/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): Gael Harbonnier.

====================================================================*/

package org.objectweb.benchmark.corba.latency;

// Package dependencies.
import java.io.InputStream;
import java.io.PrintStream;
import java.net.ServerSocket;
import java.net.Socket;
import java.util.Properties;


/**
 * IORServer sends IOR to a CORBA client.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */
public class IORServer
{
    // ==================================================================
    //
    // Internal states.
    //
    // ==================================================================
    
    /**
     * The IOR
     */
    private String ior;
  

    /**
     * Port for the socket
     */
    private int port;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     */
    public IORServer(String ior)
    throws Exception
    {
        this.ior=ior;

        Properties props = new Properties();
        InputStream propStream = getClass().getClassLoader().getResourceAsStream("build.properties");
        props.load(propStream);

        port = Integer.parseInt( props.getProperty("ior.port") );
    }  
    
    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================
    
    /**
     * Waits for client connection and publishes Server IOR.
     */
    public void listen()
    throws Exception
    {
        ServerSocket ss = new ServerSocket(port);    
        Socket s = ss.accept();    
    
        PrintStream out = new PrintStream(s.getOutputStream());

        // Sends IOR 
        out.println(this.ior);

        s.close();
    }
}
