/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.benchmark.fractal.latency;

// Package dependencies.
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

import org.objectweb.fractal.adl.Factory;
import org.objectweb.fractal.adl.FactoryFactory;
import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.rmi.registry.NamingService;
import org.objectweb.fractal.rmi.registry.Registry;
import org.objectweb.fractal.util.Fractal;

/**
 * This class looks up for server bootstrap,
 * instantiates the assembly,
 * and start the root component.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */
public class ClientLauncher
{
    public static void main(String[] args)
    {
        String name = "org.objectweb.benchmark.fractal.latency.Latency";
        NamingService ns = null;
        Component client = null;
        Properties properties = new Properties();
        String host = null;

        // Get host name
        try {
            java.io.InputStream propStream = null;
        
            // Bench info
            propStream = Thread.currentThread().getContextClassLoader().getResourceAsStream("benchmark.properties");
            properties.load(propStream);
            host = properties.getProperty("com.host");
        } catch (Exception e) {
            e.printStackTrace();
        }
        
        // Runs the assembly
        try{
            System.setSecurityManager(new SecurityManager());
            
            ns = Registry.getRegistry(host);
            
            Map context = new HashMap();
            context.put("remote-node", ns.lookup("PingServer"));
            
            Factory f = FactoryFactory.getFactory(FactoryFactory.FRACTAL_BACKEND);
            client = (Component) f.newComponent(name, context);
            
            // start root component
            Fractal.getLifeCycleController(client).startFc();
            Runnable r = (Runnable) client.getFcInterface("Runnable");
            r.run();
            Fractal.getLifeCycleController(client).stopFc();
            System.out.println("Client stopped");
        }catch(Exception ex){
            ex.printStackTrace();
        }
    }
}
