/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): 

====================================================================*/

package org.objectweb.benchmark.ccm.latency;

// Package dependencies
import org.objectweb.benchmark.util.ResultPrinter;

/**
 * This is the implementation of the OMG IDL3 latency::Client component type.
 *
 * This class inherits from the CIF generated skeleton class defined
 * as ClientSessionComposition::ComponentImpl.
 */

public class ClientImpl
     extends org.objectweb.benchmark.ccm.latency.ClientSessionComposition.ComponentImpl
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** Number of steps*/
    private int nb_step;

    /** Number of invocations per step*/
    private int nb_step_invocation;
    
    /** Beginning of the first step*/
    private int step_start;
    
    /** Results file name */
    private String result_file;

    /** host */
    private String host;
    
    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public
    ClientImpl()
    {
        java.util.Properties properties = new java.util.Properties();
        result_file = "OpenCCM.txt";

        try {
            java.io.InputStream propStream = null;

            propStream = getClass().getClassLoader().getResourceAsStream("benchmark.properties");
            properties.load(propStream);
        
            nb_step = Integer.parseInt( properties.getProperty("step.number") );
            nb_step_invocation = Integer.parseInt( properties.getProperty("step.invocation.number") );
            step_start = Integer.parseInt( properties.getProperty("step.start") );
            host = properties.getProperty("com.host");
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for OMG IDL Components::EnterpriseComponent
    //
    // ==================================================================

    /**
     * Complete the component configuration.
     *
     * @exception org.omg.Components.InvalidConfiguration
     *            Thrown if the configuration is invalid.
     */
    public void
    configuration_complete()
    throws org.omg.Components.InvalidConfiguration
    {
        // Check if the connection to the server is set.
        if(get_context().get_connection_to_server() == null)
            throw new org.omg.Components.InvalidConfiguration();

        // Obtain the object reference associated to the
        // 'to_server' receptacle.
        PingInterface to_server = get_context().get_connection_to_server();

        // Check if the connection is available.
        if(to_server == null)
        {
            System.err.println("The hello::Client::to_server receptacle is not set!");
            return;
        }

        // Don't include the first step_start invocations
        for (int i=0; i<step_start; i++)
            to_server.ping();
    
        // Runs test
        System.out.println("Running Rmi Benchmark with " + nb_step + " step(s) of " + nb_step_invocation +" method calls.");
        try
        {
            for(int j=0; j<nb_step; j++)
            {
                long timer = System.currentTimeMillis();
                
                for (int i=0; i<nb_step_invocation; i++)
                    to_server.ping();
                timer = (long) ( ( System.currentTimeMillis() - timer ) * 1000 / (float)nb_step_invocation );
            
                // write results
                ResultPrinter p = new ResultPrinter(result_file);
                p.write(timer);
                p.close();
            }
        }catch(Exception ex){
            ex.printStackTrace();
        }
    }

    // ==================================================================
    //
    // Methods for the OMG IDL org.omg.Components.SessionComponent
    //
    // ==================================================================

    /**
     * Container callback to signal that the component is removed.
     *
     * @throw org.omg.Components.CCMException For any problems.
     */
    public void
    ccm_remove()
    throws org.omg.Components.CCMException
    {
    }

    // ==================================================================
    //
    // Methods for the OMG IDL demo1::CCM_Client_Executor
    //
    // ==================================================================

}
