/*====================================================================
 
 Objectweb Browser Framework
 Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
 Contact: openccm@objectweb.org
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 USA
 
 Initial developer(s): Jerome Moroy.
 Contributor(s): ______________________________________.
 
 ---------------------------------------------------------------------
 $Id: InternalInterfacesTable.java,v 1.1 2004/04/20 16:37:27 moroy Exp $
 ====================================================================*/

package org.objectweb.util.browser.plugins.fractal.panel;

import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.Interface;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.BindingController;
import org.objectweb.fractal.api.control.ContentController;
import org.objectweb.fractal.api.control.NameController;
import org.objectweb.fractal.api.type.InterfaceType;
import org.objectweb.util.browser.api.Entry;
import org.objectweb.util.browser.api.Table;
import org.objectweb.util.browser.api.TreeView;
import org.objectweb.util.browser.core.naming.DefaultEntry;
import org.objectweb.util.browser.core.naming.DefaultName;
import org.objectweb.util.browser.plugins.fractal.FcBrowser;
import org.objectweb.util.browser.plugins.fractal.context.InterfaceWrapperFactory;
import org.objectweb.util.browser.plugins.fractal.lib.SignatureWrapper;

/**
 * Displays the internal components of a component.
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class InternalInterfacesTable
  implements Table 
{
    
    //==================================================================
    //
    // Internal states.
    //
    //==================================================================
    
    //==================================================================
    //
    // Constructor.
    //
    //==================================================================
    
    /** The name controller. */
    protected NameController nameController_;
    
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    
    /**
     * Provides the bound interface of the given client interface.
     */
    protected Entry getBoundInterface(Interface itf, BindingController bc){
        if(bc!=null){
            try{
                Interface bindInterface = (Interface)bc.lookupFc(itf.getFcItfName());
                if(bindInterface!=null)
                    return new DefaultEntry(bindInterface, 
                                            new DefaultName(FcBrowser.getPrefixedName(bindInterface)));
            } catch(NoSuchInterfaceException e) {
                return null;
            }
        }
        return null;
    }
    
    /**
     * Provides the BindingController associates to the given interface.
     */
    protected BindingController getBindingController(Interface itf){
        Component comp = itf.getFcItfOwner();
        try{
            return FcBrowser.getBindingController(comp);
        }catch(NoSuchInterfaceException e){
            return null;
        }
    }
    
    /**
     * Provides the NameController associates to the given interface.
     */
    protected NameController getNameController(Interface itf){
        Component comp = itf.getFcItfOwner();
        try{
            return FcBrowser.getNameController(comp);
        }catch(NoSuchInterfaceException e){
            return null;
        }
    }
    
    /**
     * Provides an interface, its type and the interface it is connected on.
     */
    protected Object[] getValues(Interface itf, BindingController bc){
        Object[] values = new Object[3];
        String sign = ((InterfaceType)itf.getFcItfType()).getFcItfSignature();
        values[0] = new DefaultEntry(InterfaceWrapperFactory.singleton().getWrapper(itf), 
                                     new DefaultName(FcBrowser.getName(itf)));
        values[1] = new DefaultEntry(new SignatureWrapper(sign), 
                                     new DefaultName(sign));
        values[2] = getBoundInterface(itf,bc);
        return values;
    }
    
    /**
     * Provides the ContentController for the given tree view.
     */
    protected ContentController provideContentController(TreeView treeView){
        return (ContentController)treeView.getSelectedObject();
    }
    
    //==================================================================
    //
    // Public methods for Table interface.
    //
    //==================================================================
    
    /**
     * Overriding methods
     * @see org.objectweb.util.browser.api.Table#getHeaders()
     */
    public String[] getHeaders(TreeView treeView) {
        return new String[]{"Interface", "Type", "Connected"};
    }
    
    /**
     * Overriding methods
     * @see org.objectweb.util.browser.api.Table#getRows(org.objectweb.util.browser.api.TreeView)
     */
    public Object[][] getRows(TreeView treeView) {
        ContentController cc = provideContentController(treeView);
        BindingController bc = getBindingController((Interface)cc);
        nameController_ = getNameController((Interface)cc);
        Object[] interfaces = cc.getFcInternalInterfaces();
        Object[][] values = new Object[interfaces.length][1];
        for (int i = 0 ; i < interfaces.length ; i++){
            values[i] = getValues((Interface)interfaces[i],bc);
        }
        return values;
    }
}
