/*====================================================================

Objectweb Browser Framework
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.browser.plugin.java.map;
import java.awt.Color;
import java.util.Map;

import javax.swing.BoxLayout;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;

import org.objectweb.util.browser.api.Panel;
import org.objectweb.util.browser.api.TreeView;

/**
 * Displays a <code>javax.swing.JTable</code> representing 
 * the given <code>java.util.Map</code> object.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.1
 */
public class MapPanel 
    implements Panel {

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================

    /** The JPanel to display */
    protected JPanel panel_;

    //==================================================================
    //
    // Constructors.
    // 
    //==================================================================

    /**
     * Default constructor.
     * Creates a empty white panel with <code>BoxLayout</code>.
     */
    public MapPanel(){
        panel_ = new JPanel();
        panel_.setBackground(Color.white);
        panel_.setLayout(new BoxLayout(panel_, BoxLayout.Y_AXIS));
    }

    //==================================================================
    //
    // No internal method.
    //
    //==================================================================

    //==================================================================
    //
    // Public methods for Panel interface.
    //
    //==================================================================
        
    /**
     * Invokes just after instanciation.
     * 
     * @param treeView A view on the tree.
     */
    public void selected(TreeView treeView) {
        String[] titre = {"Keys","Values"};
        Map map = (Map)treeView.getSelectedObject();
        String[][] contenu = new String[map.size()][2];
        Object[] keys = map.keySet().toArray();
        Object[] elements = map.entrySet().toArray();
        for (int i = 0; i < keys.length; i++) {
            contenu[i] = new String[]{keys[i].toString(), elements[i].toString()};
        }
        panel_.add(new JScrollPane(new JTable(contenu,titre)));        
    }

    /**
     * Provides the panel to display.
     * 
     * @return The panel to display.
     */
    public JPanel getPanel() {
        return panel_;
    }

    /**
     * Invokes just before removing.
     * 
     * @param treeView A view on the tree.
     */
    public void unselected(TreeView treeView) {
        // Noting to do
    }
        
}    