/*====================================================================

Objectweb Browser Framework
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.browser.api;

/**
 * <p>
 * A wrapper owns a reference to a wrapped object.<br>
 * In order to define a panel, you can have a look to the corresponding
 * <a href="../../../../../../resources/browser_dtd.html#wrapper">DTD element</a> or to 
 * an <a href="package-summary.html#xml">XML example.</a>
 * </p>
 * 
 * <p>
 * Example:
 * <pre>
 *      public void 
 *      setWrapped(Object object) 
 *      {
 *          properties_ = (Properties) object;
 *      }
 *
 *      public Object 
 *      getWrapped() 
 *      {
 *          return properties_;
 *      }
 * </pre>
 * The wrapper manages <code>java.util.Properties<code> object.
 * </p>
 * 
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.2
 */
public interface Wrapper 
{

    /**
     * Sets the wrapped object.
     * 
     * @param object The object to wrap.
     */
    public void 
    setWrapped(Object object);

    /**
     * Gets the wrapped object.
     * 
     * @return The wrapped object.
     */
    public Object 
    getWrapped();

}