/*====================================================================

Objectweb Browser framework
Copyright (C) 2000-2003 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.browser.core.api;

import org.objectweb.util.browser.api.DropAction;

/**
 * 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * 
 * @version 0.1
 */

public interface AssociatedDropAction 
    extends AssociatedElement {

    //==================================================================
    //
    // No internal state.
    //
    //==================================================================

    //==================================================================
    //
    // Public methods.
    //
    //==================================================================

    /** 
     * Returns the action associated to the node
     * Equivalent to a getDropAction(node,false) call
     *
     * @param node The node 
     * @param dropAction The dropAction used (Copy/Move/Link).
     * @return The associated action or null if no context is found
     */
    public DropAction getDropAction(Object node, int dropAction);

    /** 
     * Returns the action associates to the node
     *
     * @param node The node 
     * @param disabledJavaLangObject If true, then java.lang.Object is not consider as a valid entry
     * @param dropAction The dropAction used (Copy/Move/Link).
     * @return The associated action or null if no context is found
     */
    public DropAction getDropAction(Object node, boolean disabledJavaLangObject, int dropAction);

    /** 
     * Returns a description of the action associated to the node
     * Equivalent to a getDropLabel(node,false) call
     *
     * @param node The node 
     * @param dropAction The dropAction used (Copy/Move/Link).
     * @return The description of the associated action or null if no context is found
     */
    public String getDropLabel(Object node, int dropAction);
    
    /** 
     * Returns a description of the action associated to the node
     *
     * @param node The node 
     * @param disabledJavaLangObject If true, then java.lang.Object is not consider as a valid entry
     * @param dropAction The dropAction used (Copy/Move/Link).
     * @return The description of the associated action or null if no context is found
     */    
    public String getDropLabel(Object node, boolean disabledJavaLangObject, int dropAction);
    
}