/*====================================================================

Objectweb Browser Framework
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.browser.core.common;

import org.objectweb.util.browser.api.Context;
import org.objectweb.util.browser.api.Entry;
import org.objectweb.util.browser.core.api.RootFactory;

/**
 * Basic implementation of RootFactory interface.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.1
 */
public class DefaultRootFactory 
  implements RootFactory 
{

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================

    /** The class to instantiate */
    protected Class class_ = null;

    //==================================================================
    //
    // No constructor.
    // 
    //==================================================================

    //==================================================================
    //
    // No internal method.
    //
    //==================================================================

    //==================================================================
    //
    // Public methods.
    //
    //==================================================================


    /**
     * Provides the root context.
     *
     * @return The associated root context.
     */
    public Entry[] newRootContext(){
        if (class_ != null) {
            try {
                Context c = (Context) class_.newInstance();
                return c.getEntries();
            } catch (java.lang.InstantiationException e) {
                System.out.println(class_.getName() + " : Instanciation exception");
            } catch (java.lang.IllegalAccessException e) {
                System.out.println(class_.getName() + " : Illegal access exception");
            }
        }
        return null;
    }
    
    /**
     * Fixes the action class to execute
     * 
     * @param theClass The class to instantiate
     */
    public void setClassName(Class theClass) {
        class_ = theClass;
    }

}


    