/*====================================================================

Objectweb Browser Framework
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.browser.core.info;

import org.objectweb.util.browser.core.api.BrowserProperty;
import org.objectweb.util.browser.core.api.InfoFactory;
import org.objectweb.util.browser.core.api.Role;
import org.objectweb.util.browser.core.common.DefaultPropertyContainer;
import org.objectweb.util.browser.core.common.ExtendedBoolean;
import org.objectweb.util.browser.api.Entry;

/**
 * 
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.1
 */
public class InfoPropertyContainer
    extends DefaultPropertyContainer {

    //==================================================================
    //
    // No internal state.
    //
    //==================================================================

    //==================================================================
    //
    // Constructors.
    // 
    //==================================================================

    /**
     * Default contstructor
     * @param loader The object to use to load new configuration
     */
    public InfoPropertyContainer(BrowserProperty loader) {
        super(loader);
    }

    //==================================================================
    //
    // Internal methods.
    //
    //==================================================================

    /**
     * Tries to load an element for the associated class name.
     * @param className The name of the class 
     * @return The founded entry or null
     */
    protected Entry getElement(String className, Role role, ExtendedBoolean nodeFound) {
        return loader_.getInfo(className, role, nodeFound);
    }

    /**
     * Adds the InfoFactory to the container.
     *
     * @param id The name of the entry to be retrieved.
     * @param object The InfoFactory to add
     * 
     */
    protected void addEntry(String id, InfoFactory object) {
        super.addEntry(id, object);
    }

    //==================================================================
    //
    // Public methods.
    //
    //==================================================================

    // ==================================================================
    //
    // Surcharging public methods for DefaultContextContainer class.
    //
    // ==================================================================

    /**
     * Adds the object to the container.
     *
     * This method does not modify the given name and the target context.
     *
     * @param id The name of the entry to be retrieved.
     * @param object The object to add
     * 
     */
    public void addEntry(String id, Object object) {
        if (object != null) {
            addEntry(id, (InfoFactory) object);
        }
    }

}