/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.util.browser.core.naming;

/** To use the Context interface. */
import org.objectweb.util.browser.api.Context;
import org.objectweb.util.browser.api.Entry;
import org.objectweb.util.browser.api.Wrapper;
import org.objectweb.util.browser.core.api.Decoder;

/**
 * Basic implementation of the Context interface
 * for intercepting message
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class ContextDecoderManager 
    implements Context, Wrapper {
	
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The decoder. */
    protected Decoder decoder_;

    /** The delegate */
    protected Context delegate_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Creates an Entry.
     *
     * @param value The value of the entry to create.
     * @param id The id of the name of the entry to create.
     *
     * @return A new Entry.
     *
     */
    protected Entry createEntry(Object value, String id) {
        return new DefaultEntry(value, new DefaultName(id), this);
    }

    // ==================================================================
    //
    // Public methods for interface Context.
    //
    // ==================================================================

    /**
     * Returns an array containing the entries contained by the target context.
     * @return A new array of entry.
     */
    public Entry[] getEntries(){
        Entry[] entries = delegate_.getEntries();
        Entry[] decodedEntries = new Entry[entries.length];
        for (int i = 0; i < entries.length; i++) {
            if (entries[i] != null) 
                decodedEntries[i] = createEntry(decoder_.decode(entries[i].getValue()),entries[i].getName().toString());
        }
        return decodedEntries; 
    }

    // ==================================================================
    //
    // Additional public methods for Wrapper interface.
    //
    // ==================================================================

    /**
     * Fix the wrapped object
     *
     * @param object The object to wrap
     *
     */
    public void setWrapped(Object object) {
        //((Wrapper)delegate_).setWrapped(decoder_.decode(object));
         ((Wrapper) delegate_).setWrapped(object);
    }

    /**
     * Gets the wrapped object
     *
     * @return The wrapped object
     *
     */
    public Object getWrapped() {
        return ((Wrapper) delegate_).getWrapped();
    }

    // ==================================================================
    //
    // Additional public methods.
    //
    // ==================================================================

    /**
     * Fixes the delegate of the decoder
     */
    public void setDelegate(Context context) {
        delegate_ = context;
    }

    /**
     * Fixes the decoder
     */
    public void setDecoder(Decoder decoder) {
        decoder_ = decoder;
    }
}
