/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.util.browser.core.panel;

/** The console's imports */
import org.objectweb.util.browser.api.Context;
import org.objectweb.util.browser.api.Entry;
import org.objectweb.util.browser.api.TreeView;
import org.objectweb.util.browser.api.Panel;

/** The Java API's imports */
import java.awt.Color;
import javax.swing.Box;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.border.TitledBorder;

/**
 * Panel which display a context
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class ContextPanel 
    implements Panel {

    // ==================================================================
    //
    // Internal states.
    //
    // ==================================================================

    /** The associated JPanel */
    protected JPanel panel_ = null;

    /** The box added into the JPanel */
    protected Box box_ = null;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Empty constructor
     */
    public ContextPanel() {
        panel_ = new JPanel();
        panel_.setBackground(Color.white);
        box_ = Box.createVerticalBox();
        panel_.add(box_);
    }

    // ==================================================================
    //
    // No internal method.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for ViewPanel interface.
    //
    // ==================================================================
    
    /**
     * Invokes just after instanciation
     */
    public void selected(TreeView treeView) {
        Context context = (Context) treeView.getSelectedEntry().getValue();
        if (context != null) {
            Entry[] entries = context.getEntries();
            for (int i = 0; i < entries.length; i++) {
                Entry entry = entries[i];
                String text = entry.getValue().toString();
                JTextField textField = new JTextField(text);
                textField.setEditable(false);
                textField.setBackground(Color.white);
                textField.setBorder(new TitledBorder(null, entry.getName().toString(), TitledBorder.LEFT, TitledBorder.TOP));
                box_.add(textField);
            }
        }
    }

    /**
     * Provides the panel to display
     * @return The panel to display
     */
    public JPanel getPanel(){
        return panel_;
    }

    /**
     * Invokes just before removing
     */
    public void unselected(TreeView treeView) {
    }

}
