/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.util.browser.core.panel;

/** The Java API's imports */
import javax.swing.JPanel;
import java.awt.Color;
import java.lang.reflect.Method;
import java.lang.reflect.Field;
import javax.swing.BoxLayout;
import javax.swing.Box;
import javax.swing.border.TitledBorder;

/** The Console's imports */
import org.objectweb.util.browser.api.TreeView;
import org.objectweb.util.browser.api.Panel;

/**
 * Intropection Panel. 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class DefaultAssociatedPanel 
    implements Panel {

    // ==================================================================
    //
    // Internal states.
    //
    // ==================================================================

    protected TreeView treeView_;

    protected Object object_;
    
    protected JPanel panel_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Empty constructor
     */
    public DefaultAssociatedPanel() {
        panel_ = new JPanel();
        panel_.setBackground(Color.white);
        panel_.setLayout(new BoxLayout(panel_, BoxLayout.Y_AXIS));
    }
    
    // ==================================================================
    //
    // No internal method.
    //
    // ==================================================================

    protected JPanel addMethods() {
        JPanel methodsPanel = new JPanel();
        methodsPanel.setBackground(Color.white);
        methodsPanel.setBorder(new TitledBorder(null, " Methods ", TitledBorder.CENTER, TitledBorder.TOP));
        Box box = Box.createVerticalBox();
        Method[] methods = object_.getClass().getDeclaredMethods();
        for (int i = 0; i < methods.length; i++) {
            box.add(new MethodGUI(methods[i], treeView_));
        }
        methodsPanel.add(box);
        return methodsPanel;
    }

    protected JPanel addFields() {
        JPanel fieldsPanel = new JPanel();
        fieldsPanel.setBackground(Color.white);
        fieldsPanel.setBorder(new TitledBorder(null, " Attributes ", TitledBorder.CENTER, TitledBorder.TOP));
        Box box = Box.createVerticalBox();
        Field[] fields = object_.getClass().getFields();
        for (int i = 0; i < fields.length; i++) {
            box.add(new FieldGUI(fields[i], object_));
        }
        fieldsPanel.add(box);
        return fieldsPanel;
    }

    // ==================================================================
    //
    // Public methods for ViewPanel interface.
    //
    // ==================================================================
    
    /**
     * Invokes just after instanciation
     */
    public void selected(TreeView treeView) {
        treeView_ = treeView;
        object_ = treeView_.getSelectedObject();
        if (object_ != null) {
            panel_.add(addFields());
            panel_.add(addMethods());
        }
    }

    /**
     * Provides the panel to display
     * @return The panel to display
     */
    public JPanel getPanel(){
        return panel_;
    }

    
    /**
     * Invokes just before removing
     */
    public void unselected(TreeView treeView) {
    }

}
