/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.browser.gui.api;

/** The Java API's imports */
import javax.swing.JDialog;

/**
 * Allows to add some elements into a dialog frame.  
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * 
 * @version 0.1
 */
public interface DialogBox {

    /**
     * Adds an element into the current JDialog without being concerned about the display.
     * @param box The element to add.
     */
    public void addElementBox(ElementBox box);
    
    /**
     * Returns the JDialog contains by the DialogBox.
     * @return The JDialog contains by the DialogBox.
     */
    public JDialog getJDialog();
    
    /**
     * Shows the dialog box.
     */
    public void show();
    
    /**
     * Hides the dialog box.
     */
    public void hide();
    
    /**
     * Fixes the action to use for the validate button
     * @param action The action to use.
     */ 
    public void setValidateAction(DialogAction action);

    /**
     * Fixes the label of the validate button (default value is "OK").
     * @param label The label of the validate button
     */
    public void setValidateLabel(String label);
    
    /**
     * Fixes the action to use for the cancel button
     * @param action The action to use.
     */
    public void setCancelAction(DialogAction action);
    
    /**
     * Fixes the label of the cancel button (default value is "Cancel").
     * @param label The label of the cancel button
     */
    public void setCancelLabel(String label);

    /**
     * Validates all the elements contains by the JDialog.
     * @return The corresponding ValidateReport.
     */
    public ValidateReport validateDialog();

}