/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.util.browser.gui.lib;

/** The Browser API's imports*/
import org.objectweb.util.browser.gui.api.ValidateReport;

/** The java API's imports */
import javax.swing.JTextField;
import javax.swing.JLabel;
import javax.swing.Box;
import javax.swing.SwingConstants;

import java.awt.Component;
import java.awt.Dimension;

/**
 * This class represents the panel which allow to specify a label
 * 
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class LabelBox 
    extends AbstractElementBox{

    /** The value of the label */
    protected String label_;

    /** The name of the entry */
    protected JTextField name_;
    
    /**
     * Default constructor
     * @param label The label of the box, it is use to display information and to display error message.
     */
    public LabelBox(String label) {
        this(label,true);   
    }

    /**
     * Constructor with params
     * @param label The label
     * @param isMandatory If the value is mandatory : TRUE, else : FALSE 
     */
    public LabelBox(String label, boolean isMandatory) {
        super(isMandatory);
        label_ = label;
        add(Box.createHorizontalGlue());
        JLabel fieldLabel = new JLabel(label_ + ": ", SwingConstants.RIGHT);
        fieldLabel.setAlignmentX(Component.RIGHT_ALIGNMENT);
        fieldLabel.setAlignmentY(Component.CENTER_ALIGNMENT);
        add(fieldLabel);
        add(Box.createHorizontalStrut(5));
        name_ = new JTextField();
        name_.setPreferredSize(new Dimension(225, 20));
        name_.setMaximumSize(new Dimension(225, 20));
        add(name_);
    }

    /**
     * Constructor with params
     * @param label
     * @param defaultValue
     */
    public LabelBox(String label, String defaultValue){
        this(label, defaultValue, true);
    }

    /**
     * Constructor with params
     * @param label
     * @param defaultValue
     * @param isMandatory
     */
    public LabelBox(String label, String defaultValue, boolean isMandatory){
        this(label, isMandatory);
        name_.setText(defaultValue);
    }

    // ==================================================================
    //
    //  Public methods for ElementBox.
    //
    // ==================================================================

    /**
     * Validates the content of the ElementBox. Indicates if the different value are acceptables or not.
     * @return The corresponding ValidateReport.
     */
    public ValidateReport validateBox(){
        if(isMandatory_){
            if(name_.getText()==null||name_.getText().equals(""))
                return new DefaultValidateReport(false,"The \"" + label_ + "\" value is mandatory");
        }
        return new DefaultValidateReport();
    }
    
    /**
     * Returns the Box contains by the ElementBox.
     * @return The Box contains by the ElementBox.
     */
    public Box getBox(){
        return this;
    }

    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================

    /** Returns the specify label */
    public String getLabel() {
        return name_.getText();
    }

}
