/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/

package org.objectweb.openccm.explorer.CORBA;

import org.objectweb.openccm.explorer.CORBA.ConsoleFactory;
import org.objectweb.util.explorer.api.Table;
import org.objectweb.util.explorer.api.TreeView;
import org.objectweb.util.explorer.core.naming.lib.DefaultEntry;

/**
 * Displays the attributes of the given <code>CORBA Object</code>.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class CORBAAttributesTable
     extends CORBAAttributes
  implements Table 
{

    //==================================================================
    //
    // No Internal state.
    //
    //==================================================================
    
    //==================================================================
    //
    // No constructor.
    //
    //==================================================================

    // ==================================================================
    //
    // No Internal method.
    //
    // ==================================================================

    //==================================================================
    //
    // Public methods for Table interface.
    //
    //==================================================================

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Table#getHeaders(org.objectweb.util.explorer.api.TreeView)
     */
    public String[] getHeaders(TreeView treeView) {
        return new String[]{"Name","Value"};
    }
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Table#getRows(org.objectweb.util.explorer.api.TreeView)
     */
    public Object[][] getRows(TreeView treeView) {
        org.omg.CORBA.Object obj = (org.omg.CORBA.Object)treeView.getSelectedObject();
        java.util.Vector values = new java.util.Vector();
        
        for(int i=0 ; i<attributesName_.length ; i++){
            if(exists(attributesName_[i],obj)){
                String name = attributesName_[i];
                try{
                    Object returnValue = obj.getClass().getMethod(name,null).invoke(obj,null);
                    String value = returnValue!=null?returnValue.toString():null;
                    values.add(new Object[]{name, new DefaultEntry(value, new ViewAttributeWrapper(name,obj))});
                } catch(Exception e) {
                    ConsoleFactory.getDebugConsole().add("[" + getClass().getName() + "] " + name + "() method not found!\n");    
                }
            }
        }

        Object[][] contents = new Object[values.size()][2];
        for(int i=0 ; i<values.size() ; i++)
            contents[i] = (Object[])values.get(i);

        return contents;
 
    }
   
}
