/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/
package org.objectweb.openccm.explorer.CORBA;

/** To use the POA interface */
import org.objectweb.util.explorer.api.Context;
import org.objectweb.util.explorer.api.Entry;
import org.objectweb.util.explorer.core.naming.lib.DefaultEntry;
import org.omg.PortableServer.POA;

/**
 * Basic implementation of the Context interface
 * for managing POA
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class POAContext 
  implements Context
{

    // ==================================================================
    //
    // No Internal state.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    protected Entry getLocalEntry(String name, POA poa) {
        if (poa != null) {
            Object value = getLocalValue(name, poa);
            // Returns a created entry if name is found, otherwise null.
            return (value != null) ? new DefaultEntry(name, value) : null;
        }
        return null;
    }

    protected Object getLocalValue(String name, POA poa) {
        if (poa != null) {
            POA obj = null;
            try {
                obj = poa.find_POA(name, false);
            } catch (org.omg.PortableServer.POAPackage.AdapterNonExistent e) {
                System.out.println("AdapterNonExistent");
            }
            return obj;
        }
        return null;
    }

    // ==================================================================
    //
    // Public methods for interface Context.
    //
    // ==================================================================

	/**
	 * Returns an array containing the entries contained by the target context.
	 * @return A new array of entry.
	 */
    public Entry[] getEntries(Object object) {
        POA poa = (POA)object;
        POA[] objects = poa.the_children();
        Entry[] values = new Entry[objects.length];
        for (int i = 0; i < values.length; i++)
            values[i] = getLocalEntry(objects[i].the_name(), poa);
        return values;
    }

}
