/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/

package org.objectweb.openccm.explorer.Components;

import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;

import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;


import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.openccm.explorer.CORBA.ConsoleFactory;
import org.objectweb.openccm.explorer.menu.TreeDialogSingleton;
import org.objectweb.util.explorer.api.Entry;
import org.objectweb.util.explorer.api.MenuItem;
import org.objectweb.util.explorer.api.MenuItemTreeView;
import org.objectweb.util.explorer.api.Tree;
import org.objectweb.util.explorer.api.TreeView;
import org.objectweb.util.explorer.swing.api.Explorer;

import org.omg.Components.CCMObject;
import org.omg.Components.FacetDescription;
import org.omg.Components.ReceptacleDescription;

/**
 * The class allows to connect a facet to a receptacle.
 * 
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class ConnectAction 
    implements MenuItem {

    public int getStatus(TreeView arg0){
        return MenuItem.ENABLED_STATUS;
    }

    public void actionPerformed(MenuItemTreeView e) throws Exception {

        ReceptacleContainer rc = (ReceptacleContainer) e.getSelectedObject();
        ReceptacleDescription receptacle = rc.getReceptacle();
        CCMObject component = rc.getComponent();

        Component tree = TreeDialogSingleton.getInstance();
        try {
            Explorer explorerItf = (Explorer)tree.getFcInterface(Explorer.EXPLORER);
            Tree treeItf = (Tree)tree.getFcInterface(Tree.TREE);
            JPanel treePanel = new JPanel();
            treePanel.setLayout(new GridLayout(1, 0));
            treePanel.setPreferredSize(new Dimension(450, 350));
            treePanel.add(new JScrollPane(explorerItf.getTree()));
            ActionEvent ae = (ActionEvent)e.getEvent();
            int result = JOptionPane.showOptionDialog((java.awt.Component)ae.getSource(), treePanel, "Select a facet", JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, null, null);
            if (result == 0) {
                Entry entry = treeItf.getSelectedEntry();
                if (entry != null) {
                    Object object = entry.getValue();
                    if (object != null) {
                        org.omg.CORBA.Object obj_ref = null;
                        if (object instanceof org.omg.CORBA.Object) {
                            obj_ref = (org.omg.CORBA.Object) object;
                        } else if (object instanceof FacetDescription) {
                            obj_ref = ((FacetDescription)object).facet_ref;
                        } else {
                            throw new Exception("CORBA object expected !");
                        }
                        if (component != null && receptacle != null && obj_ref != null) {
                            component.connect(receptacle.name, obj_ref);
                        }
                    }
                }
            }
        } catch (NoSuchInterfaceException e1) {
            ConsoleFactory.getDebugConsole().add(e1.getMessage());
        }        
    }

}
