/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/
package org.objectweb.openccm.explorer.Components;

import org.omg.Components.CCMObject;
import org.omg.Components.ReceptacleDescription;
import org.omg.Components.ConnectionDescription;

/**
 * This class is composed by
 * <ul>
 * <li>A ConnectionDescription reference.</li>
 * <li>The associated ReceptacleDescription reference.</li>
 * <li>The component reference associates to the ReceptacleDescription</li>
 * </ul>
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class ConnectionContainer {

    /** The ConnectionDescription reference. */
    protected ConnectionDescription connection_;

    /** The associated ReceptacleContainer */
    protected ReceptacleContainer receptacleContainer_;

    /**
     * @return
     */
    public ConnectionDescription getConnection() {
        return connection_;
    }

    /**
     * @param description
     */
    public void setConnection(ConnectionDescription connection) {
        connection_ = connection;
    }

    /**
     * @param container
     */
    public void setReceptacleContainer(ReceptacleContainer receptacleContainer) {
        receptacleContainer_ = receptacleContainer;
    }

    /**
     * @return
     */
    public ReceptacleDescription getReceptacle() {
        if (receptacleContainer_ != null)
            return receptacleContainer_.getReceptacle();
        return null;
    }

    /**
     * @return
     */
    public CCMObject getComponent() {
        if (receptacleContainer_ != null)
            return receptacleContainer_.getComponent();
        return null;
    }

}
