/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/
package org.objectweb.openccm.explorer.CosNaming;

import org.objectweb.util.explorer.api.Entry;
import org.objectweb.util.explorer.api.MenuItem;
import org.objectweb.util.explorer.api.MenuItemTreeView;
import org.objectweb.util.explorer.api.Tree;
import org.objectweb.util.explorer.api.TreeView;
import org.objectweb.util.explorer.swing.gui.api.DialogAction;
import org.objectweb.util.explorer.swing.gui.api.DialogBox;
import org.objectweb.util.explorer.swing.gui.lib.DefaultDialogBox;
import org.objectweb.util.explorer.swing.gui.lib.LabelBox;
import org.omg.CosNaming.NamingContextExt;

/**
 * Renamed the binding.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class RenameBinding 
  implements MenuItem, DialogAction 
{

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================

    protected LabelBox bindingName_ = null;
    
    protected String currentBindingName_ = null;
    
    protected org.omg.CORBA.Object bindingObject_ = null;

    protected NamingContextExt naming_ = null;

    protected Tree tree_ = null;

    //==================================================================
    //
    // No constructor.
    //
    //==================================================================

    //==================================================================
    //
    // Internal methods.
    //
    //==================================================================

    /**
     * Binds the object into the current NameService
     */
    protected void bind(NamingContextExt naming, String id, org.omg.CORBA.Object o) {
        try {
            naming.rebind(naming.to_name(id), o);
        } catch (org.omg.CosNaming.NamingContextPackage.NotFound e) {
            System.out.println(getClass().getName() + " : Object Not Found Exception !");
        } catch (org.omg.CosNaming.NamingContextPackage.CannotProceed e) {
            System.out.println(getClass().getName() + " : CannotProceed Exception");
        } catch (org.omg.CosNaming.NamingContextPackage.InvalidName e) {
            System.out.println(getClass().getName() + " : InvalidName Exception");
        }
    }

    //==================================================================
    //
    // Public methods for MenuItem interface.
    //
    //==================================================================

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.MenuItem#getStatus(org.objectweb.util.explorer.api.TreeView)
     */
    public int getStatus(TreeView arg0){
        return MenuItem.ENABLED_STATUS;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.MenuItem#actionPerformed(org.objectweb.util.explorer.api.MenuItemTreeView)
     */
    public void actionPerformed(MenuItemTreeView tv) throws Exception {
        Entry entry = tv.getSelectedEntry();
        currentBindingName_ = entry.getName().toString();
        naming_ = (NamingContextExt) tv.getParentObject();
        bindingObject_ = (org.omg.CORBA.Object)tv.getSelectedObject();
        tree_ = tv.getTree();
        
        DialogBox dialog = new DefaultDialogBox("Rename this binding");
        bindingName_ = new LabelBox("Binding name",currentBindingName_,true);
        dialog.addElementBox(bindingName_);
        dialog.setValidateAction(this);
        dialog.show();
    }

    //==================================================================
    //
    // Public methods for DialogAction interface.
    //
    //==================================================================

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.swing.gui.api.DialogAction#executeAction()
     */
    public void executeAction() throws Exception {
        String newName = bindingName_.getLabel();
        if(!newName.equals(currentBindingName_)){
            naming_.rebind(naming_.to_name(newName), bindingObject_);
            naming_.unbind(naming_.to_name(currentBindingName_));
            tree_.renameSelectedNode(currentBindingName_, newName);
        }
    }
}
