/*===========================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Sylvain Leblanc.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.openccm.explorer.CosTrading;

/** Java Imports. */
import java.util.List;
import java.util.LinkedList;

/** OMG CosTrading imports. */
import org.omg.CosTrading.Lookup;

/**
 * Wrapper class used to provide a node in the administration console
 * tree which children are <code>Query</code> instances. This class
 * also provided class-methods to manage created queries.
 *
 * @author <a href="mailto:Sylvain.Leblanc@lifl.fr">Sylvain Leblanc</a>
 * @version 0.1
 */
public class Queries {

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** 
     * A list of created queries. 
     */
    protected static List queries;

    /** 
     * The CosTrading Lookup interface used to create new queries. 
     */
    protected Lookup lookup_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    public Queries(Lookup lookup) 
    {
        lookup_ = lookup;
        if (Queries.queries  == null) Queries.queries = new LinkedList();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /**
     * Returns the lookup reference to use in order to create new
     * queries.
     *
     * @return The lookup reference to use in order to create new
     * queries.
     */
    public Lookup
    getLookup()
    {
        return lookup_;
    }

    /**
     * Returns all queries created and added to the queries list.
     *
     * @return All queries created and added to the queries list.
     */
    public Query[] 
    getQueries()
    {
        return (Query[])Queries.queries.toArray(new Query[0]);
    }

    /**
     * Adds a new query in the queries list.
     *
     * @param q The query to add the queries list.
     */
    public void
    addQuery(Query q)
    {
        Queries.queries.add(q);
    }

    /**
     * Removes a query from the queries list.
     *
     * @param q The query to remove from the list.
     */
    public void
    removeQuery(Query q)
    {
        boolean rmvd = Queries.queries.remove(q);
    }

    /**
     * Returns the size of the queries list.
     *
     * @return The size of the queries list.
     */
    public int 
    getSize()
    {
        return Queries.queries.size();
    }

    /**
     * Cleans the queries list.
     */
    public void
    clean()
    {
        Queries.queries.clear();
    }

}
