/*===========================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Sylvain Leblanc.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.openccm.explorer.CosTrading.gui;

import java.io.BufferedReader;
import java.io.FileReader;

import javax.swing.Box;
import javax.swing.JPanel;

import org.objectweb.openccm.explorer.menu.BrowserPanel;
import org.objectweb.openccm.explorer.menu.OpenCCMBrowserConstants;
import org.omg.CORBA.ORB;
import org.omg.CosTrading.FollowOption;
import org.omg.CosTrading.Lookup;
import org.omg.CosTrading.LookupHelper;

/**
 * Panel used to display what needs to be set for
 * creating a link.
 */
public class AddLinkPanel 
     extends JPanel 
{

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The browser panel for Lookup reference. */
    protected BrowserPanel lbp_;

    /** The box to select default follow rule. */
    protected FollowOptionBox def_;

    /** The box to select limiting follow rule. */
    protected FollowOptionBox limit_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Default constructor. 
     */
    public AddLinkPanel() {
        Box b = Box.createVerticalBox();
        b.add(Box.createVerticalGlue());
            
        // Creates the browser panel.
        lbp_ = new BrowserPanel("Link Name: ", "Choose an IOR File: ", OpenCCMBrowserConstants.IOR_FILE_CHOOSER);
        b.add(lbp_);

        b.add(Box.createVerticalStrut(10));

        // Creates the def combo box
        def_ = new FollowOptionBox("Default Follow Link Rule: ");
        b.add(def_);

        b.add(Box.createVerticalStrut(10));

        // Creates the limit combo box
        limit_ = new FollowOptionBox("Limiting Follow Link Rule: ");
        b.add(limit_);

        b.add(Box.createVerticalGlue());
            
        add(b);
    }        

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
        
    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /**
     * Returns the new link name.
     *
     * @return The new link name.
     */
    public String getName() {
        return lbp_.getLabel();
    }

    /**
     * Returns the new link targeted trader.
     *
     * @return The new link targeted trader.
     */
    public Lookup getLookupRef() {
        Lookup ref = null;
        if (lbp_.getFile() != null) {
            java.io.File file = lbp_.getFile();
            String ior = null;
            try {
                BufferedReader in = new BufferedReader(new FileReader(file));
                ior = in.readLine();
            } catch (java.io.FileNotFoundException err) {
                System.err.println(file + ": File not found !");
            } catch (java.io.IOException err) {
                System.err.println(file + ": Error while reading !");
            }
            if (ior != null && ior.startsWith("IOR:")) {
                ORB orb = org.objectweb.openccm.corba.TheORB.getORB();
                ref = LookupHelper.narrow(orb.string_to_object(ior));
            }
        }  else if (lbp_.getSelectedObject() != null) {
            ref = (Lookup)lbp_.getSelectedObject();
        }
        return ref;
    }

    /**
     * Returns the new link def pass on option.
     *
     * @return The new link def pass on option.
     */
    public FollowOption getDefPassOn() {
        return def_.getOption();
    }

    /**
     * Returns the new link limiting option.
     *
     * @return The new link limiting option.
     */
    public FollowOption getLimiting() {
        return limit_.getOption();
    }
}

