/*===========================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Sylvain Leblanc.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.openccm.explorer.CosTrading.gui;

/** The Java API's imports */
import javax.swing.JPanel;
import java.awt.Color;
import javax.swing.BoxLayout;
import javax.swing.Box;
import javax.swing.border.TitledBorder;
import javax.swing.JLabel;

import org.objectweb.openccm.explorer.CosTrading.Query;

/**
 * Panel used to view content of a
 * <code>Query</code> instance. 
 *
 * @author <a href="mailto:Sylvain.Leblanc@lifl.fr">Sylvain Leblanc</a>
 * @version 0.1
 */
public class QueryPanel extends DefaultNodeViewPanel {

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The query to display. */
    protected Query query_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Default constructor.
     */
    public QueryPanel() {
        setBackground(Color.white);
        setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /**
     * Creates the content of the panel.
     */
    public void onSetTreeView() {
        if (getTreeView() != null) {
            query_ = (Query)getTreeView().getSelectedObject();
            if (query_ != null) {

                // Creates a new Panel
                JPanel queryPanel = new JPanel();
                queryPanel.setBackground(Color.white);
                queryPanel.setBorder(new TitledBorder(null," " + query_.getQueryLabel() + " ",TitledBorder.CENTER,TitledBorder.TOP));
                
                // Creates various labels
                JLabel stn_lab = new JLabel("Service Type: " + query_.getServiceTypeName());                
                JLabel constr_lab = new JLabel("Constraint: " + query_.getConstraint());                
                JLabel pref_lab = new JLabel("Preferences: " + query_.getPref());
                
                // Creates a new Swing box
                Box box = Box.createVerticalBox();                
                box.add(stn_lab);
                box.add(Box.createVerticalStrut(10));                        
                box.add(constr_lab);
                box.add(Box.createVerticalStrut(10));                        
                box.add(pref_lab);
                
                // Adding box and panel in this panel
                queryPanel.add(box);            
                add(queryPanel);
            }
        }
    }
}














