/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2005 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================
$Id: MainPDA.java,v 1.4 2005/07/01 15:55:17 moroy Exp $
====================================================================*/
package org.objectweb.openccm.explorer;

import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.adl.Factory;
import org.objectweb.fractal.adl.FactoryFactory;
import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;
import org.objectweb.fractal.util.Fractal;
import org.objectweb.openccm.explorer.CORBA.ConsoleFactory;
import org.objectweb.openccm.explorer.menu.Menu;
import org.objectweb.util.explorer.api.Tree;
import org.objectweb.util.explorer.context.api.ContextParser;
import org.objectweb.util.explorer.parser.api.ParserConfiguration;
import org.objectweb.util.explorer.swing.api.Explorer;
import org.objectweb.util.explorer.swing.api.StatusBar;
import org.objectweb.util.explorer.swing.api.ViewPanel;
import org.objectweb.util.explorer.swing.lib.DefaultTreePanel;

/** The java API's imports */
import java.awt.Dimension;
import java.awt.BorderLayout;
//import java.awt.HeadlessException;

import javax.swing.JTabbedPane;

/**
 * This class defines the main frame of the OpenCCM Explorer designed for PDA
 * 
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class MainPDA 
     extends Main 
{

    /** 
     * Initializes the OpenCCM Browser frame
     */
    protected void init(String contextPropertyFile, String[] browserPropertyFile){

        try {
            // Creates a Fractal Explorer instance.
            Factory f = FactoryFactory.getFactory(FactoryFactory.FRACTAL_BACKEND);
            Component explorer = (Component)f.newComponent("org.objectweb.openccm.explorer.SwingCCMExplorer",null);
            Fractal.getLifeCycleController(explorer).startFc();

            // Loads the configuration file.
            ParserConfiguration parser = (ParserConfiguration)explorer.getFcInterface(ParserConfiguration.PARSER_CONFIGURATION);
            for (int i = 0; i < browserPropertyFile.length; i++) {
                parser.addPropertyFile(browserPropertyFile[i]);
            }
            parser.parse();

            // Loads the context configuration file.
            ContextParser cParser = (ContextParser)explorer.getFcInterface(ContextParser.CONTEXT_PARSER);
            cParser.parse(contextPropertyFile);
            
            Explorer explorerItf = (Explorer)explorer.getFcInterface(Explorer.EXPLORER);
            Tree treeItf = (Tree)explorer.getFcInterface(Tree.TREE);
            
            //setIconImage(createIcon("icons/tools.png").getImage());

            // Creates the menu
            Menu menu = new Menu(this, explorer);
            
            explorerItf.setMultipleRoles(true);
            explorerItf.setCurrentRoles(new String[]{"user view","Deployment administrator","Components administrator","CORBA Administrator","CosNaming administrator"});
            explorerItf.setMenuBar(menu.getMenuBar());
            explorerItf.setToolBar(menu.getToolBar());
            populateTree(treeItf);
            
            ViewPanel viewPanelItf = (ViewPanel)explorer.getFcInterface(ViewPanel.VIEW_PANEL);
            StatusBar statusBarItf = (StatusBar)explorer.getFcInterface(StatusBar.STATUS_BAR);
            
            // Initializes the tree using in JDialog Boxes,
            initializeTreeDialog(treeItf);

            setJMenuBar(menu.getMenuBar());

            getContentPane().setLayout(new BorderLayout());
            getContentPane().add(menu.getToolBar(),BorderLayout.NORTH);
            JTabbedPane tabbedPane = new JTabbedPane();
            tabbedPane.addTab("Tree", new DefaultTreePanel(explorerItf.getTree()));
            tabbedPane.addTab("View", viewPanelItf.getViewPanel());
            getContentPane().add(tabbedPane, BorderLayout.CENTER);
            getContentPane().add(statusBarItf.getStatusBar(),BorderLayout.SOUTH);

            //setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
            addWindowListener(new OpenCCMWindowListener(treeItf));
            pack();

            // Centers the frame
            Dimension screenSize = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
            setLocation((screenSize.width - getWidth()) / 2, (screenSize.height - getHeight()) / 2);

            setVisible(true);
        }  catch (ADLException e) {
            ConsoleFactory.getDebugConsole().add(e.getMessage());
        } catch (IllegalLifeCycleException e) {
            ConsoleFactory.getDebugConsole().add(e.getMessage());
        } catch (NoSuchInterfaceException e) {
            ConsoleFactory.getDebugConsole().add(e.getMessage());
        } 
        catch (Exception e) {
            ConsoleFactory.getDebugConsole().add(e.getMessage());
        }               
    }

    /**
     * Default constructor
     */
    public MainPDA(String contextPropertyFile, String[] browserPropertyFile) {
        super(contextPropertyFile, browserPropertyFile);
    }
    
}
