/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/
package org.objectweb.openccm.explorer.commandLine;

/** The Command Lines framework's imports */
import org.objectweb.util.cmdline.lib.DefaultOptionBase;

/**
 * Class representing the option to set the view of the main frame.<br>
 * ex : ccm_browser --view (basic|tabs)
 * 
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class ViewOption extends DefaultOptionBase {

    /** Reference to the View Application. */
    protected ViewApplication application_;

    /**
     * The constructor with the owner View Application.
     * @param application Reference to the View Application.
     */
    public ViewOption(ViewApplication application) {
        // Calls the DefaultOptionBase constructor.
        super();
        setLabels(new String[] { "--view" });
        setArguments(new String[] { "view_type" });
        setDescription(new String[] { "Set the view of the main frame (basic|tabs) (default value is basic)" });
        setMandatory(false);

        // Inits internal state.
        application_ = application;
    }

    // ==================================================================
    // Public methods for interface org.objectweb.util.cmdline.api.Option
    // ==================================================================

    /**
     * Consumes command line arguments from an iterator.
     * @param iterator The command line argument iterator.
     */
    public void consume(org.objectweb.util.cmdline.api.Iterator iterator) {
        checkAlreadySet(iterator);
        String view = consumeArgument(iterator);
        if((view!=null) && (view.equals("basic")||view.equals("tabs"))){
            application_.setView(view);
        }
    }

}
