/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/
package org.objectweb.openccm.explorer.menu;

/** The java API's imports */
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.Box;

import org.objectweb.util.explorer.api.Entry;
import org.objectweb.util.explorer.api.Tree;
import org.objectweb.util.explorer.swing.api.Explorer;

import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.openccm.explorer.CORBA.ConsoleFactory;
import org.objectweb.openccm.explorer.menu.TreeDialogSingleton;

import java.awt.Dimension;
import java.io.File;

/**
 * This class represents the panel which allows to choose a file and specify a label to the entry
 * 
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class BrowserPanel extends JPanel {

    /** The associated FileChooserPanel */
    protected FileChooserPanel fileChooserPanel_;

    /** The associated Tree */
    protected Component tree_;

    /** The Tree interface of the tree component. */
    protected Tree treeItf_;
    
    /** 
     * Default constructor
     */
    public BrowserPanel(String nameFieldLabel, String nameBrowserLabel, int fileFilter) {

        fileChooserPanel_ = new FileChooserPanel(nameFieldLabel, nameBrowserLabel, fileFilter);

        Box b = Box.createVerticalBox();
        b.add(Box.createVerticalGlue());

        b.add(fileChooserPanel_);

        b.add(Box.createVerticalStrut(10));

        try {
            tree_ = TreeDialogSingleton.getInstance();
            Explorer explorerItf = (Explorer)tree_.getFcInterface(Explorer.EXPLORER);
            treeItf_ = (Tree)tree_.getFcInterface(Tree.TREE);
            Box treeBox = Box.createHorizontalBox();
            //tree.setPreferredSize(new Dimension(350,150));
            JScrollPane scroll = new JScrollPane(explorerItf.getTree());
            scroll.setPreferredSize(new Dimension(350, 150));
            treeBox.add(scroll);
            b.add(treeBox);

            b.add(Box.createVerticalGlue());

            add(b);
        } catch (NoSuchInterfaceException e) {
            ConsoleFactory.getDebugConsole().add(e.getMessage());
        }
    }

    /** Returns the specify label */
    public String getLabel() {
        return fileChooserPanel_.getLabel();
    }

    /** Returns the chosen file */
    public File getFile() {
        return fileChooserPanel_.getFile();
    }

    /** Returns the selected object */
    public Object getSelectedObject() {
        if (tree_ != null) {
            Entry entry = treeItf_.getSelectedEntry();
            if (entry != null)
                return entry.getValue();
        }
        return null;
    }

}
