/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

===========================================================================*/
package org.coach.actor.commandline;

import org.objectweb.util.cmdline.lib.ApplicationBase;
import org.objectweb.util.cmdline.lib.DefaultCommandLine;
import org.objectweb.util.misc.api.ExceptionWrapper;
import org.coach.actor.Main;
import java.io.File;
import java.util.Vector;
import java.util.List;

/**
 * This class manages the different options and launch the corresponding command.
 * 
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class ActorApplication extends ApplicationBase implements DefaultApplication, ConfigApplication {

    /* The default actor config file or directory. */
    protected String actor_ = "";

    /* The default context config file or directory. */
    protected String context_ = "";

    /* The actor config file or directory fix by the user. */
    protected String config_ = null;

    /**
     * Default Constructor.
     */
    public ActorApplication() {
        super(new DefaultCommandLine(new String[] { "ccm_actor" }, new String[0], new String[] { "Display the OpenCCM actor console" }, true));
        // Creates the ClientApplication options
//        getCommandLine().addOption(new DefaultContextOption(this));
        getCommandLine().addOption(new DefaultActorOption(this));
//        getCommandLine().addOption(new ConfigOption(this));
    }

    /**
     * Remove the ORB arguments.
     * @param args The command line arguments.
     * @return The new args without ORB arguments.
     */
    private String[] removeORBArgument(String[] args) {
        int nb = 0;
        String[] tmp = new String[args.length];
        for (int i = 0; i < args.length; i++) {
            if (!args[i].startsWith("-ORB")) {
                tmp[nb] = args[i];
                nb++;
            } else {
                i++;
            }
        }
        String[] tmp2 = new String[nb];
        for (int i = 0; i < nb; i++)
            tmp2[i] = tmp[i];
        return tmp2;
    }

    /**
     * Fixes the Configuration file to use
     * @param file The configuration file to use
     */
    public void setConfigFile(String file) {
        config_ = file;
    }

    /**
     * Fixes the Default Context Configuration file to use
     * @param file The configuration file to use
     */
    public void setDefaultContextConfigFile(String file) {
        context_ = file;
    }

    /**
     * Fixes the Default Actor Configuration file to use
     * @param file The configuration file to use
     */
    public void setDefaultActorConfigFile(String file) {
        actor_ = file;
    }

    /**
     * Executes the main function.
     * @param args The command line arguments.
     */
    public void runMain(String[] args) {
        // Initializes the CORBA::ORB singleton.
        org.omg.CORBA.ORB orb = org.objectweb.openccm.Components.Runtime.init(args);
        //org.objectweb.openccm.corba.TheORB.initialize(args);

        // Surcharges the ApplicationBase.runMain method.
        try {
            String[] arguments = getCommandLine().parse(removeORBArgument(args));
            int ret = start(arguments);
        } catch (ExceptionWrapper exc) {
            report_exception(exc.getException());
        } catch (Exception exc) {
            report_exception(exc);
        }
    }

    /**
     * Starts the main function.
     * @param args The command line arguments.
     */
    public int start(String[] args) {
        List fileList = new Vector();
        fileList.add(new File(actor_));
        if (config_ != null) {
            fileList.add(new File(config_));
        }
        new Main(new File(context_), (File[]) fileList.toArray(new File[0]));
        return 0;
    }

    /**
     * The main method.
     * @param args The command line arguments.
     */
    public static void main(String[] args) {
        ActorApplication application = new ActorApplication();
        application.runMain(args);
    }

}