/***************************************************************************/
/* COACH: Component Based Open Source Architecture for                     */
/*        Distributed Telecom Applications                                 */
/* See:   http://www.objectweb.org/                                        */
/*                                                                         */
/* Copyright (C) 2003 Lucent Technologies Nederland BV                     */
/*                    Bell Labs Advanced Technologies - EMEA               */
/*                                                                         */
/* Initial developer(s): Harold Batteram                                   */
/*                                                                         */
/* This library is free software; you can redistribute it and/or           */
/* modify it under the terms of the GNU Lesser General Public              */
/* License as published by the Free Software Foundation; either            */
/* version 2.1 of the License, or (at your option) any later version.      */
/*                                                                         */
/* This library is distributed in the hope that it will be useful,         */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        */
/* Lesser General Public License for more details.                         */
/*                                                                         */
/* You should have received a copy of the GNU Lesser General Public        */
/* License along with this library; if not, write to the Free Software     */
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
/***************************************************************************/
package org.coach.actor.componentBrowser;

import java.awt.*;
import javax.swing.*;
import javax.swing.border.*;
import java.awt.event.*;
import javax.swing.tree.*;

import org.coach.idltree.*;
import org.coach.util.IorPrinter;

public class ComponentControlPanel extends JPanel {
    BorderLayout borderLayout1 = new BorderLayout();
    JScrollPane jScrollPane1 = new JScrollPane();
    JTextArea iorTextArea = new JTextArea();
    JPanel buttonPanel = new JPanel();
    JButton deleteButton = new JButton();
    JButton refreshButton = new JButton();
    TitledBorder titledBorder1;
    ComponentModel model;
    JPanel iorPanel = new JPanel();
    FlowLayout flowLayout1 = new FlowLayout();
    JLabel typeLabel = new JLabel();
    JTextField typeTextField = new JTextField();
    JLabel hostLabel = new JLabel();
    JTextField hostTextField = new JTextField();
    JLabel portLabel = new JLabel();
    JTextField portTextField = new JTextField();
    JButton pingButton = new JButton();
    JLabel pingLabel = new JLabel();
    JButton showButton = new JButton();
    JButton tclButton = new JButton();
    org.omg.CORBA.ORB orb;
        
    public ComponentControlPanel() {
        try  {
            jbInit();
        }
        catch(Exception ex) {
            ex.printStackTrace();
        }
    }

    public ComponentControlPanel(ComponentModel model, org.omg.CORBA.ORB orb) {
        this.model = model;
        this.orb = orb;
        try  {
            jbInit();
        }
        catch(Exception ex) {
            ex.printStackTrace();
        }
    }
    private void jbInit() throws Exception {
        titledBorder1 = new TitledBorder("");
        this.setLayout(borderLayout1);
        iorTextArea.setRows(3);
        iorTextArea.setBackground(Color.lightGray);
        iorTextArea.setBorder(titledBorder1);

        refreshButton.setText("refresh");
        refreshButton.addActionListener(new java.awt.event.ActionListener() {

            public void actionPerformed(ActionEvent e) {
                refreshButton_actionPerformed(e);
            }
        });
        titledBorder1.setTitle("IOR");
        jScrollPane1.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS);
        jScrollPane1.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_NEVER);
        iorPanel.setLayout(flowLayout1);
        typeLabel.setText("Type Id");
        hostLabel.setText("Host");
        hostTextField.setText("        ");
        typeTextField.setText("          ");
        portLabel.setText("Port");
        portTextField.setText("        ");
        iorPanel.setBorder(BorderFactory.createEtchedBorder());

        pingButton.setText("ping");
        pingButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(ActionEvent e) {
                pingButton_actionPerformed(e);
            }
        });
        pingLabel.setFont(new java.awt.Font("Monospaced", 0, 12));
        pingLabel.setText("         ");

        showButton.setText("show");
        showButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(ActionEvent e) {
                showButton_actionPerformed(e);
            }
        });

        tclButton.setText("tcl shell");
        tclButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(ActionEvent e) {
                tclButton_actionPerformed(e);
            }
        });
        
        this.add(jScrollPane1, BorderLayout.CENTER);
        this.add(buttonPanel, BorderLayout.SOUTH);
        buttonPanel.add(refreshButton, null);
        buttonPanel.add(showButton, null);
        buttonPanel.add(tclButton, null);
        buttonPanel.add(pingButton, null);
        buttonPanel.add(pingLabel, null);
        this.add(iorPanel, BorderLayout.NORTH);
        iorPanel.add(typeLabel, null);
        iorPanel.add(typeTextField, null);
        iorPanel.add(hostLabel, null);
        iorPanel.add(hostTextField, null);
        iorPanel.add(portLabel, null);
        iorPanel.add(portTextField, null);
        jScrollPane1.getViewport().add(iorTextArea, null);

        addMouseListener(new java.awt.event.MouseAdapter() {
            public void mousePressed(java.awt.event.MouseEvent e) {
                if (e.isPopupTrigger()) {
                    showButton_actionPerformed(null);
                }
            }
            public void mouseReleased(java.awt.event.MouseEvent e) {
                if (e.isPopupTrigger()) {
                    showButton_actionPerformed(null);
                }
            }
        });
    }

    void refreshButton_actionPerformed(ActionEvent e) {
        model.refresh();
    }

    void pingButton_actionPerformed(ActionEvent e) {
        TreePath path = model.getSelection();
        if (path != null) {
            ComponentNode node = (ComponentNode)path.getLastPathComponent();
            if (node.ping()) {
                pingLabel.setForeground(Color.green);
                pingLabel.setText("alive!   ");
            } else {
                pingLabel.setForeground(Color.red);
                pingLabel.setText("no reply!");
            }
        }
    }

    void showButton_actionPerformed(ActionEvent e) {
        TreePath path = model.getSelection();
        if (path != null) {
            ComponentNode node = (ComponentNode)path.getLastPathComponent();
            if (node.isLeaf()) {
                String ior = node.getIor();
                IorPrinter iorPrinter = new IorPrinter(ior);
                String id = iorPrinter.getTypeId();
                try {
                    MethodFrame mf = new MethodFrame(this, id, node.toString(), node.getObject(), orb);
                } catch (Exception ex) {
                    ex.printStackTrace();
                    JOptionPane.showMessageDialog(null, ex.toString());
                }
            }
        }
    }

    void tclButton_actionPerformed(ActionEvent e) {
        TreePath path = model.getSelection();
        if (path != null) {
            ComponentNode node = (ComponentNode)path.getLastPathComponent();
            if (node.isLeaf()) {
                String ior = node.getIor();
                IorPrinter iorPrinter = new IorPrinter(ior);
                String id = iorPrinter.getTypeId();
                try {
                    TclFrame mf = new TclFrame(this, id, node.toString(), node.getObject());
                } catch (Exception ex) {
                    ex.printStackTrace();
                    JOptionPane.showMessageDialog(null, ex.toString());
                }
            }
        }
    }
}                   