/***************************************************************************/
/* COACH: Component Based Open Source Architecture for                     */
/*        Distributed Telecom Applications                                 */
/* See:   http://www.objectweb.org/                                        */
/*                                                                         */
/* Copyright (C) 2003 Lucent Technologies Nederland BV                     */
/*                    Bell Labs Advanced Technologies - EMEA               */
/*                                                                         */
/* Initial developer(s): Harold Batteram                                   */
/*                                                                         */
/* This library is free software; you can redistribute it and/or           */
/* modify it under the terms of the GNU Lesser General Public              */
/* License as published by the Free Software Foundation; either            */
/* version 2.1 of the License, or (at your option) any later version.      */
/*                                                                         */
/* This library is distributed in the hope that it will be useful,         */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        */
/* Lesser General Public License for more details.                         */
/*                                                                         */
/* You should have received a copy of the GNU Lesser General Public        */
/* License along with this library; if not, write to the Free Software     */
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
/***************************************************************************/
package org.coach.actor.componentBrowser;

import java.awt.*;
import javax.swing.*;
import org.coach.idltree.*;
import org.coach.util.IorPrinter;
import org.omg.Components.*;

public class MethodPanel extends JPanel implements ObjectListener {
    MethodFrame methodFrame;
    JPanel treePanel;
    JPanel emptyReply = new JPanel();
    IdlTreePanel operationTree;
    JScrollPane operationScrollPane;
    IdlTreePanel replyTree;
    JScrollPane replyScrollPane;
    InvokePanel invokePanel;
    org.omg.CORBA.ORB orb;
    
    public MethodPanel() {
        try  {
            this.setLayout(new BorderLayout());
        }
        catch(Exception ex) {
            ex.printStackTrace();
        }
    }

    public MethodPanel(MethodFrame mf, String id, String facetName, org.omg.CORBA.Object target, org.omg.CORBA.ORB orb) {
        this();
        this.orb = orb;
        this.methodFrame = mf;
        invokePanel = new InvokePanel(this, orb);
        invokePanel.setOperation(id, facetName, target);
        treePanel = new JPanel();
        treePanel.setLayout(new GridLayout(1,2));
        setOperation(invokePanel.getModel());       
        this.add(treePanel, BorderLayout.CENTER);
        this.add(invokePanel, BorderLayout.SOUTH);
    }
    
    public void setReply(IdlModel replyModel) {
        replyTree = new IdlTreePanel(replyModel);
        replyTree.addObjectListener(this);
        replyScrollPane = new JScrollPane(replyTree);
        treePanel.remove(emptyReply);
        treePanel.add(replyScrollPane);
        treePanel.repaint();
        repaint();
        methodFrame.pack();
    }

    public void setOperation(IdlModel operationModel) {
        treePanel.removeAll();
        operationTree = new IdlTreePanel(operationModel);
        operationTree.addModelListener(invokePanel);
        operationScrollPane = new JScrollPane(operationTree);
        treePanel.add(operationScrollPane);
        clearReply();
        methodFrame.pack();
    }
    
    public void clearReply() {
        replyTree = null;
        replyScrollPane = null;
        treePanel.add(emptyReply);
        treePanel.repaint();
        repaint();
    }
        
    /**
     * This method is called when a user double clicks on an IOR in the reply tree
     */
    public void objectAction(String ior) {
        try {
            IorPrinter iorPrinter = new IorPrinter(ior);
            String id = iorPrinter.getTypeId();
            org.omg.CORBA.Object obj = orb.string_to_object(ior);
            try {
                // if the corba object is a component, start the component browser
                CCMObject c = CCMObjectHelper.narrow(obj);
//                ComponentBrowser cb = new ComponentBrowser(this, orb, c.getName(), c);
//                ComponentBrowser cb = new ComponentBrowser(this, orb, "component name?", c);
                  invokePanel.setOperation(id, "", obj);
                  setOperation(invokePanel.getModel());
//MethodFrame mf = new MethodFrame(this, id, "", obj, orb);
            } catch (Exception ex) {
                // else, start the facet browser
//                MethodFrame mf = new MethodFrame(this, id, "", obj, orb);
                  invokePanel.setOperation(id, "", obj);
                  setOperation(invokePanel.getModel());
            }   
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
} 