/*====================================================================
 
 OpenCCM: The Open CORBA Component Model Platform
 Copyright (C) 2004 INRIA - USTL - LIFL - GOAL
 Contact: openccm@objectweb.org
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 USA
 
 Initial developer(s): Areski Flissi.
 Contributor(s): 
 
 ====================================================================
 $Id: MulticastServer.java,v 1.1 2004/10/12 14:39:36 rouvoy Exp $
 ====================================================================*/

package org.objectweb.comanche.lib;

import java.net.InetAddress;
import java.net.DatagramPacket;
import java.net.DatagramSocket;
import java.net.MulticastSocket;

import java.io.IOException;

/**
 * 
 * @author Areski Flissi
 * @version 0.1
 */
public class MulticastServer 
     extends Thread 
{
    /**
     * Comment for <code>s_port</code>
     */
    protected static final int s_port = 8888;
    /**
     * Comment for <code>ms_port</code>
     */
    protected static final int ms_port = 8880;
    /**
     * Comment for <code>ior_str_</code>
     */
    protected String ior_str_ = null; 
    /**
     * Comment for <code>add_group_</code>
     */
    protected String add_group_;
    /**
     * Comment for <code>config_dir_</code>
     */
    protected String config_dir_;
    
    /**
     * @param addgroup
     * @param config_dir_
     */
    public MulticastServer(String addgroup, String config_dir_) {        
        add_group_ = addgroup;
        this.config_dir_ = config_dir_;
    }
        
    /**
     * @param infilename
     * @return
     */
    public static String get_ior_from_file(String infilename) {
        // Read data from the file to be transferred
        String inFileName = infilename;
        java.io.FileInputStream inStream = null;
        String ior_str;
        
        java.io.File isFileExist = new java.io.File(infilename);
        
        if (isFileExist.exists()) {
            try {
                inStream = new java.io.FileInputStream(inFileName);
            } catch (java.io.FileNotFoundException ex) {
                System.err.println(
                      "Can't open file " + inFileName + ": " + ex.getMessage());
            }
            
            byte[] file = null;
            
            try {
                file = new byte[inStream.available()];
                inStream.read(file);
                inStream.close();
            } catch (java.io.IOException ex) {
                System.err.println(
                      "Can't read from " + inFileName + ": " + ex.getMessage());
            }
            
            ior_str = new String(file);
        } else {
            ior_str="file_not_exist";
        }
        return ior_str;
    }
    
    /* (non-Javadoc)
     * @see java.lang.Runnable#run()
     */
    public void run() {
        InetAddress groupAddress = null;
        while (true) {
            byte[] mem = new byte[1000];
            DatagramPacket recv = new DatagramPacket(mem, mem.length);
            
            // Receiving request from clients
            MulticastSocket msocket = null;
            DatagramSocket socket;
            
            try {
                msocket = new MulticastSocket(ms_port);
                msocket.joinGroup(InetAddress.getByName(add_group_));
                msocket.receive(recv);
                byte[] ior_req = recv.getData();
                
                String ior_filename = new String(ior_req);
                ior_req = null;
                
                System.out.println(
                        "receive multicast request from "
                        + recv.getAddress().getHostName()
                        + ":"
                        + recv.getPort());
                
                msocket.disconnect();
                msocket.close();
                
                // Gros dodo pendant 3 seconde
                try {
                    Thread.sleep(3000);
                } catch (InterruptedException ex) {
                    // None
                }
                
                // Send IOR if request from client has been received
                // Read IOR from file
                String ior_str =
                    get_ior_from_file(config_dir_ + "\\" + ior_filename);				
                
                if (ior_str != "file_not_exist") {
                    System.out.println("Sending IOR to client...");
                    InetAddress client_address = recv.getAddress();
                    
                    DatagramPacket envoi =
                        new DatagramPacket(
                                ior_str.getBytes(),
                                ior_str.length(),
                                client_address,
                                s_port + 1);
                    
                    socket = new DatagramSocket();
                    socket.send(envoi);
                    System.out.println(
                            "IOR sent to "
                            + client_address.getHostName()
                            + ":"
                            + s_port);
                    socket.disconnect();
                    socket.close();
                }
            } catch (IOException e) {
            }
        }
    }
}
