/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.openccm.corba.idl2java;

// Package dependencies.
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;


/**
 * This application wraps the JacORB 2.1 idl2java compiler.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */
public class IdlToJava
     extends IdlToJavaApplication
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    
    /** The default constructor */
    public IdlToJava()
    {
    }
    
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    
    /**
     * Get the JacORB IDL Compiler arguments.
     * 
     * @return A string with all arguments.
     */
    private String[]
    getArguments()
    {
        List args = null;
        String key = null,
               value = null;
        String[] includes = null;
        Map mappings = null;
        Set mapping_keys = null;
        
        args = new ArrayList();
        
        // Default arguments
        args.add("-jdk14");
        
        // Add the destination directory
        args.add("-d");
        args.add( getDestinationDirectory() );
        
        // Add Include directory list
        includes = getIncludeDirectories();
        for (int i=0; i<includes.length; i++)
        {
            args.add("-I" + includes[i].replace('\\','/'));
        }

        // Add Package mappings
        mappings = getPackageMappings();
        mapping_keys = getPackageMappings().keySet();
        for (Iterator it=mapping_keys.iterator(); it.hasNext(); )
        {
            key = (String) it.next();
            value = (String) mappings.get(key);
            args.add("-i2jpackage");
            args.add(key + ":" + value);
        }

        // Add the file to parse
        args.add(getInputFile());
        
         return (String[])args.toArray(new String[0]);
    }

    // ==================================================================
    //
    //  Public methods for org.objectweb.util.cmdline.api.Application
    //
    // ==================================================================

    /**
      * Starts the main function.
      *
      * @param args The command line arguments.
      *
      * @return The status of the application.
      */
    public int
    start(String[] args)
    {
        parse_cmdline(args);
        
        try
        {
            org.jacorb.idl.parser.main( getArguments() );
        } catch (Exception e) {
            e.printStackTrace();
            return -1;
        }
        return 0;
    }
    
    // ==================================================================
    //
    // Public methods
    //
    // ==================================================================

    public static void
    main(String[] args)
    {
        IdlToJava app = new IdlToJava();
        app.runMain(args);
    }
}
