/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2005 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): Philippe Merle.

====================================================================
$Id: IdlToJavaApplicationBase.java,v 1.2 2005/07/06 11:47:50 merle Exp $
====================================================================*/

package org.objectweb.openccm.corba.idl2java;

// Package dependencies.
import org.objectweb.util.cmdline.api.CommandLine;
import org.objectweb.util.cmdline.api.OptionArgument;
import org.objectweb.util.cmdline.api.OptionArguments;
import org.objectweb.util.cmdline.lib.ApplicationBase;
import org.objectweb.util.cmdline.lib.DefaultCommandLine;
import org.objectweb.util.cmdline.lib.DefaultOptionArgument;
import org.objectweb.util.cmdline.lib.DefaultOptionArguments;

import org.objectweb.openccm.command.lib.ReleaseInfo;

/**
 * Base class for an IDL to Java application.
 * This class manages the command line.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */
public abstract class IdlToJavaApplicationBase
              extends ApplicationBase
           implements IdlToJavaOperations
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    
    /** The output filename option. */
    protected OptionArgument destdir_opt_; // -d <destdir>

    /** The Preprocessor include option. */
    protected PreprocessorOption include_opt_; // -IDIR

    /** The package mapping option. */
    protected OptionArguments i2jpackage_opt_; // -i2jpackage x:a.b

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    
    /**
     * The default constructor.
     */
    public 
    IdlToJavaApplicationBase()
    {
        this(new DefaultCommandLine("idl2java",
                                    "omg_idl_file",
                                    "Generate Java Mapping from an OMG IDL 2.0 file.",
                                    true),
             true);
    }

    /**
     * The constructor with a provided command line manager.
     *
     * @param commandLine The provided command line manager.
     * @param withDefaultOptions True to add default options in the command line.
     */
    public IdlToJavaApplicationBase(CommandLine commandLine,
                                    boolean withDefaultOptions)
    {
        this(commandLine,withDefaultOptions,true);
    }

    /**
     * The constructor with a provided command line manager.
     *
     * @param commandLine The provided command line manager.
     * @param withDefaultOptions True to add default options in the command line.
     * @param withPreprocessorOptions True to add preprocessor options in the command line.
     */
    public IdlToJavaApplicationBase(CommandLine commandLine,
                                    boolean withDefaultOptions,
                                    boolean withPreprocessorOptions)
    {
        // Calls the default ApplicationBase constructor.
        super(commandLine, withDefaultOptions);

        // Add the destination directory option
        destdir_opt_ = new DefaultOptionArgument(
                            "-d",
                            "destdir",
                            "Set the destination directory name, default is .",
                            ".");
        commandLine.addOption(destdir_opt_);
        
        // Add the include directory option
        include_opt_ = new OptionIDIR(this);
        commandLine.addOption(include_opt_);
        
        // Add the package mapping option
        i2jpackage_opt_ = new DefaultOptionArguments(
                            "-i2jpackage",
                            "idl.module:java.pkg",
                            "Define the target Java package for an OMG IDL module");
        commandLine.addOption(i2jpackage_opt_);
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.util.api.Identifiable
    //
    // ==================================================================

    /**
     * Obtains its identity.
     *
     * Should be defined in subclasses.
     *
     * @return Its identity.
     */
    public String
    getIdentity()
    {
        return getCommandLine().getLabels()[0]
             + ' ' + ReleaseInfo.VERSION;
    }

    // ==================================================================
    //
    // Public methods for org.objectweb.util.cmdline.api.Application
    //
    // ==================================================================

    /**
     * Obtains the associated version information.
     *
     * @return The associated version information.
     */
    public String[]
    getVersionInformation()
    {
        String[] result = super.getVersionInformation();
        result[0] = ReleaseInfo.NAME_SHORT + ' '
                  + getIdentity()
                  + " (on top of "
                  + System.getProperty("orb.name", "UNKNOWN")
                  + ' '
                  + System.getProperty("orb.version", "X.X")
                  + ')';
        return result;
    }

    // ==================================================================
    //
    // Public methods
    //
    // ==================================================================

}
