/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.openccm.task;

// Package dependencies.
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.StringTokenizer;


/**
 * This class configure a standard launcher application to run an idl2java command.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */
public class Idl2JavaApplication
     extends LauncherApplication
{
    // ==================================================================
    //
    // Internal states.
    //
    // ==================================================================

    /** The file to parse. */
    protected String file_;

    /** The destination directory. */
    protected String destdir_;

    /** The directory list to add to the search path. */
    protected String includes_;

    /** Ordered list of Mapping elements. */
    protected List mapping_elements_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     */
    public Idl2JavaApplication()
    {
        // Init internal states
        file_ = null;
        destdir_ = null;
        includes_ = null;
        mapping_elements_ = new ArrayList();
    }
    
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    
    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================
    
    /**
     * Set the file to parse.
     *
     * @param file - The file name.
     */
    public void
    setFile(String file)
    {
        file_ = file;
    }

    /**
     * Set the destination directory.
     *
     * @param dir - The directory name.
     */
    public void
    setDestdir(String dir)
    {
        destdir_ = dir;
    }

    /**
     * Set a directory list to add to the search path.
     *
     * @param dirs - A directory list.
     */
    public void
    setIncludes(String dirs)
    {
        includes_ = dirs;
    }

    /**
     * Create an inner element for Package Mapping.
     */
    public PackageMapping
    createMapping()
    {
        PackageMapping mapping = null;
        
        mapping = new PackageMapping();
        // Add to ordered list
        mapping_elements_.add(mapping);
                
        return mapping;
    }
    
    /**
     * Configure the task.
     */
    public void
    configure()
    {
        StringTokenizer st = null;
        
        setXmlFile( project_properties_.getProperty("OpenCCM_HOMEDIR") + "/xml/launcher/IdlToJava.xml" );
        
        // Add the destination directory
        if (destdir_ != null)
        {
            addArgument("-d");
            addArgument(destdir_);
        }
            
       // Add includes
       if (includes_ != null)
       {
           st = new StringTokenizer(includes_, ",");
           while (st.hasMoreTokens())
           {
               addArgument( "-I" + st.nextToken().trim() );
           }
       }
       
       // Add package mappings
       for (Iterator it = mapping_elements_.iterator(); it.hasNext();)
       {
           addArgument("-i2jpackage");
           addArgument( ((PackageMapping) it.next()).asArgument() ); 
       }
       
       // Add the file to parse
       addArgument(file_);
    }
}
