/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frederic
Contributor(s): ___________________________________________________.

====================================================================*/

package org.objectweb.openccm.Deployment;


import java.io.IOException;
import java.net.URL;

import org.objectweb.openccm.descriptor.componentassembly.beans.*;
//import org.objectweb.openccm.descriptor.componentassembly.ccm.*;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.root.*;
import org.objectweb.openccm.descriptor.*;
import org.omg.Components.Deployment.Assembly;
import org.omg.CosNaming.NamingContextExtHelper;

//import hfinder package for setting the deployTable

//import org.objectweb.openccm.Deployment.components.HFinder.*;
/**
 * AssemblyImpl is the top level implementation of the 
 * assembly behaviour. 
 *
 * @author <a href="mailto:frederic.briclet@lifl.fr">Briclet Frederic</a>
 *
 * @version 0.1
 */
public class AssemblyImpl extends org.omg.Components.Deployment.AssemblyPOA 
                          implements AssemblyConfigurator{


        
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================


    // xml handler path
    private URL xmlFilePath;

    // Console for emittion of message
    private org.objectweb.util.cmdline.api.Console console;

    private java.util.zip.ZipFile zipFile;
    
    private java.io.File tmpZipFile;

    // State of the assembly    
    //private org.omg.Components.Deployment.AssemblyOperations etat;
    AssemblyBase etat ;
    // ==================================================================
    //
    // Constructor
    //
    // ==================================================================
   
    public 
    AssemblyImpl(URL xmlFilePath)
    {
        this.xmlFilePath=xmlFilePath;
        etat=new AssemblyBase(this);
    }

    
    public ComponentassemblyDeployerHandler 
    configure(ComponentassemblyDeployerHandler context)
    {
       try{
         
            /*Store reference on the name service*/
            context.connectNamingcontext(NamingContextExtHelper.narrow(
                                        org.objectweb.openccm.corba.TheNameService
                                        .getNamingContext()
                                        .getNamingContext()));

            try{
                  org.objectweb.openccm.OpenCCM_DCI.DCIManager
                    DCI=
                    org.objectweb.openccm.
                    OpenCCM_DCI.DCIManagerHelper.
                    narrow(org.objectweb.openccm.corba
                           .TheORB.resolve_initial_reference("DCIManager"));    
                  
                  context.connectHomefinder(DCI.provide_home_finder());
                  context.connectHomeregistration(DCI.provide_home_registration());
                  context.connectDciinfo(DCI.provide_dci_information());
                  zipFile=new java.util.zip.ZipFile(xmlFilePath.getPath());
                  context.connectZipEntryRetriever(new ZipEntryRetriever(zipFile));
                  
            }
            catch(Exception e){
                e.printStackTrace();
                System.err.println
                    ("CCM_deploy >> DCIManager not start,  HomeFinder functionnalities disable !");
                System.err.println
                    ("CCM_deploy >> To start DCIManager execute dci_start <dci_name> command");
            }        
        }
        catch(Exception e){
            System.err.println("Problem occured during setting of the deployTable");
        }
        return context;
    }
 
      public Assembly getAssembly(){
          org.omg.CORBA.Object ref =
                     this._this_object(org.objectweb.openccm.corba.TheORB.getORB());
        
          return   org.omg.Components.Deployment.AssemblyHelper.narrow(ref);
      }
    
      public void removeAssembly(){
             
      }
    
      public ComponentassemblyBean getComponentassemblyTree()    
      {
          try{
          // get the ORB
         org.omg.CORBA.ORB orb
             = org.objectweb.openccm.corba.TheORB.getORB();
         //console.message("Got the ORB");

         // inits OpenCCM runtime
         org.objectweb.openccm.Components.Runtime.init (orb);
         //console.message("OpenCCM runtime is ready");

         java.io.InputStreamReader reader ;
         
         java.net.URL url=xmlFilePath; //new URL(xmlFilePath);          
         tmpZipFile =java.io.File.createTempFile(System.currentTimeMillis()+"","aar");
          java.io.FileOutputStream fos= new java.io.FileOutputStream(tmpZipFile);

    
           java.io.InputStream bis=url.openStream();
   
           byte [] byteArray= new byte[32000];
           int readed=bis.read(byteArray,0,32000);                        
    
           System.err.print("Downloading "+xmlFilePath+" [");
           while(readed>0)                      
               {   
                   fos.write(byteArray,0,readed);
                   readed=bis.read(byteArray,0,32000);
                   System.err.print("*");
               }
           System.err.println("]");
           fos.flush();
           fos.close();
    
           zipFile= 
               new java.util.zip.ZipFile(tmpZipFile);
                                   
       
        
         for(java.util.Enumeration entries=zipFile.entries();entries.hasMoreElements();)
             {
        
                 java.util.zip.ZipEntry ze=(java.util.zip.ZipEntry)entries.nextElement();
                 //System.out.println("Filename:"+ze.getName());
                 if(ze.getName().endsWith(".cad"))
                     {
                         reader=new java.io.InputStreamReader
                             (zipFile.getInputStream(ze));
                        
                        return org.objectweb.openccm.descriptor
                             .componentassembly.beans.ComponentassemblyBeanImpl
                             .unmarshalBean(reader,true);
                     }                        
             }
        }
        catch(Exception e){
                e.printStackTrace(); 
        }
        return null;
      }
    
   public void 
   deleteTemporaryFile()
   {
           try{
               zipFile.close();
              tmpZipFile.delete();
           }
           catch(Exception e)
           {//Not a problem the temporaryfile will be removed by the OS
           }

   }
      
      
      
    /*Delegation operation to the state assembly*/
    public void 
    build() 
    throws org.omg.Components.CreateFailure
    {
        etat.build();
    }


    public void 
    tear_down() 
    throws org.omg.Components.RemoveFailure 
    {
        etat.tear_down();
    }
    


    public org.omg.Components.Deployment.AssemblyState
    get_state()
    {
        return etat.get_state();
    }

    public void registerAssembly(){
        etat.registerAssembly();
    }
    
    public void 
    unregisterAssembly()
    {
        try{
            
            etat.unregisterAssembly();
        }
        catch(Exception e){}

    }
}
