/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frederic
Contributor(s): ___________________________________________________.

====================================================================*/

package org.objectweb.openccm.OpenCCM_DCI.cif;

import org.objectweb.openccm.OpenCCM_DCI.*;
import org.objectweb.openccm.corba.*;

/**
 * This is the implementation of the 
 * Components::Deployment::ComponentServer interface.
 * 
 * This class inherits from the skeleton
 * generated by the OpenCCM's CIF to Java mapping generator.
 *
 * @author <a href="mailto:Frederic.Briclet@lifl.fr">Briclet Frederic</A>
 */
public class ComponentServerSegImpl 
    extends  org.objectweb.openccm.OpenCCM_DCI.
             ComponentServerManagerSessionComposition.ComponentServerSeg
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    //Configuration of the component server
    private org.omg.Components.ConfigValue[] configuration;
    //Cookie connection with NodeManager
    private org.omg.Components.Cookie cookie;
    //A reference on the main interface
    private org.objectweb.openccm.OpenCCM_DCI.ComponentServerManagerCCM CS;
    //Boolean used to manager removal process
    private boolean removed;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================
    public ComponentServerSegImpl(){
        super();  
        //Retrieve reference of the main context
        
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    
    private org.objectweb.openccm.OpenCCM_DCI.ComponentServerManagerCCM
    getCS()
    {
        if(CS==null)
           CS=(org.objectweb.openccm
            .OpenCCM_DCI.ComponentServerManagerCCM)get_context(); 
        return CS;
    }
    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================
    public void 
    configuration(org.omg.Components.ConfigValue[] configuration)
    {
        this.configuration=configuration;
    }
    
    public void
    cookie(org.omg.Components.Cookie cookie)
    {
      this.cookie=cookie;
    }

    // ==================================================================
    //
    // org.omg.Components.Deployment.ComponentServer methods.
    //
    // ==================================================================

    /**
     * The accessor method to the configuration attribute
     * @return the current configuration
     */
    public  org.omg.Components.ConfigValue[]
    configuration(){
        return this.configuration;
    }

    /**
     * This method return the parent ServerActivator
     * @return the parent ServerActivator
     */
    public  org.omg.Components.Deployment.ServerActivator
    get_server_activator(){
        return getCS().get_connection_parent_server_activator();
    }

    /**
     * Create a new container with specified config value.
     * @param config the config value to use
     * @return the container created.
     */     
    public
    org.omg.Components.Deployment.Container
    create_container(org.omg.Components.ConfigValue[] config)
        throws org.omg.Components.CreateFailure,
               org.omg.Components.Deployment.InvalidConfiguration
    {
        
        //Retrieve a connection on the ContainerManagerHome
        ContainerManagerHome conthome=
            getCS().get_connection_container_manager_home();
        //create a new ContainerManager
        org.objectweb.openccm.OpenCCM_DCI.ContainerManager contm=
            conthome.create();
        //Setting up its configuration
        contm.config(config);
        
        try{
            //connect the ContainerManagerRegistration interface
            contm.connect_container_manager_registration(getCS().provide_container_manager_registration());       
            //connect the parent ComponentServer
            contm.connect_component_server(getCS().provide_component_server());
            //connect the ComponentInstallation to use
            contm.connect_component_installation(get_context().get_connection_component_installation());
        }
        catch(org.omg.Components.AlreadyConnected e)
            {
                System.err.println(e.getMessage());
                throw new org.omg.Components.CreateFailure();
            }
        try{
            // configure complete the ContainerManager
            contm.configuration_complete();
        }
        catch(org.omg.Components.InvalidConfiguration e2)
            {
                 System.err.println(e2.getMessage());
                throw new  org.omg.Components.Deployment.InvalidConfiguration();
            }
        //Return a reference of the provided Container facet.
        return contm.provide_container();        
    }
    
    /**
     * Remove a  container child.
     */   
    public void
    remove_container(org.omg.Components.Deployment.Container cref)
    throws org.omg.Components.RemoveFailure
    {
        //Retrieve connection with all ContainerManager
        org.objectweb.openccm.OpenCCM_DCI.
            ComponentServerManagerPackage.container_managersConnection 
            connect[]=getCS().get_connections_container_managers();
        //compare all container reference to find the right container
        // and remove it.
        for(int i=0;i<connect.length;i++)
            if(connect[i].objref.
               provide_container().
               _is_equivalent(cref))
                {
                    connect[i].objref.remove();
                    return ;
                }
        //The container reference was not a child of this component server
        throw new org.omg.Components.RemoveFailure();        
    }

    /**
     * This method provide a list of all the current container children
     */
    public org.omg.Components.Deployment.Container[]
    get_containers()
    {
        //Retrieve all the ContainerManager connection
        org.objectweb.openccm.OpenCCM_DCI.
            ComponentServerManagerPackage.container_managersConnection 
            connect[]=getCS().get_connections_container_managers();
        //build a container array
        org.omg.Components.Deployment.Container[] cont=
            new org.omg.Components.Deployment.Container[connect.length];
        //Fill the container array
        for(int i=0;i<connect.length;i++)
            cont[i]=connect[i].objref.provide_container();
        //return the array.
        return cont;                
       
    }

    //
    // IDL:omg.org/Components/Deployment/ComponentServer/remove:1.0
    //
    /***/
    public void
    remove()
    throws org.omg.Components.RemoveFailure 
    {
        if(!removed)
            {
                removed=true;
                
                try
                    {
                        //unregister the componnentservermanager
                        get_context().get_connection_component_server_manager_registration()
                            .unregister_component_server_manager(cookie);     
                        //retrieve all connection with containermanager
                        org.objectweb.openccm.OpenCCM_DCI.
                            ComponentServerManagerPackage.container_managersConnection 
                            connect[]=getCS().get_connections_container_managers();
                        
                        //remove all the container
                        for(int i=0;i<connect.length;i++)
                            connect[i].objref.remove();
                        //remove the main segment
                        getCS().remove();                
                    }
                catch(Exception e )
                    {
                        System.out.println("Cannot disconnect ComponentServer/Node");
                        e.printStackTrace();
                        throw new org.omg.Components.RemoveFailure();
                    }
            }
       
    }
  


}
