/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frederic
Contributor(s): ---------------------------------------------

====================================================================*/

package org.objectweb.openccm.OpenCCM_DCI.cif;

import org.objectweb.openccm.OpenCCM_DCI.*;

/**
 * This is the implementation of the OMG IDL3 demo3::Consumer component type.
 *
 * This class inherits from the skeleton
 * generated by the OpenCCM's CIF to Java mapping generator.
 *
 * @author <a href="mailto:Frederic.Briclet@lifl.fr">Briclet Frederic</A>
 */

public class NodeManagerHomeImpl
        extends org.objectweb.openccm
                .OpenCCM_DCI.NodeManagerSessionComposition
                .NodeManagerHomeImpl
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    //Node Properties file path
    private String npdFilePath;
    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public
    NodeManagerHomeImpl()
    {
      super();
    }
    
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for creation of component segments.
    //
    // ==================================================================

    /**
     * Create an executor segment from its identifier.
     *
     * @param segid The executor segment identifier.
     */
    public org.omg.Components.ExecutorSegmentBase
    create_executor_segment(int segid)
    {
        switch(segid){
            case 0
                : NodeManagerImpl nmi=
                  new NodeManagerImpl(npdFilePath);  
                  return nmi;    
            case org.objectweb.openccm.OpenCCM_DCI.
                 NodeManagerSessionComposition.
                 ComponentServerManagerRegistrationSeg._segment_id_value
                 : return new ComponentServerManagerRegistrationImpl();
            case org.objectweb.openccm.OpenCCM_DCI.
                 NodeManagerSessionComposition.
                 ServerActivatorSeg._segment_id_value
                 : return new ServerActivatorImpl();
            case org.objectweb.openccm.OpenCCM_DCI.
                 NodeManagerSessionComposition.
                 ComponentInstallationSeg._segment_id_value
                : return new ExtComponentInstallationImpl();
            case org.objectweb.openccm.OpenCCM_DCI.
                 NodeManagerSessionComposition.
                 NodeInformationSeg._segment_id_value
                 : return new NodeInformationSegImpl();
            default:System.err.println("Bad segment request");
                return null;
        }
        
    }

    // ==================================================================
    //
    // Methods for the deployment.
    //
    // ==================================================================

    /**
     * This method is called by the OpenCCM Component Server
     * to create a home instance.
     */
    public static org.omg.Components.HomeExecutorBase
    create_home()
    {
        return new NodeManagerHomeImpl();
    }
    
    /**
     * Factory method creating NodeManager with the specified 
     * configuration file.
     * @param npdFilePath The NodePropertiesDescriptor
     */
    public  org.omg.Components.EnterpriseComponent
    create_node(String npdFilePath){        
        this.npdFilePath=npdFilePath;        
        return create();
    }
    
    
}
