/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA
Initial developer(s): Briclet Frederic
Contributor(s): ___________________________________________________.

====================================================================*/

package org.objectweb.openccm.deploytool;
/**
 * TearDownTool allow to tear down an assembly from a console or
 * from java code.
 *
 * @author <a href="mailto:frederic.briclet@lifl.fr">Briclet Frederic</a>
 *
 * @version 0.1
 */
public class TearDownTool {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    /*AssemblyName to tear_down */
    private String assemblyName=null;
    /*Ior file to use to stop a component*/
    private String iorFile=null;
    /*The file URL*/
    private String fileURL=null;
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    private void       
    computeArgs(String args[])
    {
        for(int i=0;i<args.length;i++){      
            if(args[i].startsWith("-N-F"))
               this.iorFile=args[i].substring(4);
            else if(args[i].startsWith("-N-U")){
                this.fileURL=args[i].substring(4);                   
            }
            else if(args[i].startsWith("-N"))
                this.assemblyName=System.getProperty("Assemblies_ns_dir")+
                                  args[i].substring(2);
               }           
    }    
    
    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /**
     * Default constructor
     * @param assemblyToTearDown the assembly name
     */
    public TearDownTool(String args[]){
        try{
            computeArgs(args);
            tearDown();
        }    
        catch(Exception e)
            {
                /*System.err.println(e.getMessage());*/
                if(iorFile!=null||fileURL!=null){
                /*    System.err.println("Cannot stop the component denote by the following path"+
                                    iorFile);*/
                }
                else{
                    System.err.println("Cannot tear_down the assembly "+assemblyName);
                }
            }
        
        
    }

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================
    /**
     * Method allowing to tear down an assembly 
     * @param assemblyToTearDown the assembly name
     */
    public void 
    tearDown()
    throws Exception
    {
        
        if(assemblyName!=null)//Stopping assembly case
            {
                org.omg.CosNaming.NamingContextExt context=
                    org.omg.CosNaming.NamingContextExtHelper
                    .narrow(org.objectweb.openccm.corba.TheNameService
                            .getNamingContext()
                            .getNamingContext());
                
                org.omg.Components.Deployment.Assembly assemblyObject=
                    org.omg.Components
                    .Deployment.AssemblyHelper
                    .narrow(context.resolve(context.to_name(assemblyName)));   
                
                //TearDown the assembly
                assemblyObject.tear_down();
            }
        else {//Stopping a classical component case            
            java.io.InputStream in ;
            if(fileURL!=null)
                {
                //Create an url with the ior file
                java.net.URL URL=new java.net.URL(fileURL);
                //create a stream
                in=URL.openStream();
                }
            else 
                {
                   in=new java.io.FileInputStream(iorFile); 
                }                            
            
            byte [] tab=new byte[in.available()];
            //read all the stream
            in.read(tab);
            //convert to string
            String ior=new String(tab);
            //retrieve the corba reference
            org.omg.CORBA.Object obj=
                org.objectweb.openccm.corba.TheORBSingleton.getORB().
                string_to_object(ior.trim());
            //retrieve a component
            org.omg.Components.CCMObjectHelper.narrow(obj).remove(); 
        }
                
    }

    public static void main(String args[]){
        //Initialize the ORB
        org.objectweb.openccm.corba.TheORB.initialize(args);
        //create a new TearDownTool to realise the tear_down process
        new TearDownTool(args);    
        
        org.objectweb.openccm.corba.TheORB.destroy();
    }
    
}
