/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base;

//Package dependencies.
import org.objectweb.openccm.descriptor.ZipEntryRetriever;

/**
 * The ChildDeployerContext is a abstract basic implementation in charge to provide
 * generic methods used by all the children deployers of componentassembly. The softpkg
 * deployer and corbacomponent deployer are considered as children such there are 
 * connected on the componentassembly tree representation  
 *
 * @author <a href="mailto:briclet@lifl.fr">Frederic Briclet</a>
 *
 * @version 0.1
 */
public abstract class ChildDeployerContext 
    extends DeployerContext 
{
    //  ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    
    //The root deployer context which handle all the services and tools
    private RootDeployerContext root;
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    //  ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    
    //  ==================================================================
    //
    //  Public .
    //
    // ==================================================================
    
    /**
     * ConnectRootDeployerContext method is used to connect the root context
     * to the current deployer. When the root deployer context is connected
     * all its services are available for the deployer.
     * 
     * @param The rootDeployerContext to connect
     */
    public void 
    connectRootDeployerContext(RootDeployerContext root) 
    {
        this.root = root;
    }
    
    /**
     * Method accessor to retrieve the RootDeployerContext
     * 
     * @return The root deployer context
     */
    public RootDeployerContext 
    getRootDeployerContext()
    {
        return root;
    }

    /**
     * Method accessor to the zipEntryRetriever connected to the root
     * deployer context. 
     * 
     * @return The zipEntryRetriever used to acces to the zipEntries
     */
    public ZipEntryRetriever getZipEntryRetriever()
    {
        return getRootDeployerContext().getZipEntryRetriever();
    }
    
    /**
     * Method accessor to get logger tool.
     * 
     * @return The current DeploymentLogger available to log message and event.
     */
    public DeploymentLogger getLogger()
    {
        return getRootDeployerContext().getDeploymentLogger();
    }
    
}
