/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base;


/**
 * The Depoyer interface specified all the methods that a valid deployer must
 * implements to be introduced in the deployer architecture
 *
 * @author <a href="mailto:briclet@lifl.fr">Frederic Briclet</a>
 *
 * @version 0.1
 */
public interface Deployer {
    
    /**
     * The visit method is in charge to process all the children deployer
     * that this deployer is able to process. 
     * @param depl
     * @throws FatalDeploymentException if the Deployer give in parameter 
     * is not supported.
     */
    public void 
    visit(Deployer depl)
    throws FatalDeploymentException;
    
    /**
     * The traverse method is in charge to schedule the processing of all the 
     * deployers given in @param deployers. It must invoke this processing on
     * the @param deployer which is in charge of this deployer. The main 
     * interest of this method is to extract the scheduling preoccupation and 
     * allow to implements different sceduling policy. 
     *  
     * @param deployer The deployer in charge to process the @param deployers.
     * @param deployers The deployers to process
     * @throws FatalDeploymentException if a fatal error occured during the 
     * deployment or if the @param deployers give in parameter are not supported.
     */
    public void 
    traverse(Deployer deployer,Deployer [] deployers)
    throws FatalDeploymentException;
    
    /**
     * The getStatus method is used to retrieved the current status 
     * of the deployer.
     * @return The deployer current status.
     */
    public DeployerState getStatus();
    
    /**
     * The getIdentifier method must provide a string identifier of the
     * deployer.
     * 
     * @return A string identifier of the deployer
     */
    public String getIdentifier();

}
