/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base;

/**
 * This interface describes all the ressource required by a life cycle manager
 * to manage a deployer.
 *
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public interface LifeCycleManager 
{
    /**
     * This method return the current status of the deployer
     * monitored.
     * 
     * @return The deployer current status 
     */
    public DeployerState 
    getStatus();
    
    /**
     * This method indicates to the manager that the deployer 
     * ended succefully the current step. So the deployer can be 
     * put in the following state.
     *  
     * @return The new deployer state.
     */
    public DeployerState 
    stepEndedSuccessFully();
    
    /**
     * Connect to this life cycle manager the deployer to
     * monitor.
     * 
     * @param deployer to monitor
     */
    public void 
    connectManagedDeployer(Deployer deployer);
    
    /**
     * Connect the logger to use to log information
     * 
     * @param logger to use to signal event
     */
    public void 
    connectLogger(DeploymentLogger logger);
    
    /**
     * This method indicates to the manager that the 
     * deployer has aborted the current step. The manager
     * return the new state.
     * 
     * @return The new deployer state.
     */
    public DeployerState stepAborded();
    
}
