/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.binder;

import org.objectweb.openccm.descriptor.componentassembly.Componentsupportedinterface;
import org.objectweb.openccm.descriptor.componentassembly.beans.ComponentsupportedinterfaceBean;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.ChildDeployerContext;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.InitializationError;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.installer.ComponentinstantiationDeployer;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.util.FindbyDeployer;

/**
 * This class describes all the context connection required for the 
 * componentsupportedinterface deployer job.
 *
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public class ComponentsupportedinterfaceDeployerContext
    extends ChildDeployerContext {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    private ComponentsupportedinterfaceBean componentsupportedinterface;
    private FindbyDeployer findbyDeployer;
    private ComponentinstantiationDeployer componentinstantiationDeployer;
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    // ==================================================================
    //
    //  Public accessor methods.
    //
    // ==================================================================
    
    /**
     * @return
     */
    public Componentsupportedinterface 
    getComponentsupportedinterface() 
    {
        return componentsupportedinterface;
    }

    /**
     * @return
     */
    public FindbyDeployer 
    getFindbyDeployer()
    {
        return findbyDeployer;
    }

    /**
     * @param componentsupportedinterface
     */
    public void 
    connectComponentsupportedinterface
    (ComponentsupportedinterfaceBean componentsupportedinterface) 
    {
        this.componentsupportedinterface = componentsupportedinterface;
        connectDeployerDescription(componentsupportedinterface);
    }

    /**
     * @param deployer
     */
    public void 
    connectFindbyDeployer(FindbyDeployer deployer)
    {
        findbyDeployer = deployer;
    }

    /**
     * @return
     */
    public ComponentinstantiationDeployer 
    getComponentinstantiationDeployer() 
    {
        return componentinstantiationDeployer;
    }
    
    /**
     * @param deployer
     */
    public void 
    connectComponentinstantiationDeployer(ComponentinstantiationDeployer deployer)
    {
        componentinstantiationDeployer = deployer;
    }

    /**
     * This initialization method is used to check that all the services and 
     * information required to deploy are presents. If all is OK the deployer 
     * is put in inactive deployer state waiting for the deployment processing.
     * 
     * @exception InitializationError is thrown if a problem is detected 
     */
    public void 
    initialize() 
    throws InitializationError 
    {
        if (getComponentsupportedinterface() == null)
            getErrorManager().submitException(
                new InitializationError(
                    this,
                    "Connection on componentsupportedinterface is required"
                        + "check the handler code it must specify this connection"));

        if (getComponentsupportedinterface().getComponentinstantiationref()
            == null
            && getFindbyDeployer() == null)
            getErrorManager().submitException(
                new InitializationError(
                    this,
                    "At least one of componentinstantiationref/findby child"
                        + "must be specified in componentsupportedinterface element,"
                        + "check you componentfiles element description.\n"
                        + getStringifiedDeployerDescription()));
        getLifeCycleManager().stepEndedSuccessFully();
    }
    
}
