/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): Sylvain Leblanc___________________________.

====================================================================*/

package org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.binder;

//Importation of the needed packages

/**
 * A connectinterfaceDeployer to establish interface connections.
 *
 * @author <a href="mailto:frederic.briclet@lifl.fr">Briclet Frederic</a>
 *
 * @version 0.1
 */

public class ConnectinterfaceDeployer 
       extends ConnectinterfaceDeployerContext 
    {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    //Internal exception to warn of impossibility to resovle a reference
    public class CannotResolveReferenceException extends Exception{};  
   
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================    
    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================
    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================


    /**
     * Establish the connectinterface connection.
     * 
     * @throws ConnectInterfaceEstablishmentFailureException thrown if
     * a problem occured during connecting.
     */
    public void deploy()
    throws ConnectInterfaceEstablishmentFailureException
    {
         try{
             org.omg.CORBA.Object providedObject=null ;
             /*Proceed a Providesport tag*/
             if(getProvidesportDeployer()!=null){
                 providedObject = getProvidesportDeployer().getProvidedPort();
             }/*Proceed the homeinterface tag*/
             else if(getHomeinterfaceDeployer()!=null){
                 providedObject =getHomeinterfaceDeployer().getHome();    
             }/*Proceed the component supported interface tag*/
             else if(getComponentsupportedinterfaceDeployer()!=null){
                 providedObject=getComponentsupportedinterfaceDeployer().resolveComponent();
             }/*proceed the existing interface tag*/
             else if(getExistinginterfaceDeployer()!=null){
                 providedObject= getExistinginterfaceDeployer().getCorbaObject();
             }  
                            
             if(providedObject==null)
                 throw new ConnectInterfaceEstablishmentFailureException(this,null);
             
              getUsesportDeployer().establishConnection(providedObject);             

         }
         catch(Exception e)
             {
               throw new ConnectInterfaceEstablishmentFailureException(this,e);
             }
        getLifeCycleManager().stepEndedSuccessFully();
    }
    
    /**
     * Break the connectinterface.
     * 
     * @exception ConnectInterfaceBrekingFailureException is thrown if a problem
     * occured during disconnecting.  
     */ 
    public void 
    tearDown()
    throws ConnectInterfaceBreakingFailureException
    {
        try
            {
                getUsesportDeployer().breakConnection();    
            }
        catch(Exception e)
            {
                throw new ConnectInterfaceBreakingFailureException(this,e);
            }
        getLifeCycleManager().stepEndedSuccessFully();
    } 

}
