/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.binder;

import org.objectweb.openccm.descriptor.componentassembly.Homeinterface;
import org.objectweb.openccm.descriptor.componentassembly.beans.HomeinterfaceBean;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.ChildDeployerContext;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.InitializationError;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.installer.HomeplacementDeployer;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.util.FindbyDeployer;

/**
 * The homeinterface deployer context defines all the connection requires for
 * home interface establishment.
 *
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public class HomeinterfaceDeployerContext 
       extends ChildDeployerContext 
    {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================    
    private HomeinterfaceBean homeinterface;
    private FindbyDeployer findbyDeployer;
    private HomeplacementDeployer homeplacementDeployer;
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    // ==================================================================
    //
    //  Public accessor methods.
    //
    // ==================================================================    
    /**
     * @return
     */
    public FindbyDeployer 
    getFindbyDeployer() 
    {
        return findbyDeployer;
    }

    /**
     * @return
     */
    public Homeinterface 
    getHomeinterface() 
    {
        return homeinterface;
    }

    /**
     * @param deployer
     */
    public void 
    connectFindbyDeployer(FindbyDeployer deployer) 
    {
        findbyDeployer = deployer;
    }

    /**
     * @param homeinterface
     */
    public void 
    connectHomeinterface(HomeinterfaceBean homeinterface) 
    {
        this.homeinterface = homeinterface;
        connectDeployerDescription(homeinterface);
    }

    /**
     * @return
     */
    public HomeplacementDeployer 
    getHomeplacementDeployer() 
    {
        return homeplacementDeployer;
    }

    /**
     * @param deployer
     */
    public void 
    connectHomeplacementDeployer(HomeplacementDeployer deployer) 
    {
        homeplacementDeployer = deployer;
    }

    /**
     * This initialization method is used to check that all the services and 
     * information required to deploy are presents. If all is OK the deployer 
     * is put in inactive deployer state waiting for the deployment processing.
     * 
     * @exception InitializationError is thrown if a problem is detected 
     */     
    public void 
    initialize() 
    throws InitializationError
    {
      if(getHomeinterface()==null)
            getErrorManager()
            .submitException(new InitializationError(this,"Connection on homeinterface bean is required"+
                                        "check the handler code it must specify this connection"));
                                  
      if(getHomeinterface().getHomeplacementref()!=null&&(
        getHomeinterface().getHomeplacementref().getIdref()==null ||
        getHomeinterface().getHomeplacementref().getIdref().length()==0)) 
             getErrorManager()
              .submitException(new InitializationError(this,"The idref attribute of the homeplacementref element"+
                                         "must be fullfilled, check the homeinterface element"+
                                         "description\n."+getStringifiedDeployerDescription()));
      if(getHomeinterface().getHomeplacementref()==null&&getFindbyDeployer()==null)
            getErrorManager()
            .submitException(new InitializationError(this,"One of homeplacementref/findby children must be"+
                                         "specified check the homeinterface element"+
                                         "description\n."+getStringifiedDeployerDescription()));                                                              
        getLifeCycleManager().stepEndedSuccessFully();  
     }

   


}
