/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.binder;

import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.util.CannotResolveReferenceException;
import org.omg.CORBA.Object;
import org.omg.Components.AlreadyConnected;
import org.omg.Components.CCMObject;
import org.omg.Components.Cookie;
import org.omg.Components.CookieRequired;
import org.omg.Components.ExceededConnectionLimit;
import org.omg.Components.InvalidConnection;
import org.omg.Components.InvalidName;
import org.omg.Components.NoConnection;

/**
 * The usesportDeployer is used to resolve a usesport and to establish
 * the connection with the user.
 *
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public class UsesportDeployer 
       extends UsesportDeployerContext 
    {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================    
    private Cookie cookie;
    private CCMObject user;
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================
    /**
     * The getCCMObjectUser is used to resolve the CCMobject which 
     * have the usesport to connect.
     * 
     * @return the CCMObject which got the precised usesport
     * @throws CannotResolveReferenceException if the CCMObject is not founded
     */
    public org.omg.Components.CCMObject
    getCCMobjectUser () 
    throws CannotResolveReferenceException

     {
         if(getComponentinstantiationDeployer()!=null)
             return getComponentinstantiationDeployer().getComponent();
         return org.omg.Components.
             CCMObjectHelper.narrow(getFindbyDeployer().resolveReference());
     }
     
    /**
     * The establishConnection method is used to establish the connection
     * between the usesport an the provided object
     * 
     * @return The cookie connection
     * @throws CannotResolveReferenceException if the CCMObject user is not founded
     * @throws InvalidName if the precised usesport name is invalid
     * @throws InvalidConnection if the given providedObject is invalid
     * @throws AlreadyConnect if the usesport is a simple connection and 
     *  it is already connected.
     * @throws ExceededConnectionLimit if the connection is multiple and have aleady 
     * too many active connections. 
     */
    public Cookie 
    establishConnection(Object providedObject) 
    throws CannotResolveReferenceException, 
           InvalidName, 
           InvalidConnection, 
           AlreadyConnected, 
           ExceededConnectionLimit
    {
        user=getCCMobjectUser();
        cookie=user.connect(getUsesport().getUsesidentifier().getValue(),providedObject);
        getLifeCycleManager().stepEndedSuccessFully();
        return cookie;   
    }
    
    /**
     * Break the current establishes connection.
     * 
     * @throws InvalidName if the usesport name precised is invalid
     * @throws InvalidConnection If conenction is invalid
     * @throws CookieRequired if the cookie given is not valid
     * @throws NoConnection if there is no connection established.
     */
    public void 
    breakConnection() 
    throws InvalidName, 
           InvalidConnection, 
           CookieRequired, 
           NoConnection
    {
        user.disconnect(getUsesport().getUsesidentifier().getValue(),cookie);
        getLifeCycleManager().stepEndedSuccessFully();
    }
}
