/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frederic
Contributor(s): Philippe Merle

====================================================================*/

package org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.installer;

//import the needed packages
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.*;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.registrar.*;
import org.objectweb.openccm.descriptor.componentassembly.*;
import org.omg.Components.CCMHome;


/**
 * HomeplacementDeployer installs a home and configure it. Il also browse
 * all the componentinstantiation to build.
 *
 * @author <a href="mailto:frederic.briclet@lifl.fr">Briclet Frederic</a>
 *
 * @version 0.1
 */
public class HomeplacementDeployer extends HomeplacementDeployerContext{
    
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================    
    /*Internal exception for deployment managing*/        
    private class CannotSetupHomeException extends Exception{};
    /*The installed home*/
    private org.omg.Components.CCMHome homePlaced;
    /*Descriptor containing the path to ccd file*/
    private org.objectweb.openccm.descriptor.softpkg.Descriptor descriptor;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================
    // ==================================================================
    //
    // private methods.
    //
    // ==================================================================
  
    
    /**
     * Setup the dependencies defined in softpkg tags
     * 
     * @throws FatalDeploymentException if a fatal problem occured
     */
    private void
    setupSoftpkgDependency()
    throws FatalDeploymentException
    {
        getDestinationDeployer().resolveDependency();
    
    }

    /**
     * Internal method in charge to setup the container  and to create the home.
     * 
     * @throws FatalDeploymentException if a fatal error occured
     * @throws CannotSetupHomeexception if the home cannot be placed
     */
    private org.omg.Components.CCMHome 
    setupHome() 
    throws FatalDeploymentException, 
           CannotSetupHomeException 
    
    {
        try {       
               
            return getDestinationDeployer().installHome();           
               
            }catch(Error err){System.out.println(err.getMessage());}
        
        throw new CannotSetupHomeException();            
    }
    /**
     * Internal method to make home registration
     * 
     * @throws FatalDeploymentException if a fatal problem occured
     */
    private void 
    proceedHomeRegistration()
    throws FatalDeploymentException
    {
         traverse(this,getRegisterwithnamingDeployers());    
         traverse(this,getRegisterwithhomefinderDeployers());
         traverse(this,getRegisterwithtraderDeployers());
     } 
     
    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================
    
    // ==================================================================
    //
    // Public visitors used in homeplacement inactive state.
    //
    // ==================================================================
    /**
     * the componentinstantiationDeployer visitor method used to instantiate component
     * 
     * @param comp The componentinstantiationDeployer to deploy
     * @param status the homeplacementDeployer current status
     * @throws FatalDeploymentException if a fatal problem occured
     */
    public void 
    visit(ComponentinstantiationDeployer comp, DeployerInactiveState status)
    throws FatalDeploymentException
    {
        try{
            comp.deploy(homePlaced);
        }
        catch(ComponentInstantiationFailureException e){
            getErrorManager().submitException(e);
        }
    }
    /**
     * The RegisterwithhomefinderDeployer visitor method used to register home in
     * home finder service.
     * 
     * @param deployer The registerwithhomefinderDeployer to execute 
     * @param status The homeplacement current status
     */  
    public void 
    visit(RegisterwithhomefinderDeployer deployer, DeployerInactiveState status)
    {
        try{
            deployer.register_home(descriptor,homePlaced);
        }
        catch(Exception e){
            e.printStackTrace();
        }
    }
    /**
     * The RegisterwithnamingDeployer visitor method used to register home in
     * name service.
     * 
     * @param deployer The registerwithnamingfinderDeployer to execute 
     * @param status The homeplacement current status
     */      
    public void visit(RegisterwithnamingDeployer deployer,
                      DeployerInactiveState status)
    throws FatalDeploymentException{
        try{
            deployer.rebind(homePlaced);
        }
        catch(NameserviceRegistrationFailureException e){
            getErrorManager().submitException(e);
        }
    }
    /**
     * The RegisterwithhometraderDeployer visitor method used to register home in
     * trader service.
     * 
     * @param deployer The registerwithtraderDeployer to execute 
     * @param status The homeplacement current status
     */      
    public void visit(RegisterwithtraderDeployer deployer, DeployerInactiveState status){
         try{
             deployer.deploy(homePlaced);
         }
         catch(Exception e){
             e.printStackTrace();
         }
     }


    
    /**
     * The deploy metod install the home on the target host and make instantiation
     * of all the required components.
     * 
     * @throws FatalDeploymentException if fatal problem occured. 
     */    
    public void 
    deploy()
    throws FatalDeploymentException
    {  
        setupSoftpkgDependency(); 
        try {
            //setup the container and install homes with container configuration.
           
            homePlaced =setupHome() ;            
            //storing the reference in the DeployInfo extension of the descriptor
            getHomeplacementInfo().setCorbaReference(homePlaced);
            getLogger().log("Home "+getHomeplacement().getId()+"is  deployed");  
        }
        catch(Exception e){
            System.err.println("Problem occurred during the deployment of "+getHomeplacement().getId());
            e.printStackTrace();

        }  
        //setup the componentinstantiation 
        traverse(this,getComponentInstantiationDeployers());
        proceedHomeRegistration();   
        getLifeCycleManager().stepEndedSuccessFully();
    }
    
    /**
     * Public accessor to retrieve the installed home.
     * @return
     */
    public CCMHome getHome(){
        return homePlaced;
    }
    

    /**
     *Tear down the homeplacement but dont remove the file archive
     *@throws FatalDeploymentException if a fatal problem occured
     */
    public void 
    tearDown()
    throws FatalDeploymentException
    {
        Homeplacement hi=getHomeplacement();
        traverse(this,getComponentInstantiationDeployers());    
        traverse(this,getRegisterwithnamingDeployers());
        traverse(this,getRegisterwithtraderDeployers());           
        traverse(this,getRegisterwithhomefinderDeployers());       
        // Remove the component server
        getDestinationDeployer().removeHome(homePlaced); 
        getLifeCycleManager().stepEndedSuccessFully();
    } 
    
    // ==================================================================
    //
    // Public visitors used in homeplacement inactive state methods.
    //
    // ==================================================================     
    /**
     * the componentinstantiationDeployer visitor method used to remove component
     * 
     * @param comp The componentinstantiationDeployer to deploy
     * @param status the homeplacementDeployer current status
     * @throws FatalDeploymentException if a fatal problem occured
     */
    public void 
    visit(ComponentinstantiationDeployer comp, DeployerActiveState status)
    {
      try{
        comp.tearDown(); 
        }
      catch(Exception e)
        {
         System.out.println("Cannot remove the instance");
         e.printStackTrace();
        }    
    }
    /**
     * The RegisterwithhomefinderDeployer visitor method used to unregister home in
     * home finder service.
     * 
     * @param deployer The registerwithhomefinderDeployer to execute 
     * @param status The homeplacement current status
     */    
    public void 
    visit(RegisterwithhomefinderDeployer deployer, DeployerActiveState status)
    {
        try{
            deployer.unregister_home();
        }
        catch(Exception e){
            e.printStackTrace();
        }
    }
    /**
     * The RegisterwithnamingDeployer visitor method used to unregister home in
     * name service.
     * 
     * @param deployer The registerwithnamingfinderDeployer to execute 
     * @param status The homeplacement current status
     */        
    public void 
    visit(
        RegisterwithnamingDeployer deployer,
        DeployerActiveState status) 
    {
        try {
            deployer.unbind();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
    /**
     * The RegisterwithhometraderDeployer visitor method used to register home in
     * trader service.
     * 
     * @param deployer The registerwithtraderDeployer to execute 
     * @param status The homeplacement current status
     */
    public void
    visit(
        RegisterwithtraderDeployer deployer,
        DeployerActiveState status) 
    {
        try {
            deployer.tearDown();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
