/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.managers;


import java.util.Hashtable;
import java.util.Iterator;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.DeployerContext;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.DeployerFailureException;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.DeploymentLogger;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.ErrorManager;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.FatalDeploymentException;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.InitializationError;
import org.objectweb.openccm.descriptor.deployerconfig.Deployerconfig;
import org.objectweb.openccm.descriptor.deployerconfig.Deployerstatus;
import org.objectweb.openccm.descriptor.deployerconfig.Package;
import org.objectweb.openccm.descriptor.softpkg.ccm.CorbaComponentFileLoadingFailureException;

/**
 * The default error manager in charge to decide in error case in the deployment
 * must goes on or stops.
 *
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public class DefaultErrorManager 
       implements ErrorManager 
    {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================    
    private DeployerContext deployer;
    private Hashtable tolerableError;
    private DeploymentLogger deploymentLogger;
    private Deployerconfig deployerConfig;
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    public DefaultErrorManager(Deployerconfig deployerConfig)
    {
        this.deployerConfig=deployerConfig;
        setupError();       
    }
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    /**
     * Internal method to setup the table of tolerable errors.
     */
    private void 
    setupError()
    {       
        tolerableError=new Hashtable();
       
        for(Iterator it=deployerConfig.getTolerablefailure().getXmlpackageList().iterator();it.hasNext();){
            Package pbi= (Package)it.next();
            for(Iterator it1=pbi.getDeployerstatusList().iterator();it1.hasNext();){
                Deployerstatus dsb=(Deployerstatus)it1.next();
                for(Iterator it2=dsb.getDeployerList().iterator();it2.hasNext();){
                    org.objectweb.openccm.descriptor.deployerconfig.Deployer dbi=
                        (org.objectweb.openccm.descriptor.deployerconfig.Deployer)it2.next();
                    tolerableError.put(pbi.getName()+"."+dbi.getName()+"."+dsb.getName(),"empty");
                }
            }
        }
            
    }

    /**
     * Internal method to decide if the error that occur is tolerable or not.
     * 
     * @param e The exception which occured
     * @return true if the error is tolerable false if it is not. 
     */
    private boolean 
    isTolerableException(DeployerFailureException e)
    {
        String deployerName=e.getDeployer().getClass().getName();
        String deployerStatus=e.getDeployer().getStatus().getStateName();
        if(tolerableError.containsKey(deployerName+"."+deployerStatus))
            return true;
        return false;    
    }
    /**
     * Internal accessor to retrieve deployment logger
     * @return The current deployment logger
     */
    protected DeploymentLogger
    getDeploymentLogger()
    {
        return deploymentLogger;    
    }
    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================
    /**
     * SubmitException is use to report a initialization error
     * and decide if the building of the deployment machine must
     * go on or stop.
     * 
     * @param e the initialization error to evaluate
     * @throws InitializationError if deployment machine building must be stopped.
     */
    public void 
    submitException(InitializationError e)
    throws InitializationError
    {

        if(!isTolerableException(e)){
            getDeploymentLogger()
                .log(e.getMessage());
            getDeploymentLogger()
                       .log(">> According to the error configuration it is  "
                            +" a fatal deployment error. Deployment will be stop here.");
        e.getDeployer().getLifeCycleManager().stepAborded();
            
        throw e;
        }
        
        getDeploymentLogger()
        .log(">> Error occured during initialization of "
             +e.getDeployer().getIdentifier()+":\n"
             +e.getMessage());
             
        if(e instanceof CorbaComponentFileLoadingFailureException){
            getDeploymentLogger()
                .log(">>Check you CSD file in must specify a link to a "+
                "non exisiting file");
            e.getDeployer().getLifeCycleManager().stepAborded();       
        }
        else{
            e.getDeployer().getLifeCycleManager().stepAborded();    
            getDeploymentLogger()
                    .log(">> "+e.getDeployer().getStringifiedDeployerDescription()+
                         "\n"+e.getMessage());        
            throw e;
        }

    }
    
    /**
     * the submitException is used to submit exception that occured
     * during deployment and choose if the deployment must be continued 
     * or to be stopped.
     * 
     * @param e the deployer failure that occured.
     * @throws FatalDeploymentException if deployment must be stopped
     */
    public void 
    submitException(DeployerFailureException e)
    throws FatalDeploymentException
    {

        try{//TODO:modifier le branchement du logueur
           
            getDeploymentLogger()
                          .log(">> An error occured durig the deployment of:");
                          
            getDeploymentLogger()
                    .log(">> "+e.getDeployer().getStringifiedDeployerDescription()+
                         "\n"+e.getMessage()); 
              
        }        
        catch(Exception ex){
            System.err.println(ex.getMessage());
        }
        if(!isTolerableException(e)){
            getDeploymentLogger()
                           .log(">> According to the error configuration it is  "
                                +" a fatal deployment error. Deployment will be stop here.");
            e.getDeployer().getLifeCycleManager().stepAborded();
            
            throw new FatalDeploymentException(e);
        }
        getDeploymentLogger().log(">> According to the error configuration it is "
                                     +"a  unfatal deployment error. Deployment will continue.");
          
        e.getDeployer().getLifeCycleManager().stepAborded();
    
    }
    
    public void connectDeploymentLogger(DeploymentLogger deploymentLogger) {
        this.deploymentLogger=deploymentLogger;        
    }
    

    
}
