/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.util;

import org.objectweb.openccm.descriptor.componentassembly.Findby;
import org.objectweb.openccm.descriptor.componentassembly.beans.FindbyBean;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.*;
import org.omg.Components.HomeFinder;
import org.omg.CosNaming.NamingContextExt;

/**
 * The findby deployer context defines all the connection requires for
 * the reference resolution, inluding homefinder service, nameservice...
 *
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public class FindbyDeployerContext 
       extends ChildDeployerContext 
    {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================    
    private FindbyBean findby;
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================    
    public void 
    connectFindby(FindbyBean findby)
    {
        this.findby=findby;
        connectDeployerDescription(findby);
    }

    public Findby
    getFindby()
    {
        return findby;
    }
    
    public NamingContextExt 
    getNamingContextExt()
    {
        return getRootDeployerContext().getNamingContextExt();
    }
    
    public HomeFinder 
    getHomeFinder()
    {
        return getRootDeployerContext().getHomefinder();
    }
    
    /**
     * This initialization method is used to check that all the services and 
     * information required to deploy are presents. If all is OK the deployer 
     * is put in inactive deployer state waiting for the deployment processing.
     * 
     * @exception InitializationError is thrown if a problem is detected 
     */
    public void 
    initialize() 
    throws InitializationError 
    {
        if (getFindby() == null)
            getErrorManager().submitException(
                new InitializationError(
                    this,
                    "Connection on findby bean is required"
                        + "check the handler code it must specify this connection"));

        if (getFindby().getHomefinder() != null) {
            if (getFindby().getHomefinder().getName() == null
                || getFindby().getHomefinder().getName().length() == 0)
                getErrorManager().submitException(
                    new InitializationError(
                        this,
                        "The name attribute of homefinder element must be"
                            + "fullfilled check the homefinder element"
                            + "description\n."
                            + getStringifiedDeployerDescription()));
            if (getHomeFinder() == null)
                getErrorManager().submitException(
                    new InitializationError(
                        this,
                        "Connection on the current HomeFinder is required to make"
                            + "HomeFinder lookup, change your findby description if"
                            + "HomeFinder is not started.\n"
                            + getStringifiedDeployerDescription()));
        }
        if (getFindby().getHomefinder() != null) {
            if (getFindby().getNamingservice().getName() == null
                || getFindby().getNamingservice().getName().length() == 0)
                getErrorManager().submitException(
                    new InitializationError(
                        this,
                        "The name attribute of namingservice element must be"
                            + "fullfilled check the findby element"
                            + "description\n."
                            + getStringifiedDeployerDescription()));
            if (getNamingContextExt() == null)
                getErrorManager().submitException(
                    new InitializationError(
                        this,
                        "Connection on the current NameService is required to make"
                            + "NamingService lookup, change your findby description if"
                            + "NameService is not started.\n"
                            + getStringifiedDeployerDescription()));
        }
        if (getFindby().getStringifiedobjectref() != null
            && getFindby().getStringifiedobjectref().getValue().length() == 0)
            getErrorManager().submitException(
                new InitializationError(
                    this,
                    "The stringifiedobjectref data must be"
                        + "fullfilled check the findby element"
                        + "description\n."
                        + getStringifiedDeployerDescription()));

        getLifeCycleManager().stepEndedSuccessFully();
    }
}
