/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.openccm.descriptor.softpkg.ccm;

import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.HandlerBase;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.InitializationError;
import org.objectweb.openccm.descriptor.softpkg.beans.ImplementationBeanImpl;

/**
 * This handler is used to produce implementationdeployer from an
 * implementation bean.
 *
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public class ImplementationDeployerHandler 
       extends HandlerBase 
{
    // ==================================================================
    //
    // Internal state.
    //
    // ================================================================== 
    private ImplementationDeployer _deploy;
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================    
    /**
     * Produce the implementation deployer binded
     * to the given @param cons.
     * 
     * @param cons The implementation bean 
     * @return the deployer produced in initialize state
     * @throws InitializationError thrown if a problem is detected
     */  
    public Object 
    getInstance(ImplementationBeanImpl cons)
    throws InitializationError 
    {
        if (_deploy == null) {
            _deploy = new ImplementationDeployer();
            _deploy.connectImplementation(cons);
            applyCommonConfig(_deploy);
    
            if (cons.getDescriptorList() == null
                || cons.getDescriptorList().size() == 0)
                _deploy.connectDescriptorDeployer(new DefaultDescriptorDeployer());
            else
                for (java.util.Iterator i = cons.getDescriptorList().iterator();
                    i.hasNext();
                    )
                    _deploy.connectDescriptorDeployer(
                        (DescriptorDeployer) getDeployer(i.next()));
    
            if (cons.getCodeList() != null)
                for (java.util.Iterator i = cons.getCodeList().iterator();
                    i.hasNext();
                    ) {
                    CodeDeployer cd = (CodeDeployer) getDeployer(i.next());
                    _deploy.connectCodeDeployer(cd);
                }
    
            if (cons.getDependencyList() != null)
                for (java.util.Iterator i = cons.getDependencyList().iterator();
                    i.hasNext();
                    ) {
                    _deploy.connectDependencyDeployer(
                        (DependencyDeployer) getDeployer(i.next()));
                }
    
            _deploy.initialize();
        }
        return (_deploy);
    }

}
