/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.openccm.descriptor.softpkg.ccm;

import java.util.LinkedList;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.ChildDeployerContext;
import org.objectweb.openccm.descriptor.componentassembly.ccm.deployer.base.InitializationError;
import org.objectweb.openccm.descriptor.softpkg.beans.SoftpkgBean;

/**
 * The softpkg deployer context defines all the connection requires for
 * processing a softpkg.
 *
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public class SoftpkgDeployerContext 
       extends ChildDeployerContext 
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    private SoftpkgBean softpkg;
    private LinkedList implementationDeployers;
    private LinkedList dependencyDeployers;
    private LinkedList descriptorDeployers;    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    public SoftpkgDeployerContext(){
        implementationDeployers=new LinkedList();
        dependencyDeployers=new LinkedList();
        descriptorDeployers=new LinkedList();
    }
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================
    /**
     * @return
     */
    public SoftpkgBean 
    getSoftpkg() 
    {
        return softpkg;
    }

    /**
     * @param bean
     */
    public void 
    connectSoftpkg(SoftpkgBean bean) 
    {
        softpkg = bean;
        connectDeployerDescription(bean);
    }

    public void 
    connectDependencyDeployer(DependencyDeployer deployer)
    {
        dependencyDeployers.addLast(deployer);
    }

    public DependencyDeployer[] 
    getDependencyDeployers()
    {
        return (DependencyDeployer[])
                dependencyDeployers
                .toArray(new DependencyDeployer[dependencyDeployers.size()]);
    }

    public void 
    connectDescriptorDeployer(DescriptorDeployer deployer)
    {
        descriptorDeployers.addLast(deployer);
    }

    public DescriptorDeployer[] 
    getDescriptorDeployers()
    {
        return (DescriptorDeployer[])
                descriptorDeployers
                .toArray(new DescriptorDeployer[descriptorDeployers.size()]);
    }

    public void 
    connectImplementationDeployer(ImplementationDeployer deployer)
    {
        implementationDeployers.addLast(deployer);
    }

    public ImplementationDeployer[] 
    getImplementationDeployers()
    {
        return (ImplementationDeployer[])
                    implementationDeployers
                    .toArray(new ImplementationDeployer[implementationDeployers.size()]);
    }
    
    /**
     * This initialization method is used to check that all the services and 
     * information required to deploy are presents. If all is OK the deployer 
     * is put in inactive deployer state waiting for the deployment processing.
     * 
     * @exception InitializationError is thrown if a problem is detected 
     */
    public void 
    initialize() 
    throws InitializationError 
    {
        if(getSoftpkg()==null)
              getErrorManager()
              .submitException(new InitializationError(this,"Connection on softpkg bean is required"+
                                                       "check the handler code it must specify this connection"));
        getLifeCycleManager().stepEndedSuccessFully();
    }    
   

}
