/*====================================================================

Objectweb Browser framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.openccm.explorer.DCI;

import org.ist.coach.DCI.AssemblyManager;
import org.ist.coach.DCI.DCIDeployment;
import org.ist.coach.DCI.UnknownAssembly;
import org.objectweb.util.explorer.api.Context;
import org.objectweb.util.explorer.api.Entry;
import org.objectweb.util.explorer.core.naming.lib.DefaultEntry;

/**
 * This context provides the instances of the given assembly model.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * 
 * @version 0.1
 */
public class AssemblyUUIDContext 
  implements Context 
{

    /**
     * Provides a name depending on the AssemblyManager id.
     */
    protected String getName(AssemblyManager assemblyManager){
        String returnedValue = "Assembly ";
        String assemblyId = assemblyManager.ass_id();
        if(assemblyId.indexOf(":")!=-1)
            returnedValue = assemblyId.substring(0,assemblyId.indexOf(":"));
        return returnedValue;
    }
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Context#getEntries(java.lang.Object)
     */
    public Entry[] getEntries(Object object) {
        AssemblyUUIDWrapper assemblyUUIDWrapper = (AssemblyUUIDWrapper)object;
        DCIDeployment DCIDeploy = assemblyUUIDWrapper.getDCIDeployment();
        String assemblyUUID = assemblyUUIDWrapper.getUUID();
        java.util.List v = new java.util.Vector();

        try {
            String[] instanceUUID = DCIDeploy.get_assembly_instances(assemblyUUID);
            for (int i = 0; i < instanceUUID.length; i++) {
                AssemblyManager assemblyManager = DCIDeploy.get_assembly_manager(instanceUUID[i]);
                AssemblyManagerWrapperWithDCIDeployment am = new AssemblyManagerWrapperWithDCIDeployment();
                am.setAssemblyManager(assemblyManager);
                am.setDCIDeployment(DCIDeploy);
                am.setUUID(instanceUUID[i]);
                v.add(new DefaultEntry(getName(assemblyManager) + " (" + (i+1) + ")", am));
            }
        } catch (UnknownAssembly e) {
            e.printStackTrace();
        }
        
        // Return the array of entry
        return (Entry[]) v.toArray(new Entry[0]);    
    }

}
