/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/

package org.objectweb.openccm.explorer.DCI;

import java.util.Vector;

import org.ist.coach.DCI.AssemblyManager;
import org.ist.coach.DCI.DCIDeployment;
import org.ist.coach.DCI.DCIInformation;
import org.ist.coach.DCI.DCIManager;
import org.ist.coach.DCI.UnknownAssembly;
import org.objectweb.openccm.explorer.CORBA.TypageCORBA;
import org.objectweb.util.explorer.api.Table;
import org.objectweb.util.explorer.api.TreeView;
import org.objectweb.util.explorer.core.naming.lib.DefaultEntry;
import org.omg.Components.Deployment.Assembly;

/**
 * Displays the running assemblies for the given DCIManager.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class DCIRunningAssembliesTable
  implements Table 
{

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================
    
    //==================================================================
    //
    // No constructor.
    //
    //==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    protected String getName(org.omg.CORBA.Object o) {
        TypageCORBA tc = new TypageCORBA(o, org.objectweb.openccm.corba.TheORB.getORB());
        return tc.getTypeID();
    }

    /**
     * Provides a name depending on the AssemblyManager id.
     */
    protected String getName(AssemblyManager assemblyManager){
        String returnedValue = "Assembly ";
        String assemblyId = assemblyManager.ass_id();
        if(assemblyId.indexOf(":")!=-1)
            returnedValue = assemblyId.substring(0,assemblyId.indexOf(":"));
        return returnedValue;
    }    
    
    protected boolean isStarted(AssemblyManager assemblyManager){
        Assembly assembly = assemblyManager.provide_assembly();
        return assembly.get_state().equals(org.omg.Components.Deployment.AssemblyState.INSERVICE);
    }
        
    //==================================================================
    //
    // Public methods for Table interface.
    //
    //==================================================================

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Table#getHeaders(org.objectweb.util.explorer.api.TreeView)
     */
    public String[] getHeaders(TreeView treeView) {
        return new String[]{"Assemblies"};
    }
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Table#getRows(org.objectweb.util.explorer.api.TreeView)
     */
    public Object[][] getRows(TreeView treeView) {
        DCIManager DCIManager_ = (DCIManager)treeView.getSelectedObject();
        DCIInformation DCIInfo = DCIManager_.provide_dci_information();
        DCIDeployment DCIDeploy = DCIManager_.provide_dci_deployment();
        String[] assemblyUUIDs = DCIDeploy.get_assemblies();
        Vector values = new Vector();
        
        for (int i = 0; i < assemblyUUIDs.length; i++) {
            try{
                String[] instanceUUID = DCIDeploy.get_assembly_instances(assemblyUUIDs[i]);
                for (int j = 0; j < instanceUUID.length; j++) {
                    AssemblyManager assemblyManager = DCIDeploy.get_assembly_manager(instanceUUID[j]);
                    AssemblyManagerWrapperWithDCIDeployment am = new AssemblyManagerWrapperWithDCIDeployment();
                    am.setAssemblyManager(assemblyManager);
                    am.setDCIDeployment(DCIDeploy);
                    am.setUUID(instanceUUID[j]);
                    if(isStarted(assemblyManager))
                        values.add(new DefaultEntry(getName(assemblyManager) + " (" + (j+1) + ")", am));
                }
            } catch (UnknownAssembly e) {
                e.printStackTrace();
            }
        }        

        Object[][] contenu = new Object[values.size()][1];
        for(int i=0 ; i<values.size() ; i++){
            contenu[i][0] = values.get(i);
        }
        
        return contenu;
    }
}
