/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Offroy.
Contributor(s): ______________________________________.

====================================================================*/
/*
 * Created on 3 juin 2003 by jerome OFFROY (offroy@lifl.fr)
 *
 */

package org.omg.lifl.eclipse.plugin.project.utils;

import org.eclipse.core.runtime.IConfigurationElement;
import org.omg.lifl.eclipse.plugin.project.utils.SWT.SetterGroupPreference;

/**
 * This class allow access of attributes of a configuration element which 
 * directly reflects the content and structure of the extension section
 * within the declaring plug-in's manifest (<code>plugin.xml</code>) file.   
 *
 * @author offroy@lifl.fr
 *
 * @version 0.1
 */
public class AttributeManager {

    private IConfigurationElement configurationElement;

    /**
     * @param elem the configuration element to use
     */
    public AttributeManager(IConfigurationElement elem) {
        this.setConfigurationElement(elem);
    }

    /**
     * @param elem configuration element to use
     * @param property name of the wanted property 
     * @return value of the property
     */
    public static String getAttribute(IConfigurationElement elem, String property) {
        String res = elem.getAttribute(property);
        if (res == null) {
            return '!' + property + '!';
        }
        return res;
    }

    /**
     * @param elem configuration element to use
     * @param preProperty prefix of the wanted property
     * @return an object representing the Properties 
     */
    public static SetterGroupPreference getAllAttribute(
        IConfigurationElement elem,
        String tag) {
        //TODO make an array (more generic)
        String _Group = elem.getAttribute(tag + "Group");
        String _PathLabel = elem.getAttribute(tag + "PathLabel");
        String _PathName = elem.getAttribute(tag + "PathName");

        if (_Group == null || _PathName == null || _PathLabel == null)
            return null;

        return new SetterGroupPreference(_Group, _PathLabel, _PathName);
    }

    /**
     * this method uses the internal configuration element 
     * @param property name of the wanted property
     * @return
     */
    public String getAttribute(String property) {
        if (elementSet())
            return getAttribute(getConfigurationElement(),property);
        else return null;
    }

    public boolean elementSet(){
        return ( getConfigurationElement() != null ? true : false );
    }

    /**
     * @return
     */
    public IConfigurationElement getConfigurationElement() {
        return configurationElement;
    }

    /**
     * @param element
     */
    public void setConfigurationElement(IConfigurationElement element) {
        configurationElement = element;
    }

}
