/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.explorer.plugin.java.swing;

import java.awt.Color;
import java.util.Collection;
import java.util.Iterator;

import javax.swing.BoxLayout;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;

import org.objectweb.util.explorer.api.Panel;
import org.objectweb.util.explorer.api.TreeView;


/**
 * Displays a <code>javax.swing.JTable</code> representing 
 * the given <code>java.util.Collection</code> object.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.1
 */
public class CollectionPanel 
    implements Panel {

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================

    /** The JPanel to display */
    protected JPanel panel_;

    //==================================================================
    //
    // Constructors.
    // 
    //==================================================================

    /**
     * Default constructor.
     * Creates a empty white panel with <code>BoxLayout</code>.
     */
    public CollectionPanel(){
        panel_ = new JPanel();
        panel_.setBackground(Color.white);
        panel_.setLayout(new BoxLayout(panel_, BoxLayout.Y_AXIS));
    }

    //==================================================================
    //
    // No internal method.
    //
    //==================================================================

    //==================================================================
    //
    // Public methods for Panel interface.
    //
    //==================================================================
        
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Panel#selected(org.objectweb.util.explorer.api.TreeView)
     */
    public void selected(TreeView treeView) {
        String[] titre = {"Class name","Instance"};
        Collection collection = (Collection)treeView.getSelectedObject();
        String[][] contenu = new String[collection.size()][2];
        Iterator iterator = collection.iterator();
        int cpt = 0;
        while (iterator.hasNext()) {
            Object element = iterator.next();
            contenu[cpt] = new String[]{element.getClass().getName(), element.toString()};
            cpt++;
        }
        panel_.add(new JScrollPane(new JTable(contenu,titre)));        
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Panel#getPanel()
     */
    public Object getPanel() {
        return panel_;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Panel#unselected(org.objectweb.util.explorer.api.TreeView)
     */
    public void unselected(TreeView treeView) {
        // Noting to do
    }
        
}    