/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.explorer.plugin.java.reflect;

import java.net.URL;
import java.net.URLClassLoader;
import java.util.Enumeration;
import java.util.Vector;
import java.util.jar.JarEntry;

import org.objectweb.util.explorer.api.Context;
import org.objectweb.util.explorer.api.Entry;
import org.objectweb.util.explorer.core.common.api.ContextContainer;
import org.objectweb.util.explorer.core.naming.lib.DefaultEntry;


/**
 * 
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.1
 */
public class JarFileContext 
    implements Context 
{

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================

    //==================================================================
    //
    // No constructor.
    // 
    //==================================================================

    //==================================================================
    //
    // Internal methods.
    //
    //==================================================================

    /**
     * Replace all the occurences of the given string with the given replacement.
     * @param original The original String to modify.
     * @param to_replace The substring of the string to search and replace.
     * @param new_value The replacement String.
     * @return The modified String.
     */
    protected String replaceAll(String original, String to_replace, String new_value) {
        StringBuffer newString = new StringBuffer();
        int indexBegin = 0;
        int index = original.indexOf(to_replace, indexBegin);
        while (index != -1) {
            newString.append(original.substring(indexBegin, index));
            newString.append(new_value);
            indexBegin = index + to_replace.length();
            index = original.indexOf(to_replace, indexBegin);
        }
        newString.append(original.substring(indexBegin));
        return newString.toString();
    }

    protected ContextContainer getContext(ContextContainer contextContainer, String packageName){
        if(packageName!=null && !packageName.equals("")) {
            String currentPackage = null;
            String otherPackage = null;
            if(packageName.lastIndexOf(".")!=-1){
                currentPackage = packageName.substring(0,packageName.indexOf("."));
                otherPackage = packageName.substring(packageName.indexOf(".")+1);   
            } else {
                currentPackage = packageName; 
            }
            if(currentPackage!=null) {
                Entry entry = contextContainer.getEntry(currentPackage);
                ContextContainer cc = (entry!=null)?(ContextContainer)entry.getValue():null;
                if(cc == null) {
                    cc = new PackageContextContainer();
                    contextContainer.addEntry(currentPackage, cc);
                }
                if(otherPackage!=null)
                    return getContext(cc, otherPackage);
                else
                    return cc;
            } else
                return contextContainer;
        }
        return contextContainer;
    }

    protected void addClass(ContextContainer contextContainer, Class theClass) {
        String packageName = theClass.getPackage().getName();
        ContextContainer cc = getContext(contextContainer, packageName);   
        cc.addEntry(theClass.getName().substring(theClass.getName().lastIndexOf(".") + 1),theClass);     
    }

    //==================================================================
    //
    // Public methods for Context interface.
    //
    //==================================================================

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Context#getEntries(java.lang.Object)
     */
    public Entry[] getEntries(Object object){
        JarFileStructure jarFile = (JarFileStructure)object;
        URLClassLoader classLoader = new URLClassLoader(new URL[]{jarFile.getJarURL()});
        ContextContainer cc = new PackageContextContainer(); 
        Vector elements = new Vector();
        Enumeration enumeration = jarFile.getJarFile().entries();
        while(enumeration.hasMoreElements()) {
            JarEntry entry = (JarEntry)enumeration.nextElement();
            if(!entry.isDirectory()){
                try {
                    Class c = Class.forName(replaceAll(entry.getName().substring(0, entry.getName().lastIndexOf('.')),"/","."),true,classLoader);
                    addClass(cc, c);
                    //elements.add(new DefaultEntry(c,new DefaultName(entry.getName()),this));
                } catch (ClassNotFoundException e) {
                    // Ignore
                }
            }
        }
        Entry[] entries = cc.getEntries(object);
        for (int i = 0; i < entries.length; i++) {
            elements.add(new DefaultEntry(entries[i].getName().toString(),entries[i].getValue()));   
        }
        return (Entry[])elements.toArray(new Entry[0]);
    }

}    
    