/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.explorer.plugin.java.reflect;

import java.lang.reflect.Method;


/**
 * 
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.1
 */
public class MethodUtil 
    extends MemberUtil {

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================

    /** The Method to manipulate */
    protected Method method_;

    //==================================================================
    //
    // Constructors.
    // 
    //==================================================================

    public MethodUtil(Method method){
        super();
        method_ = method;
    }

    public MethodUtil(Method method, ClassVisibilityConfig config) {
        super(config);
        method_ = method;
    }

    //==================================================================
    //
    // No internal method.
    //
    //==================================================================

    //==================================================================
    //
    // Public methods.
    //
    //==================================================================

    /**
     * Provides an HTML representation of a Field
     */
    public String toHTML(){
        boolean displayParams = config_.get(ClassVisibilityConfig.METHOD + "." + ClassVisibilityConfig.PARAMS);
        boolean displayReturnType = config_.get(ClassVisibilityConfig.METHOD + "." + ClassVisibilityConfig.RETURN_TYPE);
        String visibility = getVisibility(method_.getModifiers());
        StringBuffer name = new StringBuffer((visibility!=null?"<i>"+visibility+"</i>" + " ":"") + "<b>" + method_.getName() + "</b>(");
        if(displayParams){
            Class[] params = method_.getParameterTypes();
            for(int j=0 ; j<params.length ; j++) {
                name.append(ClassVisibility.getTypeName(params[j]));
                if(j<params.length-1)
                    name.append(", ");
            }    
        }
        name.append(")");
        if(displayReturnType)
            name.append(": " + ClassVisibility.getTypeName(method_.getReturnType()));
        return name.toString();
    }

}



    