/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.explorer.plugin.java.reflect;

import java.util.List;
import java.util.Map;
import java.util.Vector;

import org.objectweb.util.explorer.api.Context;
import org.objectweb.util.explorer.api.Entry;
import org.objectweb.util.explorer.core.naming.lib.DefaultEntry;

/**
 * This class allows to browse a <code>TreeInheritance</code> object.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.1
 */
public class TreeInheritanceContext 
    implements Context 
{

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================

    /** Contains the configuration for each class */
    protected static Map config_;

    /** The key of the default configuration entry */
    public static final String DEFAULT_CONFIG = "_default_config_";

    //==================================================================
    //
    // No constructor.
    // 
    //==================================================================

    //==================================================================
    //
    // No internal method.
    //
    //==================================================================

    //==================================================================
    //
    // Public methods for Context interface.
    //
    //==================================================================

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Context#getEntries(java.lang.Object)
     */
    public Entry[] getEntries(Object object) {
        TreeInheritance treeInheritance = (TreeInheritance)object;
        List entryList = new Vector();
        Class class_ = treeInheritance._getClass();
        Class superClass = class_.getSuperclass();
        if(superClass!=null){
            entryList.add(new DefaultEntry(superClass.getName(),superClass));
        }
        Class[] interfaces = class_.getInterfaces();
        for (int i = 0; i < interfaces.length; i++) {
            entryList.add(new DefaultEntry(interfaces[i].getName(),interfaces[i]));
		}
        return (Entry[])entryList.toArray(new Entry[0]);        
    }

}