/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.explorer.plugin.java.reflect.swing;

import java.awt.Color;
import java.awt.FlowLayout;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.Vector;

import javax.swing.JEditorPane;
import javax.swing.JPanel;

import org.objectweb.util.explorer.api.Panel;
import org.objectweb.util.explorer.api.TreeView;
import org.objectweb.util.explorer.plugin.java.reflect.ClassUtil;
import org.objectweb.util.explorer.plugin.java.reflect.ClassVisibility;
import org.objectweb.util.explorer.plugin.java.reflect.ClassVisibilityConfig;
import org.objectweb.util.explorer.plugin.java.reflect.FieldUtil;
import org.objectweb.util.explorer.plugin.java.reflect.MemberComparator;
import org.objectweb.util.explorer.plugin.java.reflect.MethodUtil;

/**
 * 
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.1
 */
public class ClassPanel 
    implements Panel {

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================

    protected JPanel panel_;

    protected StringBuffer htmlText_;

    /** The comparator to use to sort the arrays */
    protected MemberComparator comparator_;

    //==================================================================
    //
    // Constructor.
    // 
    //==================================================================

    public ClassPanel(){
        panel_ = new JPanel();
        htmlText_ = new StringBuffer();
        FlowLayout flow = new FlowLayout(FlowLayout.LEFT);
        panel_.setLayout(flow);
        panel_.setBackground(Color.white);
        comparator_ = new MemberComparator();
    }

    //==================================================================
    //
    // No internal method.
    //
    //==================================================================

    protected String[] getFields(Field[] fields, ClassVisibilityConfig config){
        Arrays.sort(fields,comparator_);
        Vector fieldList = new Vector();
        FieldUtil fieldUtil = null;
        for(int i=0 ; i<fields.length ; i++){
            if(ClassVisibility.hasToBeAdded(fields[i].getModifiers(),config,ClassVisibilityConfig.ATTRIBUTE)){
                fieldUtil = new FieldUtil(fields[i]);
                fieldList.add(fieldUtil.toHTML());
            }                
        }
        return (String[])fieldList.toArray(new String[0]);
    }

    protected String[] getMethods(Method[] methods, ClassVisibilityConfig config){
        Arrays.sort(methods,comparator_);
        Vector methodList = new Vector();
        MethodUtil methodUtil = null;
        for(int i=0 ; i<methods.length ; i++){
            if(ClassVisibility.hasToBeAdded(methods[i].getModifiers(),config,ClassVisibilityConfig.METHOD)){
                methodUtil = new MethodUtil(methods[i]);
                methodList.add(methodUtil.toHTML());
            }                
        }
        return (String[])methodList.toArray(new String[0]);
    }

    protected String[] getInnerClasses(Class[] classes, ClassVisibilityConfig config){
        Arrays.sort(classes,comparator_);
        Vector classList = new Vector();
        ClassUtil classUtil = null;
        for(int i=0 ; i<classes.length ; i++){
            if(ClassVisibility.hasToBeAdded(classes[i].getModifiers(),config,ClassVisibilityConfig.INNER_CLASS)){
                classUtil = new ClassUtil(classes[i]);
                classList.add(classUtil.toHTML());
            }                
        }
        return (String[])classList.toArray(new String[0]);
    }

    protected String getHTMLList(String[] elements){
        if(elements!=null){
            StringBuffer list = new StringBuffer();
            list.append("<ul>");
            for(int i = 0 ; i < elements.length ; i++)
                list.append("<li>" + elements[i] + "</li>");
            list.append("</ul>");
            return list.toString();
        }
        return "";
    }

    //==================================================================
    //
    // Public methods for Panel interface.
    //
    //==================================================================


    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Panel#getPanel()
     */
    public Object getPanel() {
        return panel_;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Panel#selected(org.objectweb.util.explorer.api.TreeView)
     */
    public void selected(TreeView treeView) {

        Class theClass = (Class)treeView.getSelectedObject();
        ClassVisibilityConfig config = (ClassVisibilityConfig)ClassVisibility.config_.get(theClass.getName());
        if(config == null)
            config = (ClassVisibilityConfig)ClassVisibility.config_.get(ClassVisibility.DEFAULT_CONFIG);    

        htmlText_.append("<html>");
        htmlText_.append("<header></header>");
        htmlText_.append("<body>");

        String name = theClass.getName();
        String package_ = theClass.isPrimitive()?"":(name.lastIndexOf('.')==-1?"":name.substring(0,name.lastIndexOf('.')));
        String type = theClass.isInterface()?"Interface ":"Class ";
        String className = name.lastIndexOf('.')==-1?name:name.substring(name.lastIndexOf('.')+1); 
        htmlText_.append(package_);
        htmlText_.append("<h2>" + type + " " + className + "</h2>");
        htmlText_.append("<hr width=\"50%\"><br>");
        
        String[] fields = getFields(theClass.getDeclaredFields(), config);
        if(fields.length>0){
            htmlText_.append("<b>Fields</b>");
            htmlText_.append(getHTMLList(fields));
        }

        String[] methods = getMethods(theClass.getDeclaredMethods(), config);
        if(methods.length>0){
            htmlText_.append("<b>Methods</b>");
            htmlText_.append(getHTMLList(methods));
        }

        String[] innerClasses = getInnerClasses(theClass.getDeclaredClasses(), config);
        if(innerClasses.length>0){
            htmlText_.append("<b>Inner classes</b>");
            htmlText_.append(getHTMLList(innerClasses));
        }
        
        htmlText_.append("</body>");
        htmlText_.append("</html>");
        
        JEditorPane html = new JEditorPane("text/html",htmlText_.toString()); 
        html.setEditable(false);
        panel_.add(html);
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Panel#unselected(org.objectweb.util.explorer.api.TreeView)
     */
    public void unselected(TreeView treeview) {
        // Nothing to do
    }

}
