/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.explorer.api;

import java.io.Serializable;

/**
 * Entries are non-mutable structures representing entries in contexts.
 *
 * An Entry is composed of a <code>&lt;name,valuet&gt;</code> tuple,
 * where name is an Object, value is an Object.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.3
 *
 */
public interface Entry
         extends Serializable
{

    /**
     * Fixes the name of the entry.
     *
     * This method updates the name of the entry.
     *
     * @param value The name of the target entry.
     *
     */
    public void 
    setName(Object value);
    
    /**
     * Gets the name of the entry.
     *
     * This method does not update the name of the entry.
     *
     * @return The name of the target entry, in the context it belongs to.
     *
     */
    public Object 
    getName();
    
    /**
     * Fixes the value contained in the entry.
     * 
     * This method updates the value contained in the entry.
     * 
     * @param value The value contained in the entry.
     */
    public void 
    setValue(Object value);
        
    /**
     * Gets the value contained in the entry.
     * 
     * This method does not update the value contained in the entry.
     * 
     * @return The value contained in the entry.
     */
    public Object 
    getValue();

    /**
     * Fixes the wrapper of the value contained in the entry.
     * 
     * This method updates the value contained in the entry.
     * 
     * @param value
     */
    public void
    setWrapper(Context value);    
    
    /**
     * Gets the wrapper of the value contained in the entry.
     * 
     * This method does not update the value contained in the entry.
     * 
     * @return The value contained in the entry.
     */
    public Context 
    getWrapper();
    
    
}