/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.explorer.api;

/**
 * <p>
 * Defines an menu item in a popup menu. <br>
 * In order to define a menu item, you can have a look to the corresponding
 * <a href="explorer-dtd.html#menu">DTD element</a> or to 
 * an <a href="package-summary.html#xml">XML example.</a>
 * </p>
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 *         
 * @version 0.2
 */
public interface MenuItem 
{

    /** Indicates that a menu is enabled */
    public static final int ENABLED_STATUS = 1;

    /** Indicates that a menu is disabled */
    public static final int DISABLED_STATUS = ENABLED_STATUS + 1;

    /** Indicates that a menu is not visible */
    public static final int NOT_VISIBLE_STATUS = DISABLED_STATUS + 1;

    /**
     * Indicates if the menu item must be enabled, disabled or not visible.
     * <br>Possible values:
     * <ul>
     * <li>ENABLED_STATUS: The menu item is enabled.</li>
     * <li>DISABLED_STATUS: The menu item is disabled.</li>
     * <li>NOT_VISIBLE_STATUS: The menu item is not visible.</li>
     * </ul>
     *  
     * @param treeView A view to obtain the node to check.
     * 
     * @return The status associated to the menu item.
     */
    public int 
    getStatus(TreeView treeView);

    /**
     * Invoked when an action occurs on the menu item.
     *
     * @param treeView The contextual MenuItemTreeView.
     * 
     * @exception Exception The invocation may thrown every kind of exception.
     */
    public void 
    actionPerformed(MenuItemTreeView treeView) 
    throws Exception;
    
}
