package org.objectweb.util.explorer.context.api;

import org.objectweb.util.explorer.api.Context;
import org.objectweb.util.explorer.core.common.api.ContextContainer;

/**
 * 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public interface ContextContainerFactory {

    /** The name of the Fractal interface. */
    public static final String CONTEXT_CONTAINER_FACTORY = "context-container-factory";
    
    /**
     * Creates a new instance of <code>ContextContainer</code>.
     * If some decoders are defined, it adds them as interceptors. 
     * @return A new instance of context container.
     */
    public ContextContainer create();
    
    /**
     * Wraps the given <code>ContextContainer</code> instance
     * with some interceptors if decoders are defined.
     * @param context The contextContainer on which interceptors may be added.
     * @return An instance of context container.
     */
    public ContextContainer create(ContextContainer context);
    
    /**
     * Wraps the given <code>Context</code> instance
     * with some interceptors if decoders are defined.
     * @param context The context on which interceptors may be added.
     * @return An instance of context.
     */
    public Context create(Context context);
    
}
