/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.explorer.context.lib;

import org.objectweb.util.explorer.api.Context;
import org.objectweb.util.explorer.api.Entry;
import org.objectweb.util.explorer.context.api.Decoder;
import org.objectweb.util.explorer.context.api.DecoderManager;
import org.objectweb.util.explorer.core.common.lib.DefaultContext;

/**
 * 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class DecoderContext 
  implements Context, DecoderManager 
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================
    
    protected Context delegate_ = null;
    
    protected Decoder decoder_ = null;
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Default Constructor
     */
    public DecoderContext(){
        this(new DefaultContext());
    }
    
    /**
     * Constructor with specific delegate
     */
    public DecoderContext(Context delegate){
        if(delegate!=null)
            delegate_ = delegate;
        else 
            delegate_ = new DefaultContext();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for Context interface. 
    //
    // ==================================================================    
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Context#getEntries(java.lang.Object)
     */
    public Entry[] getEntries(Object object) {
        Entry[] entries = delegate_.getEntries(object);
        if(entries!=null && decoder_!=null){
            for (int i = 0; i < entries.length; i++) {
                Object obj = decoder_.decode(entries[i].getValue());
                entries[i].setValue(obj);
            }
        }
        return entries;
    } 

    // ==================================================================
    //
    // Public methods for DecoderManager interface. 
    //
    // ==================================================================    
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.context.api.DecoderManager#setDecoder(org.objectweb.util.explorer.context.api.Decoder)
     */
    public void setDecoder(Decoder decoder) {
        decoder_ = decoder;
    }
    
}
