/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.explorer.context.lib;

import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.util.explorer.api.Context;
import org.objectweb.util.explorer.context.api.ContextContainerFactory;
import org.objectweb.util.explorer.context.api.ContextPropertiesProvider;
import org.objectweb.util.explorer.context.api.Decoder;
import org.objectweb.util.explorer.core.common.api.ContextContainer;
import org.objectweb.util.explorer.core.common.lib.BindingFeature;
import org.objectweb.util.explorer.core.common.lib.DefaultContextContainer;

/**
 * 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class Factory 
     extends BindingFeature 
  implements ContextContainerFactory 
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    protected ContextPropertiesProvider getPropertiesFeeder(){
        try {
            return (ContextPropertiesProvider)lookupFc(ContextPropertiesProvider.CONTEXT_PROPERTIES_PROVIDER);
        } catch (NoSuchInterfaceException e) {
            getTrace().warn(ContextPropertiesProvider.CONTEXT_PROPERTIES_PROVIDER + ": interface not found!");
            return null;
        }
    }
    
    // ==================================================================
    //
    // Public methods for BindingFeature abstract class. 
    //
    // ==================================================================    
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.common.lib.BindingFeature#clientFc()
     */
    public String[] clientFc() {
        return new String[]{ContextPropertiesProvider.CONTEXT_PROPERTIES_PROVIDER}; 
    }

    // ==================================================================
    //
    // Public methods for ContextContainerFactory interface. 
    //
    // ==================================================================    
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.context.api.ContextContainerFactory#create()
     */
    public ContextContainer create() {
        return create(new DefaultContextContainer());
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.context.api.ContextContainerFactory#create(org.objectweb.util.explorer.core.common.api.ContextContainer)
     */
    public ContextContainer create(ContextContainer context) {
        Decoder decoder = getPropertiesFeeder().getDecoder();
        if(decoder!=null){
            DecoderContextContainer cc = new DecoderContextContainer(context);
            cc.setDecoder(decoder);
            return cc;
        } else {
            return context;
        }    
    }
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.context.api.ContextContainerFactory#create(org.objectweb.util.explorer.api.Context)
     */
    public Context create(Context context) {
        Decoder decoder = getPropertiesFeeder().getDecoder();
        if(decoder!=null){
            DecoderContext cc = new DecoderContext(context);
            cc.setDecoder(decoder);
            return cc;
        } else {
            return context;
        }    
    }
    
}

