/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2005 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================
$Id: DefaultKey.java,v 1.2 2005/07/06 15:36:00 moroy Exp $
====================================================================*/

package org.objectweb.util.explorer.core.common.lib;

import org.objectweb.util.explorer.ExplorerUtils;
import org.objectweb.util.explorer.core.role.api.Role;

/**
 * This class represents the key of the data structure containing the Explorer configuration.
 * This is composed of two elements which are the ID and the associated role.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class DefaultKey 
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================

    /** The ID of the Type System */
    protected String typeSystemId_;
    
    /** The type name. */
    protected String typeName_; 
    
    /** The role for which the node configuration is defined. */
    protected Role role_;
        
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Default constructor.
     * @param typeSystemId The ID of the Type System.
     * @param typeName The type name.
     * @param role The role for which the node configuration is defined.
     */
    public DefaultKey(String typeSystemId, String typeName, Role role) {
        this.typeSystemId_ = typeSystemId;
        this.typeName_ = typeName;
        this.role_ = role;
    }

    // ==================================================================
    //
    // Internal method.
    //
    // ==================================================================


    
    /**
     * Two keys are considered equal if they have 
     * the same type system id, the same type name, and the same role.
     */
    protected boolean equals(DefaultKey key){
        if (key != null) {
            return ExplorerUtils.compareObjects(key.typeSystemId_,typeSystemId_) 
              && ExplorerUtils.compareObjects(key.typeName_,typeName_)
              && ExplorerUtils.compareObjects(key.role_,role_);
        }
        return false;
    }
    

    // ==================================================================
    //
    // Public methods surcharging Object class.
    //
    // ==================================================================    
   
    /**
     * Surcharging the Object.equals method.
     * @see DefaultKey#equals(DefaultKey)
     */
    public boolean equals(Object o){
        if(o!=null && o instanceof DefaultKey)
            return equals((DefaultKey)o);
        return false;
    }
    
    /**
     * Return a String representation of a DefaultKey  
     */
    public String toString(){
        return "DefaultKey[typeSystem=" + typeSystemId_ + ", typeName=" + typeName_ + ", role=" + (role_!=null?role_.toString():"null") + "]";
    }
    
    /**
     * Returns a hash code value for the object.
     * @see java.lang.Object#hashCode()
     */
    public int hashCode(){
       return ExplorerUtils.getHashCode(typeSystemId_) 
           + ExplorerUtils.getHashCode(typeName_) 
           + ExplorerUtils.getHashCode(role_);  
    }
}

