/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.explorer.core.dnd.api;

import org.objectweb.util.explorer.core.common.api.Description;

/**
 * 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public interface DnDDescriptions 
         extends Description 
{
    
    /**
     * Adds the given drop action into the list of available DnD actions.
     * @param codeDesc The description of the code defining the drop action.
     */
    public void addDropAction(DnDDescription dndDesc);
    
    /**
     * Provides the drop action corresponding to the given acion type.
     * @param actionType The type of the action. This parameter may take 
     * the following values:
     * <ul>
     *   <li>DnDDescription.MOVE_ACTION</li>
     *   <li>DnDDescription.COPY_ACTION</li>
     *   <li>DnDDescription.LINK_ACTION</li>
     * </ul>
     * @return The corresponding drop action.
     */
    public DnDDescription getDropAction(String actionType);
    
    /**
     * Provides a string representation for all the available drop actions.
     * @return An array containing the representation of the available drop actions (One drop action description per array element). 
     */
    public String[] getActionsDescription();
    
}
