/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.explorer.core.menu.lib;

import org.objectweb.util.explorer.ExplorerUtils;
import org.objectweb.util.explorer.core.code.api.CodeDescription;
import org.objectweb.util.explorer.core.common.api.Description;
import org.objectweb.util.explorer.core.icon.api.IconDescription;
import org.objectweb.util.explorer.core.menu.api.AcceleratorDescription;
import org.objectweb.util.explorer.core.menu.api.ItemDescription;
import org.objectweb.util.explorer.core.menu.api.MnemonicDescription;

/**
 * Basic implementation of the <code>ItemDescription</code> interface.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class BasicItemDescription 
  implements ItemDescription 
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================

    protected String label_;
    protected boolean treeChildVisible_ = false;
    protected boolean typeChildVisible_ = true;
    protected CodeDescription codeDesc_;
    protected IconDescription iconDesc_;
    protected AcceleratorDescription acceleratorDesc_;
    protected MnemonicDescription mnemonicDesc_;
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Two ItemDescription are considered as equals if and only if 
     * they have the same label and the same CodeDescription.
     */
    protected boolean equals(BasicItemDescription itemDesc){
        return ExplorerUtils.compareObjects(label_, itemDesc.label_)
            && ExplorerUtils.compareObjects(codeDesc_, itemDesc.codeDesc_);
    }
  
    // ==================================================================
    //
    // Public methods for Description interface.
    //
    // ==================================================================
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.common.api.Description#getDescriptionType()
     */
    public String getDescriptionType() {
        return Description.ITEM_DESCRIPTION;
    }


    /* (non-Javadoc)
     * @see boolean#isNull()
     */
    public boolean isEmpty() {
        return label_==null || label_.equals("") || codeDesc_==null || codeDesc_.isEmpty();
    }
    
    // ==================================================================
    //
    // Public methods for ItemDescription interface.
    //
    // ==================================================================
        
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#setLabel(java.lang.String)
     */
    public void setLabel(String label) {
        label_ = label;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#getLabel()
     */
    public String getLabel() {
        return label_;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#setTreeChildVisible(boolean)
     */
    public void setTreeChildVisible(boolean treeChildVisible) {
        treeChildVisible_ = treeChildVisible;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#getTreeChildVisible()
     */
    public boolean getTreeChildVisible() {
        return treeChildVisible_;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#setTypeChildVisible(boolean)
     */
    public void setTypeChildVisible(boolean typeChildVisible) {
        typeChildVisible_ = typeChildVisible;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#getTypeChildVisible()
     */
    public boolean getTypeChildVisible() {
        return typeChildVisible_;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#setCodeDescription(org.objectweb.util.explorer.core.code.api.CodeDescription)
     */
    public void setCodeDescription(CodeDescription codeDescription) {
        codeDesc_ = codeDescription;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#getCodeDescription()
     */
    public CodeDescription getCodeDescription() {
        return codeDesc_;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#setIconDescription(org.objectweb.util.explorer.core.icon.api.IconDescription)
     */
    public void setIconDescription(IconDescription iconDescription) {
        iconDesc_ = iconDescription;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#getIconDescription()
     */
    public IconDescription getIconDescription() {
        return iconDesc_;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#setAcceleratorDescription(org.objectweb.util.explorer.core.menu.api.AcceleratorDescription)
     */
    public void setAcceleratorDescription(AcceleratorDescription acceleratorDescription) {
        acceleratorDesc_ = acceleratorDescription;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#getAcceleratorDescription()
     */
    public AcceleratorDescription getAcceleratorDescription() {
        return acceleratorDesc_;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#setMnemonicDescription(org.objectweb.util.explorer.core.menu.api.MnemonicDescription)
     */
    public void setMnemonicDescription(MnemonicDescription mnemonicDescription) {
        mnemonicDesc_ = mnemonicDescription;    
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.menu.api.ItemDescription#getMnemonicDescription()
     */
    public MnemonicDescription getMnemonicDescription() {
        return mnemonicDesc_;
    }
    
    // ==================================================================
    //
    // Public methods surcharging Object class.
    //
    // ==================================================================    
   
    /**
     * Surcharging the Object.equals method.
     * @see DefaultKey#equals(DefaultKey)
     */    
    public boolean equals(Object o){
        if(o!=null && o instanceof BasicItemDescription)
            return equals((BasicItemDescription)o);
        return false;
    }
    
    /**
     * Return a String representation of a BasicItemDescription  
     */
    public String toString(){
        return "BasicItemDescription[" +
                "label=" + ExplorerUtils.toString(label_) +
                ", treeChildVisible=" + treeChildVisible_ +
                ", typeChildVisible=" + typeChildVisible_ +
                ", codeDesc=" + ExplorerUtils.toString(codeDesc_) +
                ", iconDesc=" + ExplorerUtils.toString(iconDesc_) +
                ", acceleratorDesc=" + ExplorerUtils.toString(acceleratorDesc_) +
                ", mnemonicDesc=" + ExplorerUtils.toString(mnemonicDesc_) +
                "]";
    }  
    
}


