/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.explorer.core.naming.lib;

import org.objectweb.util.explorer.ExplorerUtils;
import org.objectweb.util.explorer.api.Context;
import org.objectweb.util.explorer.api.Entry;


/**
 * Default basic implementation of the Entry interface.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 * @version 0.1
 */
public class DefaultEntry 
  implements Entry 
{

    // ==================================================================
    //
    // Internal states.
    //
    // ==================================================================

    /** The name. */
    protected Object name_;
        
    /** The value. */
    protected Object value_;

    /** The wrapper*/
    protected Context wrapper_;
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Constructs a DefaultEntry with a name and value.
     *
     * This constructor sets the name and value
     * to respectively the given name and value.
     *
     * @param name The name.
     * @param value The value.
     *
     * @postcondition
     *        getName() == name
     *  and   getValue() == value
     */
    public DefaultEntry(Object name, Object value) {
        // Inits the internal state.
        name_ = name;
        setValue(value);
    }
    
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    protected boolean equals(DefaultEntry entry){
        if (entry!=null){
            return (this==entry)
                || (ExplorerUtils.compareObjects(name_, entry.name_)
                && ExplorerUtils.compareObjects(value_, entry.value_));
        }
        return false;
    }
    
    // ==================================================================
    //
    // Public methods for interface Entry.
    //
    // ==================================================================

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Entry#getValue()
     */
    public Object getValue() {
        return value_;
    }    
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Entry#setName()
     */
    public void setName(Object name) {
        this.name_ = name;
    }
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Entry#setValue(java.lang.Object)
     */
    public void setValue(Object value) {
        this.value_ = value;
        if(value!=null && value instanceof Context){
            wrapper_ = (Context)value;
        }
    }
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Entry#getName()
     */
    public Object getName() {
        return name_;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Entry#getWrapper()
     */
    public Context getWrapper() {
        return wrapper_;
    }
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.api.Entry#setWrapper(org.objectweb.util.explorer.api.Context)
     */
    public void setWrapper(Context wrapper) {
        this.wrapper_ = wrapper;
    }
    
    // ==================================================================
    //
    // Public methods surcharging Object class.
    //
    // ==================================================================    
   
    /**
     * Surcharging the Object.equals method.
     * Tests if a given object is equals to the target entry.
     *
     * @param o The given object.
     *
     * @return
     *  true   if the given entry is the same object as the target entry,
     *      or if it is an Entry instance and the name and value
     *         of the given entry are equals to the name and value
     *         of the target entry;
     *  false otherwise.
     * `
     * @see DefaultKey#equals(DefaultKey)
     */    
    public boolean equals(Object o){
        if(o!=null && o instanceof DefaultEntry)
            return equals((DefaultEntry)o);
        return false;
    }
    
    /**
     * Return a String representation of a BasicItemDescription  
     */
    public String toString(){
        return "DefaultEntry[" +
                "name=" + ExplorerUtils.toString(name_) +
                ", value=" + value_ +
                "]";
    }    

    /**
     * Returns a hash code value for the object.
     * @see java.lang.Object#hashCode()
     */
    public int hashCode(){
       return ExplorerUtils.getHashCode(name_) 
           + ExplorerUtils.getHashCode(value_);  
    }    
}
