/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.explorer.core.panel.api;

import org.objectweb.util.explorer.core.code.api.CodeDescription;
import org.objectweb.util.explorer.core.common.api.Description;

/**
 * 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public interface PanelDescription 
         extends Description 
{

    /** The different kind of panels. */
    public static final String PANEL = "panel";
    public static final String TABLE = "table";
    public static final String COMPOSITE_PANEL = "composite";

    /**
     * Provides the type of panel
     * @return
     */
    public String getPanelType();
    
    /**
     * Returns the code associated to this panel.
     * The returned value may be null in the case of a composite panel.
     */
    public CodeDescription getCodeDescription();
    
    /**
     * Fixes the code associated to this panel.
     * @param codeDesc The associated code description.
     */
    public void setCodeDescription(CodeDescription codeDesc);
    
    /**
     * Fixes the inheritTypePanel value.
     * @param inheritTypePanel true if this panel has to inherit panel 
     * from parents at the java type inheritance level and false otherwise. 
     */
    public void setInheritTypePanel(boolean inheritTypePanel);
    
    /**
     * Indicates if this panel has to inherit panel from parents 
     * at the java type inheritance level.
     */
    public boolean inheritTypePanel();
    
}
