/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2005 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================
$Id: RoleProvider.java,v 1.2 2005/07/06 15:36:00 moroy Exp $
====================================================================*/

package org.objectweb.util.explorer.core.role.api;

/**
 * This interface resolves the mappings between role ID and its associated Role object. 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public interface RoleProvider {

    /** The name of the fractal interface reference. */
    public static String ROLE_PROVIDER = "role-provider";
    /** Represent the default user (when no user is defined). */
    public static final String DEFAULT_ROLE = "_Default_Role_";
    
    /**
     * Provides the role identified by the given id param (or null if no mapping is defined).
     * @param roleId The ID of the role.
     * @return The associated Role.
     */
    public Role getRole(String roleId);
    
    /**
     * Provides an array of roles identified by the given array of IDs  (or and empty array if no mappings are defined).
     * @param id The IDs of the roles.
     * @return The associated Roles.
     */
    public Role[] getRoles(String[] roleIds);

    /**
     * Provides an array of roles ids corresponding to the given array of Roles.
     * @param roles The array of roles
     * @return The corresponding array of role ids
     */
    public String[] getRoleIds(Role[] roles);
    
    /**
     * Provides the inherited roles of the given role IDs. 
     * If no inherited role is defined, an empty array is returned.
     * @param roleIds An array of roles ID.
     * @return An array containing the inherited roles of the given roles.
     */
    public String[] getInheritedRoleIds(String[] roleIds);

    /**
     * Provides the list of all defined roles.
     * Equivalent to <code>RoleProvider.getRoleList(false)</code>.
     * @see RoleProvider#getRoleList(boolean)
     * @return The list of defines roles.
     */
    public String[] getRoleList();
    
    /**
     * Provides the list of all defined roles, sorted in alphabetic order.
     * Equivalent to <code>RoleProvider.getRoleList(false, false)</code>.
     * @see RoleProvider#getRoleList(boolean, boolean)
     * @return The list of defined roles.
     */
    public String[] getRoleList(boolean alphabeticOrder);
    
    /**
     * Provides the list of all defined roles (expected those which are considered as abstracts), 
     * sorted in alphabetic order.
     * @return The list of defined roles.
     */
    public String[] getRoleList(boolean alphabeticOrder, boolean excludedAbstractRoles);
        
    /**
     * Provides the default role.
     * @return The default role.
     */
    public Role getDefaultRole();    
    
}
