/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2005 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================
$Id: DefaultRoleDescription.java,v 1.2 2005/07/06 15:36:01 moroy Exp $
====================================================================*/

package org.objectweb.util.explorer.core.role.lib;

import org.objectweb.util.explorer.core.common.api.Description;
import org.objectweb.util.explorer.core.role.api.RoleDescription;

/**
 * Basic implementation of a Role definition. 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class DefaultRoleDescription 
  implements RoleDescription 
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================

    protected String id_;
    
    protected String[] inheritance_;
    
    protected boolean concrete_ = true;
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // No internal method.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for Description interface.
    //
    // ==================================================================
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.common.api.Description#getDescriptionType()
     */
    public String getDescriptionType() {
        return Description.ROLE_DESCRIPTION;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.common.api.Description#isEmpty()
     */
    public boolean isEmpty() {
        return id_==null || id_.equals("");
    }    
    
    // ==================================================================
    //
    // Public methods for ... interface.
    //
    // ==================================================================    
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.role.api.RoleDescription#setId(java.lang.String)
     */
    public void setId(String id) {
        id_ = id;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.role.api.RoleDescription#getId()
     */
    public String getId() {
        return id_;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.role.api.RoleDescription#setInheritance(java.lang.String[])
     */
    public void setInheritance(String[] inheritance) {
        inheritance_ = inheritance;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.role.api.RoleDescription#getInheritance()
     */
    public String[] getInheritance() {
        return inheritance_;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.role.api.RoleDescription#setConcrete(boolean)
     */
    public void setConcrete(boolean concrete) {
        concrete_ = concrete;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.role.api.RoleDescription#isConcrete()
     */
    public boolean isConcrete() {
        return concrete_;
    }

}