/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.explorer.interpreter.lib.swing;

import java.util.Map;

import org.objectweb.util.explorer.api.Panel;
import org.objectweb.util.explorer.api.Table;
import org.objectweb.util.explorer.api.Tree;
import org.objectweb.util.explorer.core.code.api.Code;
import org.objectweb.util.explorer.core.common.api.Description;
import org.objectweb.util.explorer.core.panel.api.CompositePanelDescription;
import org.objectweb.util.explorer.core.panel.api.PanelDescription;
import org.objectweb.util.explorer.core.panel.api.TableDescription;
import org.objectweb.util.explorer.interpreter.api.DescriptionInterpreter;
import org.objectweb.util.explorer.interpreter.lib.AbstractDescriptionInterpreter;
import org.objectweb.util.explorer.resolver.api.PropertyResolver;
import org.objectweb.util.explorer.swing.panel.BasicCompositePanel;
import org.objectweb.util.explorer.swing.panel.BasicTablePanel;

/**
 * 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class PanelInterpreter 
     extends AbstractDescriptionInterpreter 
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    protected Panel createPanel(TableDescription table, Map params){
        Code tableCode = getCodeProvider().getCode(table.getCodeDescription());
        if(tableCode!=null && tableCode.isInstanceOf(Table.class)){
            BasicTablePanel p = new BasicTablePanel();
            p.setTable((Table)tableCode.createInstance());
            p.setPropertyResolver((PropertyResolver)params.get(PropertyResolver.PROPERTY_RESOLVER));
            p.setDescriptionInterpreter((DescriptionInterpreter)params.get(DescriptionInterpreter.DESCRIPTION_INTERPRETER));
            p.setTree((Tree)params.get(Tree.TREE));
            return p;
        } else {
            getTrace().warn(tableCode + " is not assignable from Table!");
            return null;            
        }
    }
    
    protected Panel createPanel(PanelDescription panel){
        Code panelCode = getCodeProvider().getCode(panel.getCodeDescription());
        if(panelCode!=null && panelCode.isInstanceOf(Panel.class)){
            return (Panel)panelCode.createInstance();
        } else {
            getTrace().warn(panelCode + " is not assignable from Panel!");
            return null;
        }
    }
    
    protected Panel createPanel(CompositePanelDescription panel, Map params){
        BasicCompositePanel compositePanel = new BasicCompositePanel();
        PanelDescription[] panelDescs = panel.getPanelDescriptions();
        for (int i = 0; i < panelDescs.length; i++) {
            PanelDescription panelDesc = panelDescs[i];
            if (PanelDescription.TABLE.equals(panelDesc.getPanelType())) {
                compositePanel.add(createPanel((TableDescription)panelDesc, params));
            } else if (PanelDescription.PANEL.equals(panelDesc.getPanelType())) {
                compositePanel.add(createPanel((PanelDescription)panelDesc));
            } else {
                compositePanel.add(createPanel((CompositePanelDescription)panelDesc));
            }
        }
        return compositePanel;
    }
        
    // ==================================================================
    //
    // Public methods for DescriptionInterpreter interface. 
    //
    // ==================================================================    
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.interpreter.api.DescriptionInterpreter#interprete(org.objectweb.util.explorer.core.common.api.Description, java.lang.Object)
     */
    public Object interprete(Description description, Object params) {
        return createPanel((CompositePanelDescription)description, (Map)params);
    }

}
