/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.explorer.parser.lib;

import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.util.explorer.core.code.api.CodeProvider;
import org.objectweb.util.explorer.core.common.lib.BindingFeature;
import org.objectweb.util.explorer.explorerConfig.Node;
import org.objectweb.util.explorer.parser.api.NodeParser;
import org.objectweb.util.explorer.property.api.PropertyFeeder;

/**
 * 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public abstract class AbstractNodeParser 
     extends BindingFeature
  implements NodeParser
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================

    /** The feeder to use. */
    protected PropertyFeeder feeder_ = null;

    /** The code provider to use. */
    protected CodeProvider codeProvider_ = null;
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Provides the <code>PropertyFeeder</code> interface to use
     * to feed the Explorer.
     * @return The feeder to use.
     */
    protected PropertyFeeder getFeeder(){
        if(feeder_==null) {
            try {
                feeder_ = (PropertyFeeder)lookupFc(PropertyFeeder.PROPERTY_FEEDER);
            } catch (NoSuchInterfaceException e) {
                getTrace().warn(PropertyFeeder.PROPERTY_FEEDER + ": Interface not found!");
            }
        }
        return feeder_;
    }     

    /**
     * Provides the <code>CodeProvider</code> interface to use
     * to obtain a code according to a given code description.
     * @return The code provider to use.
     */
    protected CodeProvider getCodeProvider(){
        if(codeProvider_==null) {
            try {
                codeProvider_ = (CodeProvider)lookupFc(CodeProvider.CODE_PROVIDER);
            } catch (NoSuchInterfaceException e) {
                getTrace().warn(CodeProvider.CODE_PROVIDER + ": Interface not found!");
            }
        }
        return codeProvider_;
    }
    
    // ==================================================================
    //
    // Public methods for BindingFeature abstract class. 
    //
    // ==================================================================    
        
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.common.lib.BindingFeature#clientFc()
     */
    public String[] clientFc() {
        return new String[]{PropertyFeeder.PROPERTY_FEEDER, CodeProvider.CODE_PROVIDER};
    }

    // ==================================================================
    //
    // Public methods for NodeParser interface.
    //
    // ==================================================================    
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.parser.api.NodeParser#parseNode(java.lang.Object, org.objectweb.util.explorer.explorerConfig.Node)
     */
    public abstract void parseNode(Object key, Node node);
    
}


