/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.explorer.parser.lib;

import java.util.Iterator;
import java.util.List;

import org.objectweb.util.explorer.core.common.api.ExplorerConstants;
import org.objectweb.util.explorer.core.dnd.api.DnDDescription;
import org.objectweb.util.explorer.core.dnd.lib.BasicDnDDescription;
import org.objectweb.util.explorer.explorerConfig.DropAction;
import org.objectweb.util.explorer.explorerConfig.Node;

/**
 * This component manages the "dnd" XML element.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class DnDManager 
     extends AbstractNodeParser 
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    protected DnDDescription getDnDDescription(DropAction dropAction){
        DnDDescription desc = new BasicDnDDescription();
        desc.setType(dropAction.getType());
        desc.setLabel(dropAction.getLabel());
        desc.setCodeDescription(ParserUtils.getCodeDescription(dropAction.getCode()));
        return desc;
    }
    
    // ==================================================================
    //
    // Public methods for NodeParser interface. 
    //
    // ==================================================================    

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.parser.api.NodeParser#parseNode(java.lang.Object, org.objectweb.util.explorer.explorerConfig.Node)
     */
    public void parseNode(Object key, Node node) {
        List l = node.getDropActionList();
        Iterator it = l.iterator();
        while (it.hasNext()) {
            DropAction element = (DropAction) it.next();
            DnDDescription dndDesc = getDnDDescription(element);
            if(dndDesc!=null && !dndDesc.isEmpty()){
                getFeeder().feed(ExplorerConstants.DND_PROPERTY, key, dndDesc);
            }
        }
    }

}


