/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2005 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================
$Id: JarManager.java,v 1.2 2005/07/06 15:36:00 moroy Exp $
====================================================================*/

package org.objectweb.util.explorer.parser.lib;

import java.net.URL;
import java.util.Iterator;
import java.util.List;
import java.util.Vector;

import org.objectweb.util.explorer.core.common.lib.BasicLoggable;
import org.objectweb.util.explorer.core.common.lib.ClassResolver;
import org.objectweb.util.explorer.explorerConfig.Jar;
import org.objectweb.util.explorer.explorerConfig.Node;
import org.objectweb.util.explorer.explorerConfig.beans.ExplorerBean;
import org.objectweb.util.explorer.parser.api.ExplorerParser;
import org.objectweb.util.explorer.parser.api.NodeParser;

/**
 * This component manages the "jar" XML element.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class JarManager
     extends BasicLoggable
  implements ExplorerParser, NodeParser 
{

    //==================================================================
    //
    // No Internal State.
    //
    // ==================================================================

    // ==================================================================
    //
    // No Constructor.
    //
    // ==================================================================

    // ==================================================================
    //
    // No internal methods.
    //
    // ==================================================================

    /**
     * Loads the list of jar URL into the Explorer CLassLoader
     * @param jarList A list of jar to load
     */
    protected void loadJars(List jarList){
        Vector urlList = new Vector();
        Iterator it = jarList.iterator();
        while(it.hasNext()){
            String jarUrl = ((Jar)it.next()).getUrl();
            try {
                urlList.add(new URL(jarUrl));
            } catch (java.net.MalformedURLException e) {
                getTrace().info(jarUrl + " : Malformed URL!");
            }
        }
        if (!urlList.isEmpty()) {
            ClassResolver.addContext((URL[]) urlList.toArray(new URL[0]));
        }
    }    
    
    // ==================================================================
    //
    // Public methods for ExplorerParser interface.
    //
    // ==================================================================
        
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.parser.api.ExplorerParser#parseExplorer(org.objectweb.util.explorer.explorerConfig.beans.ExplorerBean)
     */
    public void parseExplorer(ExplorerBean explorer) {
        loadJars(explorer.getJarList());
    }

    // ==================================================================
    //
    // Public methods for NodeParser interface.
    //
    // ==================================================================

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.parser.api.NodeParser#parseNode(java.lang.Object, org.objectweb.util.explorer.explorerConfig.Node)
     */
    public void parseNode(Object key, Node node) {
        loadJars(node.getJarList());
    }
}
