/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2005 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================
$Id: NodeDispatcher.java,v 1.2 2005/07/06 15:36:00 moroy Exp $
====================================================================*/

package org.objectweb.util.explorer.parser.lib;

import java.util.Iterator;
import java.util.List;

import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.util.explorer.core.common.api.BadParamException;
import org.objectweb.util.explorer.core.common.api.KeyProvider;
import org.objectweb.util.explorer.core.common.lib.BindingFeature;
import org.objectweb.util.explorer.core.role.api.RoleProvider;
import org.objectweb.util.explorer.explorerConfig.Node;
import org.objectweb.util.explorer.explorerConfig.Role;
import org.objectweb.util.explorer.explorerConfig.beans.ExplorerBean;
import org.objectweb.util.explorer.parser.api.ExplorerParser;
import org.objectweb.util.explorer.parser.api.NodeParser;
import org.objectweb.util.explorer.parser.api.RoleParser;

/**
 * This component manages the "node" XML element.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class NodeDispatcher 
     extends BindingFeature 
  implements ExplorerParser, RoleParser 
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // No internal method.
    //
    // ==================================================================

    protected void dispatchNode(String roleId, Node theNode){
        try {
            String[] keyElements = new String[]{theNode.getTypeSystem(),theNode.getTypeName(),roleId};
            Object key = ((KeyProvider)lookupFc(KeyProvider.KEY_PROVIDER)).computeKey(keyElements);

            String[] clientIftNames = listFc();
            for (int i = 0; i < clientIftNames.length; i++) {
                if(clientIftNames[i].startsWith(NodeParser.NODE_PARSER)){
                    ((NodeParser)lookupFc(clientIftNames[i])).parseNode(key,theNode);
                }
            }
        } catch (BadParamException e) {
            e.printStackTrace();
        } catch (NoSuchInterfaceException e) {
            e.printStackTrace();
        }        
    }
    
    protected void parseNodeList(String roleId, List nodeList){
        Iterator it = nodeList.iterator();
        while (it.hasNext()) {
            Node node = (Node)it.next();
            if(node!=null) {
                dispatchNode(roleId, node);
            }
        }
    }
    
    // ==================================================================
    //
    // Public methods for BindingFeature class.
    //
    // ==================================================================    
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.common.lib.BindingFeature#clientFc()
     */
    public String[] clientFc() {
        return new String[]{NodeParser.NODE_PARSER,
                            KeyProvider.KEY_PROVIDER};
    }

    // ==================================================================
    //
    // Public methods for ExplorerParser interface.
    //
    // ==================================================================    

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.parser.api.ExplorerParser#parseExplorer(org.objectweb.util.explorer.explorerConfig.beans.ExplorerBean)
     */
    public void parseExplorer(ExplorerBean explorer) {
        parseNodeList(RoleProvider.DEFAULT_ROLE,explorer.getNodeList());
    }

    // ==================================================================
    //
    // Public methods for RoleParser interface.
    //
    // ==================================================================    
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.parser.api.RoleParser#parseRole(org.objectweb.util.explorer.explorerConfig.Role)
     */
    public void parseRole(Role role) {
        parseNodeList(role.getId(),role.getNodeList());
    }
}
