/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.explorer.parser.lib;

import java.net.URL;

import org.objectweb.util.explorer.ExplorerUtils;
import org.objectweb.util.explorer.core.code.api.CodeDescription;
import org.objectweb.util.explorer.core.code.lib.BasicCodeDescription;
import org.objectweb.util.explorer.core.icon.api.IconDescription;
import org.objectweb.util.explorer.core.icon.lib.BasicIconCodeDescription;
import org.objectweb.util.explorer.core.icon.lib.BasicIconFileDescription;
import org.objectweb.util.explorer.explorerConfig.Code;
import org.objectweb.util.explorer.explorerConfig.Icon;

/**
 * Useful toolkit for Parser component.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class ParserUtils {

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal method.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods. 
    //
    // ==================================================================    
        
    /**
     * Provides a Code description for the given code element.
     */
    public static CodeDescription getCodeDescription(Code code){
        CodeDescription cd = new BasicCodeDescription();
        cd.setLanguage(code.getLanguage());
        cd.setCode(code.getValue());
        return cd;
    }

    /**
     * Provides an Icon description for the given icon element.
     */
    public static IconDescription getIconDescription(Icon icon){
        IconDescription iconDescription = null;
        if(icon!=null){
            if (icon.getIconFile()!=null) {
                URL url = ExplorerUtils.getURL(icon.getIconFile().getUrl());
                if(url!=null){
                    iconDescription = new BasicIconFileDescription();
                    ((BasicIconFileDescription)iconDescription).setURL(url);
                }
            } else if (icon.getCode()!=null) {
                CodeDescription codeDesc = getCodeDescription(icon.getCode());
                if(codeDesc!=null){
                    iconDescription = new BasicIconCodeDescription();
                    ((BasicIconCodeDescription)iconDescription).setCode(codeDesc);
                }
            }            
        }
        return iconDescription;
    }    
        
}


