/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2005 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================
$Id: RoleManager.java,v 1.2 2005/07/06 15:36:00 moroy Exp $
====================================================================*/

package org.objectweb.util.explorer.parser.lib;

import java.util.Iterator;
import java.util.List;
import java.util.StringTokenizer;
import java.util.Vector;

import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.util.explorer.core.common.lib.BindingFeature;
import org.objectweb.util.explorer.core.role.api.RoleDescription;
import org.objectweb.util.explorer.core.role.api.RoleFeeder;
import org.objectweb.util.explorer.core.role.lib.DefaultRoleDescription;
import org.objectweb.util.explorer.explorerConfig.Role;
import org.objectweb.util.explorer.explorerConfig.beans.ExplorerBean;
import org.objectweb.util.explorer.parser.api.ExplorerParser;
import org.objectweb.util.explorer.parser.api.RoleParser;

/**
 * This component manages the "role" XML element.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class RoleManager 
     extends BindingFeature 
  implements ExplorerParser 
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================

    protected boolean firstTime_ = true;
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    
    // ==================================================================
    //
    // No internal method.
    //
    // ==================================================================

    protected void initRole(){
        if(firstTime_){
            storeRole(createDefaultRoleDesc());
            firstTime_ = false;            
        }
    }

    public void storeRole(RoleDescription roleDesc){
        try {
            ((RoleFeeder)lookupFc(RoleFeeder.ROLE_FEEDER)).feed(roleDesc);
        } catch (NoSuchInterfaceException e1) {
            e1.printStackTrace();
        }
    }
    
    protected RoleDescription createDefaultRoleDesc(){
        RoleDescription defaultRole = new DefaultRoleDescription();
        defaultRole.setId(org.objectweb.util.explorer.core.role.api.RoleProvider.DEFAULT_ROLE);
        defaultRole.setInheritance(new String[0]);
        defaultRole.setConcrete(false);
        return defaultRole;
    }
    
    protected RoleDescription createRoleDesc(org.objectweb.util.explorer.explorerConfig.Role role){
        RoleDescription theRoleDef = new DefaultRoleDescription();
        
        Vector v = new Vector();
        if(role.getXmlextends()!=null){
            StringTokenizer st = new StringTokenizer(role.getXmlextends(),",");
            while (st.hasMoreTokens())
                v.add(st.nextToken().trim());
        }
        
        theRoleDef.setId(role.getId().trim());
        theRoleDef.setInheritance((String[])v.toArray(new String[0]));
        theRoleDef.setConcrete(role.getKind().equals("concrete"));
        
        return theRoleDef;
    }
    
    // ==================================================================
    //
    // Public methods for BindingFeature class.
    //
    // ==================================================================    
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.common.lib.BindingFeature#clientFc()
     */
    public String[] clientFc() {
        return new String[]{RoleParser.ROLE_PARSER,
                            RoleFeeder.ROLE_FEEDER};
    }

    // ==================================================================
    //
    // Public methods for ExplorerParser interface.
    //
    // ==================================================================    

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.parser.api.ExplorerParser#parseExplorer(org.objectweb.util.explorer.explorerConfig.beans.ExplorerBean)
     */
    public void parseExplorer(ExplorerBean explorer) {
        initRole();
        List theRoles = explorer.getRoleList();
        Iterator it = theRoles.iterator();
        while (it.hasNext()) {
            Role theRole = (Role) it.next();
            RoleDescription roleDesc = createRoleDesc(theRole);
            storeRole(roleDesc);
            
            String[] clientIftNames = listFc();
            for (int i = 0; i < clientIftNames.length; i++) {
                if(clientIftNames[i].startsWith(RoleParser.ROLE_PARSER)) 
                    try {
                        ((RoleParser)lookupFc(clientIftNames[i])).parseRole(theRole);
                    } catch (NoSuchInterfaceException e) {
                        e.printStackTrace();
                    }
            }
        }
    }

}