/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.explorer.property.lib;

import org.objectweb.util.explorer.core.common.api.Description;
import org.objectweb.util.explorer.core.panel.api.CompositePanelDescription;
import org.objectweb.util.explorer.core.panel.api.PanelDescription;
import org.objectweb.util.explorer.core.panel.lib.BasicCompositePanelDescription;

/**
 * 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class PanelProperty 
     extends AbstractProperty 
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Adds the given source panel into the given target panel if and only if
     * the target panel is a composite panel. Else, it creates a composite panel
     * and adds both the source and the target into this composite.
     */
    protected PanelDescription mergePanelDescription(PanelDescription source, PanelDescription target){
        if(target instanceof CompositePanelDescription){
            ((CompositePanelDescription)target).addPanelDescription(source);
            if(source.inheritTypePanel()){
                ((CompositePanelDescription)target).setInheritTypePanel(true);
            }
        } else {
            CompositePanelDescription composite = new BasicCompositePanelDescription();
            composite.addPanelDescription(target);
            composite.addPanelDescription(source);
            composite.setInheritTypePanel(source.inheritTypePanel()||target.inheritTypePanel());
            target=composite;
        }
        return target;
    }
    
    // ==================================================================
    //
    // Public methods for PropertyFeeder interface. 
    //
    // ==================================================================    
        
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.property.api.PropertyFeeder#feed(java.lang.String, java.lang.Object, org.objectweb.util.explorer.core.common.api.Description)
     */
    public void feed(String propertyType, Object key, Description value) {
        if(value!=null && value instanceof PanelDescription){
            //if(properties_.containsKey(key)){
            //    value = mergePanelDescription((PanelDescription)value, (PanelDescription)(Description)properties_.get(key));                
            //}
            properties_.put(key,value);
        }
    }

    // ==================================================================
    //
    // Public methods for PropertyProvider interface. 
    //
    // ==================================================================    

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.property.api.PropertyProvider#getPropertyDescription(java.lang.String, java.lang.Object)
     */
    public Description getPropertyDescription(String propertyType, Object key) {
        return (Description)properties_.get(key);
    }

}


