/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.explorer.property.lib;

import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.util.explorer.core.common.api.Description;
import org.objectweb.util.explorer.core.common.lib.BindingFeature;
import org.objectweb.util.explorer.property.api.PropertyProvider;

/**
 * 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class PropertyProviderDispatcher 
     extends BindingFeature 
  implements PropertyProvider 
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal method.
    //
    // ==================================================================

    /**
     * Provides the interface compliant with the given interface name suffixe.
     * The name of the binding must be the following:<br>
     * <code>&#160;&#160;PropertyProvider.PROPERTY_PROVIDER+"-collection-" + itfSuffixe</code>
     * @return The associated PropertyProvider
     */
    protected PropertyProvider getPropertyProvider(String itfSuffixe){
        try {
            return (PropertyProvider)lookupFc(PropertyProvider.PROPERTY_PROVIDER+"-collection-" + itfSuffixe);
        } catch (NoSuchInterfaceException e) {
            getTrace().info(PropertyProvider.PROPERTY_PROVIDER+"-collection-" + itfSuffixe + ": interface not found!");
            return null;
        }
    }
    
    // ==================================================================
    //
    // Public methods for BindingFeature abstract class. 
    //
    // ==================================================================    
        
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.common.lib.BindingFeature#clientFc()
     */
    public String[] clientFc() {
        return new String[]{PropertyProvider.PROPERTY_PROVIDER+"-collection"};
    }

    // ==================================================================
    //
    // Public methods for PropertyProvider interface. 
    //
    // ==================================================================    
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.common.api.PropertyProvider#getPropertyDescription(int, java.lang.Object)
     */
    public Description getPropertyDescription(String propertyType, Object key) {
        PropertyProvider propertyProvider = getPropertyProvider(propertyType);
        if (propertyProvider!=null)
            return propertyProvider.getPropertyDescription(propertyType,key);
        return null;
    }

}


