/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.explorer.resolver.lib;

import org.objectweb.util.explorer.core.menu.api.ItemDescription;
import org.objectweb.util.explorer.core.menu.api.MenuDescription;
import org.objectweb.util.explorer.core.menu.api.MenuElement;
import org.objectweb.util.explorer.core.menu.lib.BasicMenuDescription;

/**
 * This implementation of MenuDescription take into account the semantic
 * of the menu description attributes. It is used to compute the menu
 * decription to display for a selected node.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class ExtendedMenuDescription 
     extends BasicMenuDescription 
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal method.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods. 
    //
    // ==================================================================    
    
    /**
     * Adds the given menu elements of the source description into the menu description 
     * by taking into account the semantic of the menu descriptions attributes.
     * That is to say:
     * <ul>
     *   <li>It doesn't add any menu element if the inherit-type-menu attribute 
     *       of the target menu description is set to false.</li>
     *   <li>It doesn't add a menu element if the type-child-visible attribute 
     *       of the given menu element is set to false (except if the isFirst boolean value is true).</li>
     * </ul> 
     */
    public void addMenuElements(MenuDescription source, boolean isFirst){
        if(inheritTypeMenu_){
            MenuElement[] menuElements = source.getMenuElements();
            for (int i = 0; i < menuElements.length; i++) {
                MenuElement element = menuElements[i];
                if(!(element instanceof ItemDescription && !((ItemDescription)element).getTypeChildVisible() && !isFirst)){
                    addMenuElement(element);
                }
            }
            inheritTypeMenu_ = source.getInheritTypeMenu();
        }
    }
    
    /**
     * Adds the given menu elements of the source description into the menu description 
     * by taking into account the semantic of the menu descriptions attributes.
     * That is to say it doesn't add any menu element if the inherit-tree-menu attribute 
     * of the target menu description is set to false. Moreover, it cleans the children menu elements
     * list if this attribute is set to false whereas it was true.</li>
     */
    public void addChildrenMenuElements(MenuDescription source){
        if(inheritTreeMenu_){
            addMenuElements(source.getChildrenMenuElements());
            inheritTreeMenu_ = source.getInheritTreeMenu();
            if(!inheritTreeMenu_){
                childMenuElements_.clear();
            }
        }
    }
    
}


