/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.explorer.swing.gui.lib;

import org.objectweb.util.explorer.swing.gui.api.ValidateReport;


/**
 * Basic implementation of a ValidateReport.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * 
 * @version 0.1
 */
public class DefaultValidateReport 
  implements ValidateReport
{

    //==================================================================
    //
    // Internal state.
    //
    //==================================================================

    /** The result of the validate method invocation */
    protected boolean result_;
    
    /** The message which explains the result */
    protected String message_;

    //==================================================================
    //
    // Constructors.
    // 
    //==================================================================

    /**
     * Empty constructor
     * Default values are :
     * <ul>
     *   <li>result : true</li>
     *   <li>message : ""</li>
     * </ul>
     */
    public DefaultValidateReport(){
        result_ = true;
        message_ = "";
    }
    
    /**
     * Constructor with params
     * @param result The result of the validate method invocation 
     * @param message The message which explains the result 
     */
    public DefaultValidateReport(boolean result, String message){
        result_ = result;
        message_ = message;   
    }

    //==================================================================
    //
    // Internal methods.
    //
    //==================================================================

    //==================================================================
    //
    // Public methods for ValidateReport
    //
    //==================================================================

    /**
     * Fixes the result value.
     * <ul>
     *   <li>TRUE if the result is OK</li>
     *   <li>FALSE if the result is not OK</li>
     * </ul>
     * @param result
     */
    public void setResult(boolean result){
        result_ = result;
    }
    
    /**
     * Gets the result value.
     * @return The result value
     */
    public boolean getResult(){
        return result_;
    }
    
    /**
     * Fixes the message to explain why the result is not OK.
     * @param message An explanation message
     */
    public void setMessage(String message){
        message_ = message;
    }
    
    /**
     * Gets the explanation message
     * @return The explanation message
     */
    public String getMessage(){
        return message_;
    }

}