/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2005 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================
$Id: SwingExplorer.java,v 1.1 2005/07/05 09:16:30 moroy Exp $
====================================================================*/
package org.objectweb.util.explorer.swing.lib;

import java.awt.BorderLayout;

import javax.swing.JFrame;
import javax.swing.JSplitPane;

import org.objectweb.fractal.adl.Factory;
import org.objectweb.fractal.adl.FactoryFactory;
import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.util.Fractal;
import org.objectweb.util.explorer.api.Tree;
import org.objectweb.util.explorer.parser.api.ParserConfiguration;
import org.objectweb.util.explorer.swing.api.Explorer;
import org.objectweb.util.explorer.swing.api.StatusBar;
import org.objectweb.util.explorer.swing.api.ViewPanel;

/**
 * This frame is composed of three elements which are the followings:
 * <ul>
 *   <li>a tree view</li>
 *   <li>a status bar</li>
 *   <li>a view panel</li>
 * </ul>
 * It also wraps the corresponding Fractal component for simplicity concern.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class SwingExplorer 
     extends JFrame 
  implements org.objectweb.util.explorer.swing.api.SwingExplorer
{

	//===================================================================
	//
	// Internal States.
	//
	// ==================================================================

	/**
	 * The SwingExplorer component.
	 */
	private Component explorer_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Creates the Frame
     */
    protected void createFrame(){
        getContentPane().setLayout(new BorderLayout());
        getContentPane().add(new JSplitPane(
                JSplitPane.HORIZONTAL_SPLIT,
                true,
                new DefaultTreePanel(getExplorerItf().getTree()),
                getViewPanelItf().getViewPanel()), BorderLayout.CENTER);
        getContentPane().add(getStatusBarItf().getStatusBar(), BorderLayout.SOUTH);
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        pack();
    }
    
    /**
     * Default constructor
     * @param name The name of the frame
     */
    public SwingExplorer(String name){
        super(name);
        try {
        	// Creates a Fractal Explorer instance.
        	Factory f = FactoryFactory.getFactory(FactoryFactory.FRACTAL_BACKEND);
        	this.explorer_ = (Component)f.newComponent("org.objectweb.util.explorer.swing.SwingFractalExplorer",null);
        	Fractal.getLifeCycleController(this.explorer_).startFc();
        } catch (Exception e) {
            e.printStackTrace();
        }
        createFrame();
    }
    
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Provides a fractal interface.
     */
    protected Object getFcInterface(String name){
        try {
            return explorer_.getFcInterface(name);
        } catch (Exception e) {
            // Should never happened!
            return null;
        }                
    }
    
    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================
    
    /**
     * @see org.objectweb.util.explorer.swing.api.SwingExplorer#getParserConfigurationItf()
     */
    public ParserConfiguration getParserConfigurationItf() {
        return (ParserConfiguration)getFcInterface(ParserConfiguration.PARSER_CONFIGURATION);
    }
    
    /**
     * @see org.objectweb.util.explorer.swing.api.SwingExplorer#getTreeItf()
     */
    public Tree getTreeItf(){
        return (Tree)getFcInterface(Tree.TREE);
    }
    
    /**
     * @see org.objectweb.util.explorer.swing.api.SwingExplorer#getExplorerItf()
     */
    public Explorer getExplorerItf(){
      	return (Explorer)getFcInterface(Explorer.EXPLORER);
    }

    /**
     * @see org.objectweb.util.explorer.swing.api.SwingExplorer#getViewPanelItf()
     */
    public ViewPanel getViewPanelItf(){
        return (ViewPanel)getFcInterface(ViewPanel.VIEW_PANEL);
    }
    
    /**
     * @see org.objectweb.util.explorer.swing.api.SwingExplorer#getStatusBarItf()
     */
    public StatusBar getStatusBarItf() {
        return (StatusBar)getFcInterface(StatusBar.STATUS_BAR);
    }
}
