/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.explorer.swt.lib;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

import org.eclipse.swt.dnd.ByteArrayTransfer;
import org.eclipse.swt.dnd.TransferData;
import org.objectweb.util.explorer.api.Entry;
import org.objectweb.util.trace.TraceSystem;

/**
 * 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>,
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class EntryTransfer 
     extends ByteArrayTransfer 
{

    //==================================================================
    //
    // Internal States.
    //
    // ==================================================================
    
    private static final String MYTYPENAME = "EntryType";
    private static final int MYTYPEID = registerType(MYTYPENAME);
    private static EntryTransfer instance_ = new EntryTransfer();
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /* (non-Javadoc)
     * @see org.eclipse.swt.dnd.Transfer#getTypeIds()
     */
    protected int[] getTypeIds() {
        return new int[] {MYTYPEID};
    }

    /* (non-Javadoc)
     * @see org.eclipse.swt.dnd.Transfer#getTypeNames()
     */
    protected String[] getTypeNames() {
        return new String[]{MYTYPENAME};
    }
    
    // ==================================================================
    //
    // Public methods for ByteArrayTransfer abstract class. 
    //
    // ==================================================================    

    public static EntryTransfer getInstance () {
        return instance_;
    }
    
    public void javaToNative (Object object, TransferData transferData) {
        if (object == null || !(object instanceof Entry)) return;
        if (isSupportedType(transferData)) {
            Entry entry = (Entry) object;   
            try {
                ByteArrayOutputStream out = new ByteArrayOutputStream();
                ObjectOutputStream writeOut = new ObjectOutputStream(out);
                //writeOut.writeObject(entry);
                writeOut.writeObject(entry.getName());
                byte[] buffer = out.toByteArray();
                writeOut.close();

                super.javaToNative(buffer, transferData);
                
            } catch (IOException e) {
                TraceSystem.get("explorer").debug("[" + getClass().getName() + "] IOException: " + e.getMessage());
                e.printStackTrace();
            }
        }
    }

    public Object nativeToJava(TransferData transferData){
        if (isSupportedType(transferData)) {
            
            byte[] buffer = (byte[])super.nativeToJava(transferData);
            if (buffer == null) return null;
            
            Entry[] myData = new Entry[0];
            try {
                ByteArrayInputStream in = new ByteArrayInputStream(buffer);
                ObjectInputStream readIn = new ObjectInputStream(in);
                String name = (String) readIn.readObject();
                readIn.close();
            } catch (IOException ex) {
                return null;
            } catch (ClassNotFoundException e) {
                e.printStackTrace();
                return null;
            }
            return myData;
        }

        return null;
    }
}
