/*===========================================================================

ObjectWeb Explorer Framework
Copyright (C) 2000-2005 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s):  ______________________________________.

===========================================================================
$Id: Main.java,v 1.2 2005/07/06 15:36:02 moroy Exp $
===========================================================================*/

package test.swing;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.util.HashMap;

import javax.swing.JFrame;
import javax.swing.JSplitPane;

import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.adl.Factory;
import org.objectweb.fractal.adl.FactoryFactory;
import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;
import org.objectweb.fractal.util.Fractal;
import org.objectweb.util.explorer.api.Tree;
import org.objectweb.util.explorer.core.common.api.ContextContainer;
import org.objectweb.util.explorer.core.common.lib.DefaultContextContainer;
import org.objectweb.util.explorer.parser.api.ParserConfiguration;
import org.objectweb.util.explorer.swing.api.Explorer;
import org.objectweb.util.explorer.swing.api.StatusBar;
import org.objectweb.util.explorer.swing.api.ViewPanel;
import org.objectweb.util.explorer.swing.lib.DefaultTreePanel;

import test.Calculate;

/**
 * This class defines a console in order to test the Explorer Framework features.
 * 
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class Main 
     extends JFrame 
{

    /**
     * Populates the tree
     */
    protected void populateTree(Tree tree) {
        tree.addEntry("Java Properties", System.getProperties());
        Calculate c = new Calculate();
        ContextContainer contextContainer_ = new DefaultContextContainer();
        contextContainer_.addEntry("Calculate", c);
        tree.addEntry("Test", contextContainer_, 1);
        tree.addEntry("Object", new Object(), 1);
        tree.addEntry("Calculatrice", new Calculate());
        tree.addEntry("HashMap class", HashMap.class);
    }

    /**
     * Default constructor
     */
    public Main(String explorerPropertyFile) {        
        super("Explorer GUI");

        try {
            // Creates a Fractal Explorer instance.
            Factory f = FactoryFactory.getFactory(FactoryFactory.FRACTAL_BACKEND);
            Component explorer = (Component)f.newComponent("test.swing.SwingFractalExplorer",null);
            Fractal.getLifeCycleController(explorer).startFc();

            // Loads the configuration file.
            ParserConfiguration parser = (ParserConfiguration)explorer.getFcInterface(ParserConfiguration.PARSER_CONFIGURATION);
            parser.addPropertyFile(explorerPropertyFile);
            parser.parse();
        
            // Populates the tree.
            populateTree((Tree)explorer.getFcInterface(Tree.TREE));

            // Configures the main frame.
            Explorer explorerItf = (Explorer)explorer.getFcInterface(Explorer.EXPLORER);
            ViewPanel viewPanelItf = (ViewPanel)explorer.getFcInterface(ViewPanel.VIEW_PANEL);
            StatusBar statusBar = (StatusBar)explorer.getFcInterface(StatusBar.STATUS_BAR);
            JFrame frame = new JFrame("Explorer GUI");
            frame.getContentPane().setLayout(new BorderLayout());
            frame.getContentPane().add(new JSplitPane(
                    JSplitPane.HORIZONTAL_SPLIT,
                    true,
                    new DefaultTreePanel(explorerItf.getTree()),
                    viewPanelItf.getViewPanel()), BorderLayout.CENTER);
            frame.getContentPane().add(statusBar.getStatusBar(), BorderLayout.SOUTH);
            frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
            frame.pack();

            // Centers the frame
            Dimension screenSize =
                java.awt.Toolkit.getDefaultToolkit().getScreenSize();
            setLocation(
                (screenSize.width - getWidth()) / 2,
                (screenSize.height - getHeight()) / 2);
            
            frame.setVisible(true);
            
        } catch (ADLException e) {
            e.printStackTrace();
        } catch (IllegalLifeCycleException e) {
            e.printStackTrace();
        } catch (NoSuchInterfaceException e) {
            e.printStackTrace();
        }        
    }

    public static void main(String[] args) {
        new Main("resources/config/demoConfig.xml");
    }

}



