/*====================================================================

ObjectWeb Util Launcher Package.
Copyright (C) 2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Romain Rouvoy.
Contributor(s): .

--------------------------------------------------------------------
$Id: LauncherApplication.java,v 1.3 2004/09/24 20:24:59 rouvoy Exp $
====================================================================*/

package org.objectweb.util.launcher;


import org.objectweb.util.cmdline.api.Option;
import org.objectweb.util.cmdline.lib.ApplicationBase;

import org.objectweb.util.launcher.option.OptionVersion;
import org.objectweb.util.launcher.parser.ParserZeus;
import org.objectweb.util.launcher.parser.Repository;
import org.objectweb.util.trace.TraceSystem;



/**
 * LauncherApplication describe the treatments to apply.<BR>
 * <p>
 * this structure considers only characters list.
 * </p>
 * @author <a href="mailto:Romain.Rouvoy@lifl.fr">Romain Rouvoy</a>
 * @version 0.1
 */
public class LauncherApplication
     extends ApplicationBase
{
    /**
     * Default Constructor
     */
    public LauncherApplication() {
        super(new LauncherCmdline(), false);
        getCommandLine().addOption(new OptionVersion(this));
    }
    
    /**
     * Obtains the mailing list associated to this development.
     * @return The mailing list associated to this development.
     */
    public String getMailingList() {
        return "openccm@objectweb.org";
    }
    
    /**
     * Complete the incoming CommandJava with the content of the argument line.
     * @param repository the Repository with descriptions.
     * @param args the arguments for the application.
     */
    protected void process(Repository repository, StringList args) {
        Option[] opt = getCommandLine().getOptions();
        boolean default_run = true ;
        for (int i = 0 ; i < opt.length ; i++) {
            try {
                CommandBuilder builder = (CommandBuilder)opt[i];
                CommandJava[] cmd = builder.complete(repository);
              	if (cmd.length!=0) default_run = false;
                for (int j=0 ; j < cmd.length ; j++) {
                    cmd[j].addArguments(args);
                    cmd[j].run();
                }
            } catch(ClassCastException ex) {
                // Nothing to do if a CommandLine option is not a CommandBuilder
            }
        }        
        if (default_run) {
            LauncherCmdline cmdline = (LauncherCmdline) getCommandLine();            
            CommandJava cmd = CommandProvider.get(repository,"default");
            cmd.addArguments(args);
            cmd.run();
        }
    }
    
    /**
     * Starts the application.
     * @param args The command line arguments.
     * @return The status.
     */
    public int start(java.lang.String[] args) {
        StringList arg = new StringList(args);
        arg.remove(0);
        try {
            process((new ParserZeus()).load(args[0]), arg);
        } catch(Exception ex) {
            TraceSystem.get("launcher").fatal("Application terminated with "+ex);
            return -1;
        }
        return 0;
    }
}
