//#include <HomeFinderS.h>
#include <HomeFinder2S.h>

#include <Correspondance_table.h>
#include <cstdio>
#include <cstring>
#include <fstream>

using std::fstream;

class HomeFinder_impl : public POA_HomeFinder_ext
{
public:

  ~HomeFinder_impl();

  Components::CCMHome_ptr 
  find_home_by_component_type( const char* repid )
    throw( CORBA::SystemException, Components::HomeNotFound );

  Components::CCMHome_ptr
  find_home_by_home_type( const char* repid )
    throw( CORBA::SystemException, Components::HomeNotFound );

  Components::CCMHome_ptr
  find_home_by_name( const char* name )
    throw( CORBA::SystemException, Components::HomeNotFound );

  // --- registration ---

  void register_home_by_component_type( Components::CCMHome_ptr a_home, 
					const char* comp_repid )
    throw( CORBA::SystemException );

  void register_home_by_home_type( Components::CCMHome_ptr a_home,
				   const char* home_repid )
    throw( CORBA::SystemException );

  void register_home_by_name( Components::CCMHome_ptr a_home,
			      const char* name )
    throw( CORBA::SystemException );

  // --

  void register_object( const char* name, CORBA::Object_ptr obj )
    throw( CORBA::SystemException );

  CORBA::Object_ptr resolve_object( const char* name )
    throw( CORBA::SystemException, HomeFinder_ext::ObjectNotFound );

private:

  Correspondance_table< Components::CCMHome_ptr > by_comp_type_;
  Correspondance_table< Components::CCMHome_ptr > by_home_type_;
  Correspondance_table< Components::CCMHome_ptr > by_home_name_;

  Correspondance_table< CORBA::Object_ptr > objs_map_;
};

// ---

HomeFinder_impl::~HomeFinder_impl()
{
  typedef Correspondance_table< Components::CCMHome_ptr >::iterator CorrTable_HomeIter;

  for( CorrTable_HomeIter iter = by_comp_type_.begin();
       iter != by_comp_type_.end();
       iter++ )
    {
      CORBA::release( iter->value );
    }

  for( CorrTable_HomeIter iter = by_home_type_.begin();
       iter != by_home_type_.end();
       iter++ )
    {
      CORBA::release( iter->value );
    }

  for( CorrTable_HomeIter iter = by_home_name_.begin();
       iter != by_home_name_.end();
       iter++ )
    {
      CORBA::release( iter->value );
    }

  // --

  typedef Correspondance_table< CORBA::Object_ptr >::iterator  Obj_iter;

  for( Obj_iter iter = objs_map_.begin();
       iter != objs_map_.end();
       iter++ )
    {
      CORBA::release( iter->value );
    }

}

Components::CCMHome_ptr 
HomeFinder_impl::find_home_by_component_type( const char* repid )
  throw( CORBA::SystemException, Components::HomeNotFound )
{
  if( by_comp_type_.exists( repid ) )
    {
      return Components::CCMHome::_duplicate( by_comp_type_[ repid ] );
    }
  else
    {
      throw Components::HomeNotFound();
    }
}

Components::CCMHome_ptr
HomeFinder_impl::find_home_by_home_type( const char* repid )
  throw( CORBA::SystemException, Components::HomeNotFound )
{
  if( by_home_type_.exists( repid ) )
    {
      return Components::CCMHome::_duplicate( by_home_type_[ repid ] );
    }
  else
    {
      throw Components::HomeNotFound();
    }
}

Components::CCMHome_ptr
HomeFinder_impl::find_home_by_name( const char* name )
  throw( CORBA::SystemException, Components::HomeNotFound )
{
  if( by_home_name_.exists( name ) )
    {
      return Components::CCMHome::_duplicate( by_home_name_[ name ] );
    }
  else
    {
      throw Components::HomeNotFound();
    }
}

// ---

void 
HomeFinder_impl::register_home_by_component_type( Components::CCMHome_ptr a_home,
						  const char* comp_repid )
  throw( CORBA::SystemException )
{
  by_comp_type_[ comp_repid ] = Components::CCMHome::_duplicate( a_home );
}

void
HomeFinder_impl::register_home_by_home_type( Components::CCMHome_ptr a_home,
					     const char* home_repid )
  throw( CORBA::SystemException )
{
  by_home_type_[ home_repid ] = Components::CCMHome::_duplicate( a_home );
}

void
HomeFinder_impl::register_home_by_name( Components::CCMHome_ptr a_home,
					const char* name )
  throw( CORBA::SystemException )
{
  by_home_name_[ name ] = Components::CCMHome::_duplicate( a_home );
}

// --

void HomeFinder_impl::register_object( const char* name, CORBA::Object_ptr obj )
  throw( CORBA::SystemException )
{
  objs_map_[ name ] = CORBA::Object::_duplicate( obj );
}

CORBA::Object_ptr HomeFinder_impl::resolve_object( const char* name )
  throw( CORBA::SystemException, HomeFinder_ext::ObjectNotFound )
{
  if( objs_map_.exists( name ) )
    {
      return CORBA::Object::_duplicate( objs_map_[ name ] );
    }
  else
    {
      throw HomeFinder_ext::ObjectNotFound();
    }
}

// --

int main( int argc, char** argv )
{
  char* location_microccm_dir = getenv( "microCCM_DIR" );

  if( ! location_microccm_dir )
    {
      printf( "env var microCCM_DIR is not defined\n" );
      exit( 1 );
    }

  CORBA::ORB_var the_orb = CORBA::ORB_init( argc, argv );

  CORBA::Object_var root_poa_obj 
    = the_orb->resolve_initial_references( "RootPOA" );

  PortableServer::POA_var the_root_poa
    = PortableServer::POA::_narrow( root_poa_obj.in() );

  PortableServer::POAManager_var the_poa_manager
    = the_root_poa->the_POAManager();

  the_poa_manager->activate();

  HomeFinder_impl the_home_finder_impl;

  PortableServer::ObjectId_var objid 
    = the_root_poa->activate_object( &the_home_finder_impl );

  CORBA::Object_var obj_ref 
    = the_root_poa->id_to_reference( objid.in() );

  char* ior_for_homefinder = strcat( location_microccm_dir, "/etc/ior_home_finder.txt" );

  fstream outfile( ior_for_homefinder, ios::out );

  CORBA::String_var the_ior = the_orb->object_to_string( obj_ref.in() );
  outfile << the_ior << endl;

  outfile.close();

  the_orb->run();

  return 0;
}

