#include <Contained_wrapper.h>
#include <compute_idl_item_dependencies.h>

#include <dump_intf_from_ir.h>

#include <iostream>
#include <typecode_utils.h>

using namespace std;

InterfaceDef_wrapper::InterfaceDef_wrapper( CORBA::Contained_ptr the_contained,
					    CORBA::ComponentIR::Repository_ptr rep )
{
  the_intf_def_ = CORBA::InterfaceDef::_narrow( the_contained );
  the_repo_ref_ = rep;
}

list< CORBA::Contained_ptr > InterfaceDef_wrapper::get_dependencies()
{
  return Compute_idl_item_dependencies::compute_interface_dependencies( the_intf_def_, the_repo_ref_ );
}

void InterfaceDef_wrapper::dump_as_idl_language( ostream& os )
{
  Dump_idl_item_as_idl_language::dump_idl_interface_as_idl_language( os, the_intf_def_ );
}

// ---------------------------------------------------------------------------------


StructDef_wrapper::StructDef_wrapper( CORBA::Contained_ptr the_contained,
				      CORBA::ComponentIR::Repository_ptr rep )
{
  the_struct_def_ = CORBA::StructDef::_narrow( the_contained );
  the_repo_ref_ = rep;
}

list< CORBA::Contained_ptr > StructDef_wrapper::get_dependencies()
{
  return Compute_idl_item_dependencies::compute_struct_dependencies( the_struct_def_, the_repo_ref_ );
}

void StructDef_wrapper::dump_as_idl_language( ostream& os )
{
  Dump_idl_item_as_idl_language::dump_idl_struct_as_idl_language( os, the_struct_def_ );
}

// ---------------------------------------------------------------------------------

ExceptionDef_wrapper::ExceptionDef_wrapper( CORBA::Contained_ptr the_contained,
					    CORBA::ComponentIR::Repository_ptr rep )
{
  the_except_def_ = CORBA::ExceptionDef::_narrow( the_contained );
  the_repo_ref_ = rep;
}

list< CORBA::Contained_ptr > ExceptionDef_wrapper::get_dependencies()
{
  return Compute_idl_item_dependencies::compute_exception_dependencies( the_except_def_, the_repo_ref_ );
}

void ExceptionDef_wrapper::dump_as_idl_language( ostream& os )
{
  Dump_idl_item_as_idl_language::dump_idl_exception_as_idl_language( os, the_except_def_ );
}


// ---------------------------------------------------------------------------------

EnumDef_wrapper::EnumDef_wrapper( CORBA::Contained_ptr the_enum_def,
				  CORBA::ComponentIR::Repository_ptr rep_ptr )
  : the_repo_ref_( rep_ptr )
{
  the_enum_def_ = CORBA::EnumDef::_narrow( the_enum_def );
}

list< CORBA::Contained_ptr > EnumDef_wrapper::get_dependencies()
{
  list< CORBA::Contained_ptr > to_be_returned;
  return to_be_returned;
}

void EnumDef_wrapper::dump_as_idl_language( ostream& os )
{
  os << "#ifndef " << the_enum_def_->name() << "_enum" << endl
     << "#define " << the_enum_def_->name() << "_enum" << endl;

  os << "enum " << the_enum_def_->name() << " { ";

  CORBA::EnumMemberSeq* the_seq = the_enum_def_->members();

  {
    for( int ct = 0; ct < the_seq->length() - 1; ct++ )
      {
	os << ( *the_seq )[ ct ] << " , ";
      }
    os << ( *the_seq )[ the_seq->length() - 1 ];
  }

  os << " };" << endl;

  os << "#endif // " << the_enum_def_->name() << "_enum" << endl;

  os << endl;

  return;
}

// ---------------------------------------------------------------------------------

Alias_wrapper::Alias_wrapper( CORBA::Contained_ptr the_contained,
			      CORBA::ComponentIR::Repository_ptr rep )
{
  an_alias_def_ = CORBA::AliasDef::_narrow( the_contained );
}

list< CORBA::Contained_ptr > Alias_wrapper::get_dependencies()
{
  list< CORBA::Contained_ptr > to_return;
  // xxx completer ici ..
  return to_return;
}

void Alias_wrapper::dump_as_idl_language( ostream& os )
{

  os << "#ifndef " << an_alias_def_->name() << "_defined" << endl
     << "#define " << an_alias_def_->name() << "_defined" << endl;

  if( an_alias_def_->original_type_def()->type()->kind() == CORBA::tk_sequence )
    {
      CORBA::SequenceDef_var the_seq_def
	= CORBA::SequenceDef::_narrow( an_alias_def_->original_type_def() );

      CORBA::IDLType_var type_in_seq 
	= the_seq_def->element_type_def();

      os << "typedef sequence < " << do_tc_kind_to_string( type_in_seq->type() ) << "> "
	 << an_alias_def_->name() << ";" << endl;
    }
  else
    {
      CORBA::Contained_var try_cast_contained
	= CORBA::Contained::_narrow( an_alias_def_->original_type_def() );

      if( CORBA::is_nil( try_cast_contained ) )
	{
	  cerr << "Revoir l'implementation de " << __PRETTY_FUNCTION__ << endl;
	  cerr << " Pour que ce cela traite tous les cas qu'il faut " << endl;
	  exit( 1 );
	}

      os << "typedef " << try_cast_contained->name() << " " << an_alias_def_->name() << ";" << endl;
    }

  os << "#endif // " << endl
     << endl;

}


// ---------------------------------------------------------------------------------

Contained_wrapper* 
Contained_wrapper_factory::create_contained_wrapper( CORBA::Contained_ptr c,
						     CORBA::ComponentIR::Repository_ptr rep)
{
  cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;

  if( CORBA::is_nil( c ))
    {
      cerr << "Error while creating contained wrapper: Contained object is NULL" << endl;
    }
  else
    {
      cerr << "Creating contained wrapper for: " << c->name() << endl;
    }

  CORBA::Object_ptr the_obj;

  try
    {
      
      the_obj = CORBA::InterfaceDef::_narrow( c );
      if( ! CORBA::is_nil( the_obj ) ) return new InterfaceDef_wrapper( c, rep );
    }
  catch( ... )
    {
      cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;
      exit( 1 );
    }

  the_obj = CORBA::StructDef::_narrow( c );
  if( ! CORBA::is_nil( the_obj ) ) return new StructDef_wrapper( c, rep );

  the_obj = CORBA::ExceptionDef::_narrow( c );
  if( ! CORBA::is_nil( the_obj ) ) return new ExceptionDef_wrapper( c, rep );

  the_obj = CORBA::EnumDef::_narrow( c );
  if( ! CORBA::is_nil( the_obj ) ) return new EnumDef_wrapper( c, rep );

  the_obj = CORBA::AliasDef::_narrow( c );
  if( ! CORBA::is_nil( the_obj ) ) return new Alias_wrapper( c, rep );

  cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;

  exit( 1 );
};

