#include <IDL3_to_CORBA_serv_proxy.h>

#include <Invariable_string_in_place_of.h>
#include <Redispatch_in_place_of.h>

#include <CORBA_generation_indicators.h>
#include <algorithm>

#include <Do_in_place_of_interception.h>
#include <debug_utils.h>
#include <sstream>

using namespace std;

void 
do_server_proxy_implementation( Cpp_class_gene& cgg , 
				CORBA::InterfaceDef_ptr current_intf )
{
  Cpp_class_gene* class_gene_new = &cgg;

  string current_intf_name( current_intf->name() );
  
  class_gene_new->add_inherited_class( string( "POA_" ) + current_intf_name, "public" );
  
  if( CORBA_generation_indicators::needs_interception( current_intf_name ) )
    {
      class_gene_new->add_inherited_class( "MCCM_has_set_interceptor", "public" );

      // and now implementation of "set_in_place_of_interceptor" method

      Cpp_method set_in_poi; 

      string protot = "void set_in_place_of_interceptor( const char* method, MCCM_Interceptor* intercept )";
      set_in_poi.set_prototype( protot );

      vector< string > methods_to_intercept 
	= CORBA_generation_indicators::methods_to_intercept( current_intf_name );

      string implem_for_set_intercept_method = "";
      for( int ct = 0; ct < methods_to_intercept.size(); ct++ )
	{
	  string name_of_interceptor = "my_interceptor_" + string(methods_to_intercept[ ct ]) + "_";
	  implem_for_set_intercept_method += string( "" ) +
	    get_mccm_debug_trace_warning("INTERCEPTORS") +
	    "if( strcmp( method, \"" + methods_to_intercept[ ct ] + "\" ) == 0 )\n"
	    "  {\n"
	    "     my_interceptor_" + methods_to_intercept[ ct ] + "_ = intercept;\n"
	    "     MCCM_Callback* mccmc = new MCCM_Callback_" + current_intf_name + "__" + methods_to_intercept[ ct ] + ";\n"
	    + get_mccm_assert("mccmc")
	    + get_mccm_assert(name_of_interceptor.c_str()) +
	    "     mccmc->set_target_objref( actual_impl_ );\n"
	    "     my_interceptor_" + methods_to_intercept[ ct ] + "_->set_callback( mccmc );\n"
	    "  }\n"
	    "\n";

	  // addition of Interceptor member in class
	  class_gene_new->add_member( "MCCM_Interceptor*", 
				      string( "my_interceptor_" ) 
				      + methods_to_intercept[ ct ] + "_" );

	}

      class_gene_new->add_method( set_in_poi );
      class_gene_new->add_implem( set_in_poi, 
				  new Invariable_string_in_place_of( implem_for_set_intercept_method ) );

    }

  // --- addition of a member to handle internal interfaces references

  class_gene_new->add_member( "map< long, microCCM::Object* >*", "the_internal_interfaces_" );

  // ------ add a constructor method

  {
    string name_of_constr_method = class_gene_new->get_name_of_class();

    Cpp_method constr_method; 

    {
      constr_method.set_name_of_method( name_of_constr_method );
      constr_method.add_parameter( string( "CCM_" ) + current_intf_name + "_ptr",
				   "delegated_to" );
    }

    string impl_constr_method = get_mccm_debug_trace_warning("INTERFACES_IMPLEM") 
      + "  actual_impl_ = delegated_to;\n";

    class_gene_new->add_method( constr_method );
    class_gene_new->add_implem( name_of_constr_method,
				new Invariable_string_in_place_of( impl_constr_method ) );
  }

  // --- add a member to redispatch on (don't forget we are currently implementing a proxy) --

  {
    string type_of_member = string( "CCM_" ) + current_intf_name + "_ptr";
    class_gene_new->add_member( type_of_member, "actual_impl_" );
  }

  // --- redispatch to the executor ... attribute methods are taken into account ...
  // --- or call interceptors that are placed here ...

  {
    vector< string > methods_intercepted
      = CORBA_generation_indicators::methods_to_intercept( current_intf_name );

    for( int ct = 0; ct < class_gene_new->get_nb_methods(); ct++ )
      {
	string name_current_method = class_gene_new->get_method( ct ).get_name_of_method();

	if( find( methods_intercepted.begin(), 
		  methods_intercepted.end(), 
		  name_current_method ) == methods_intercepted.end() )
	  {
	    Redispatch_in_place_of* invocation 
	      = new Redispatch_in_place_of( "actual_impl_",
					    class_gene_new->get_method( ct ) );

	    // retrieve reference to method in the Cpp_class_gene
	    class_gene_new->add_implem( class_gene_new->get_method( ct ), invocation );
	  }
	else
	  {
	    Do_in_place_of_interception* invocation 
	      = new Do_in_place_of_interception( class_gene_new->get_method( ct ) );

	    class_gene_new->add_implem( class_gene_new->get_method( ct ), invocation );
	  }
      }

  }

}

// -----------

#include <IDL_to_cpp_mapping.h>

void do_mccm_callback_implementations( list< Cpp_class_gene* >& l,
				       CORBA::InterfaceDef_ptr current_intf )
{
  Cpp_class_gene cpp_transformed = IDL_to_Cpp_mapping( current_intf, "foo" );

  string current_intf_name( current_intf->name() );

  if( !CORBA_generation_indicators::needs_interception( current_intf_name ) ) 
    {
      return;
    }
  else
    {
      vector< string > methods_to_intercept 
	= CORBA_generation_indicators::methods_to_intercept( current_intf_name );

      for( int ct = 0; ct < cpp_transformed.get_nb_methods(); ct++ )
	{
	  if( find( methods_to_intercept.begin(), 
		    methods_to_intercept.end(),
		    cpp_transformed.get_name_of_method_nb( ct ) ) != methods_to_intercept.end() )
	    {
	      // needs to create a callback

	      string current_method_name = cpp_transformed.get_name_of_method_nb( ct );

	      string type_of_callback 
		= string( "MCCM_Callback_" ) + current_intf_name + "__" + current_method_name;

	      Cpp_class_gene* to_add = new Cpp_class_gene( type_of_callback );

	      to_add->add_inherited_class( "MCCM_Callback", "public" );

	      {
		Cpp_method invoke_method; invoke_method.set_prototype( "void invoke( MCCM_Args* args );" ); 
		
		to_add->add_method( invoke_method );
		
		string implem_method = string("")
		  + get_mccm_debug_trace_warning("CALLBACKS")
		  + get_mccm_assert("targeted_ref_")
		  + get_mccm_assert("args")
		  + "targeted_ref_->" + current_method_name + "(";

		Cpp_method& current_method = cpp_transformed.get_method( ct );

		int nb_params_for_method = current_method.get_nb_parameters();

		for( int ct2 = 0; ct2 < nb_params_for_method; ct2++ )
		  {
		    pair< string, string > the_param = current_method.get_parameter_nb( ct2 );
		    ostringstream ostr; ostr << ct2;
		    implem_method += " ( " + the_param.first  +  " ) args->arg_" + ostr.str();
		    //		    implem_method +=  the_param.first + " arg" + ostr.str()  + " = ( " + the_param.first  +  ") args->arg_" + ostr.str() + ";";

		    if( ct2 < nb_params_for_method - 1 )
		      {
			implem_method += ",";
		      }
		    else
		      {
			implem_method += ");\n";
		      }
		  }
		
		to_add->add_implem( invoke_method, new Invariable_string_in_place_of( implem_method ) );
	      }

	      {
		Cpp_method set_target_objref; 
		set_target_objref.set_prototype( "void set_target_objref( microCCM::Object* the_obj );" );

		to_add->add_method( set_target_objref );

		string implem_method = string( "" ) 
		  + get_mccm_debug_trace_warning("CALLBACKS")
		  + get_mccm_assert("the_obj")
		  + "targeted_ref_ = CCM_" + current_intf_name + "::_narrow( the_obj );\n";

		to_add->add_implem( set_target_objref, new Invariable_string_in_place_of( implem_method ) );
	      }

	      {
		to_add->add_member( string( "CCM_" ) + current_intf_name + "_ptr", "targeted_ref_" );
	      }

	      l.push_back( to_add );
	    }
	}
    }
    

}
