#include <Stubs_IR3.h>

#include <IFR3_client_errors.h>

#include <obtain_repo_ref.h>

#include <Cpp_class_gene.h>

#include <iostream>
#include <fstream>
using namespace std;

#include <repid_utils.h>
#include <IDL_to_cpp_mapping.h>

#include <Invariable_string_in_place_of.h>

#include <IFR3_Singleton.h>

void usage( char* name_program )
{
  cerr << "usage : " << endl
       << name_program << " name_of_component" << endl;

  exit( ERROR_USAGE );
}

int main( int argc, char** argv )
{
  if( argc != 3 ) usage( argv[ 0 ] );
  
  string name_of_component( argv[ 1 ] );

  CORBA::ORB_ptr the_orb = CORBA::ORB_init( argc, argv );

  CORBA::ComponentIR::Repository_ptr the_repository
    = obtain_the_repo_ref( the_orb );

  IFR3_Singleton::set_instance( the_repository );

  CORBA::Contained_ptr the_component
    = the_repository->lookup( name_of_component.c_str() );

  // and now generate base classes executor interfaces
  // as well as "CCM_xxx" for interfaces provided ...
  // Callback

  CORBA::ComponentIR::ComponentDef_ptr the_component_def 
    = CORBA::ComponentIR::ComponentDef::_narrow( the_component );

  if( CORBA::is_nil( the_component_def ) )
    {
      cerr << "Problem, this component is unknown ..." << endl;
      exit( ERROR_ITEM_NOT_COMPONENT );
    }

  cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;

  the_component_def->describe();

  cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;

  CORBA::ComponentIR::ComponentDescription* the_description = NULL;

  if( the_component_def->describe()->value >>= the_description )
    {
      cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;
      
      CORBA::String_var name_comp 
	= CORBA::string_dup( the_description->name );

      cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;

      Cpp_class_gene the_class_gene( "CCM_" + string( name_comp.in() ) );

      the_class_gene.add_required_include( "<EnterpriseComponent.h>" );

      the_class_gene.add_inherited_class( "Components::EnterpriseComponent" , "public" );

      CORBA::ComponentIR::ProvidesDescriptionSeq& provided_interfaces
	= the_description->provided_interfaces;

      cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;

      //
      // ********************** local interfaces CCM_bidule *****************************
      //
      list< Cpp_class_gene* > ccm_xxx_to_generate;

      for( int ct_provided_interfaces = 0;
	   ct_provided_interfaces < provided_interfaces.length();
	   ct_provided_interfaces++ )
	{
	  CORBA::ComponentIR::ProvidesDescription& current_provide
	    = provided_interfaces[ ct_provided_interfaces ];

	  cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;

	  const char* intf_rep_id = current_provide.interface_type;

	  CORBA::Contained_ptr the_intf_def_as_contained = the_repository->lookup_id( intf_rep_id );
	  CORBA::InterfaceDef_ptr the_intfdef_ref = CORBA::InterfaceDef::_narrow( the_intf_def_as_contained );

	  // le mieux serait peut-etre de creer un interface locale dans l'interface repository
	  // mais ca pose probleme car bug de l'IR3 vis-a-vis de la FullInterfaceDescription
	  // renvoyee qui n'est pas ok ;-/
	  // ce qui suit peut etre considere comme un workaround.

	  cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;

	  string name_generated_class = string( "CCM_" ) + string( the_intfdef_ref->name() );

	  Cpp_class_gene* the_cpp_conversion 
	    = new Cpp_class_gene( IDL_to_Cpp_mapping( the_intfdef_ref, name_generated_class, true ) );

	  add_duplicate_and_narrow_methods( *the_cpp_conversion ); // xxx a mettre dans "IDL_to_Cpp_mapping en fait"
	  the_cpp_conversion->add_inherited_class( "microCCM::Object", "public" );
	  
	  ccm_xxx_to_generate.push_back( the_cpp_conversion );
	}

      cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;
      
      //
      // ************* CCM_xxx generation *******************************
      //
      // -- provided interfaces --

      for( int ct_provided_interfaces = 0;
	   ct_provided_interfaces < provided_interfaces.length();
	   ct_provided_interfaces++ )
	{
	  const char* name_of_port_c = provided_interfaces[ ct_provided_interfaces ].name;
	  string name_of_port( name_of_port_c );

	  Cpp_method the_method;
	  the_method.set_name_of_method( "get_" + name_of_port );

	  const char* interface_type_name_c 
	    = provided_interfaces[ ct_provided_interfaces ].interface_type;

	  string interface_type_name = scoped_name( interface_type_name_c );

	  string return_type 
	    = string( "CCM_" ) + interface_type_name + "_ptr"; // xxx attention aux modules ...

	  the_method.set_return_type( return_type );
	  the_method.set_virtual_decl( is_pure_virtual );

	  the_class_gene.add_method( the_method );
	}
       
      
      // -- Insertion of push methods for sinks  --
      CORBA::ComponentIR::EventPortDescriptionSeq& consumes_events
	= the_description->consumes_events;
      
      for(int ct_evt_sink=0; ct_evt_sink < consumes_events.length(); ct_evt_sink++ )
	{
	  Cpp_method push_xxx;
	  CORBA::String_var consumes_name = CORBA::string_dup( consumes_events[ct_evt_sink].name );
	  CORBA::ComponentIR::EventDef_var evt_def = CORBA::ComponentIR::EventDef::_narrow(the_repository->lookup_id(consumes_events[ct_evt_sink].event));
	  string name_of_event(evt_def->name());
	  push_xxx.set_name_of_method(string("push_") + consumes_name.in());
	  push_xxx.set_return_type( "void" );
	  push_xxx.set_virtual_decl( is_pure_virtual );
	  push_xxx.add_parameter(name_of_event + "*", "evt");
	  the_class_gene.add_method( push_xxx );
	}
      
      cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;

      // -- Insertion of "attribute" methods  --
      {
 	CORBA::ExtAttrDescriptionSeq& attributes_seq
 	  = the_description->attributes;

 	for(int ct_attributes = 0; ct_attributes < attributes_seq.length(); ct_attributes++)
 	  {
 	    CORBA::ExtAttributeDescription& attr_desc = attributes_seq[ ct_attributes ];
 	    string attr_name = string(attr_desc.name);

 	    {
 	      Cpp_method get_attribute_method;
 	      string attr_type_ret = IDL_to_cpp_arg_mapping(attr_desc.type.in(), arg_passing_return);

	      get_attribute_method.set_name_of_method( attr_name );
	      get_attribute_method.set_return_type( attr_type_ret );
	      get_attribute_method.set_virtual_decl( is_pure_virtual );

	      // get_attribute_method.set_prototype( attr_type_ret + " " + attr_name + string(")") );
 	      the_class_gene.add_method( get_attribute_method );
 	    }

	    if( attr_desc.mode == CORBA::ATTR_NORMAL )
 	    {
 	      Cpp_method set_attribute_method;
 	      string attr_type_in = IDL_to_cpp_arg_mapping(attr_desc.type.in(), arg_passing_in);

	      set_attribute_method.set_name_of_method( attr_name );
	      set_attribute_method.set_return_type( "void" );
	      set_attribute_method.add_parameter( attr_type_in, "attribute" );
	      set_attribute_method.set_virtual_decl( is_pure_virtual );

	      // set_attribute_method.set_prototype(string("void ") + attr_name + string("(") + attr_type_in + "attribute" + string(")") );

 	      the_class_gene.add_method( set_attribute_method );
 	    }

 	  }

      }
      
      // -- Insertion of "configuration_complete" method  --
      {
        Cpp_method configuration_complete_method;
        configuration_complete_method.set_name_of_method( "configuration_complete" );
        configuration_complete_method.set_return_type( "void" );
        configuration_complete_method.add_exception_thrown( "Components::InvalidConfiguration" );
        configuration_complete_method.set_virtual_decl( is_pure_virtual );

        the_class_gene.add_method( configuration_complete_method );
      }
      
      
      //
      // ************* CCM_xxx_Context generation *******************************
      //
      Cpp_class_gene context_generation( "CCM_" + string( name_comp.in() ) + "_Context" );
      context_generation.add_inherited_class( "microCCM::Object", "public" );

      {
	// Getter method for receptacles
	CORBA::ComponentIR::UsesDescriptionSeq used_interfaces
	  = the_description->used_interfaces;

	for( int ct_used_interfaces = 0;
	     ct_used_interfaces < used_interfaces.length();
	     ct_used_interfaces++ )
	  {
	    Cpp_method get_connection_method;

	    CORBA::String_var port_name = CORBA::string_dup( used_interfaces[ ct_used_interfaces ].name );

	    get_connection_method.set_name_of_method( string( "get_connection_" ) + port_name.in() );
	    get_connection_method.set_virtual_decl( is_pure_virtual );
	    get_connection_method.set_return_type( scoped_name( used_interfaces[ ct_used_interfaces ].interface_type ) + "_ptr" );
	    context_generation.add_method( get_connection_method );
	  }

	
	// Duplicate and Narrow methods 
	add_duplicate_and_narrow_methods( context_generation );

	// Push methods for all types of events
	CORBA::ComponentIR::EventPortDescriptionSeq& publishes_events
	  = the_description->publishes_events;
       
	for(int ct_evt_sources=0; ct_evt_sources < publishes_events.length(); ct_evt_sources++ )
	  {
	    Cpp_method push_method;
	    string a = string(publishes_events[ct_evt_sources].name);
	    CORBA::String_var publishes_name = CORBA::string_dup( publishes_events[ct_evt_sources].name );
	    push_method.set_name_of_method( string( "push_" ) + publishes_name.in() );
	    push_method.set_virtual_decl( is_pure_virtual );

	    CORBA::ComponentIR::EventDef_var evt_def 
	      = CORBA::ComponentIR::EventDef::_narrow(the_repository->lookup_id(publishes_events[ct_evt_sources].event));

	    push_method.add_parameter(  string(evt_def->name()) + "*", "evt");
	    push_method.set_return_type( "void" );
	    context_generation.add_method( push_method );
	  }
      }
      

      //
      // *******************     SessionComponent generation   *******************
      //
      string base_name_sessioncmp_class = string( "CCM_" ) + name_of_component + "_SessionComponent";
      Cpp_class_gene sessioncmp_class( base_name_sessioncmp_class + "_impl" );
      {
       sessioncmp_class.add_inherited_class( "Components::SessionComponent", "public" );

       sessioncmp_class.add_member( "CCM_" + name_of_component + "_Context_ptr", "component_context_" );

       // implementation set_session_context
       Cpp_method set_session_method; 
       set_session_method.set_name_of_method("set_session_context" );
       set_session_method.set_return_type( "void" );
       set_session_method.add_parameter( "Components::SessionContext_ptr", "ctx");
       set_session_method.add_exception_thrown( "Components::CCMException" );
       sessioncmp_class.add_method( set_session_method );
       string set_session_implem = "component_context_ = dynamic_cast< CCM_" + name_of_component + "_Context_ptr >( ctx );" + "\n";
       sessioncmp_class.add_implem( "set_session_context",
				   new Invariable_string_in_place_of( set_session_implem ) );
       
       // implementation get_session
       Cpp_method get_session_method; 
       get_session_method.set_name_of_method("get_context" );
       get_session_method.set_return_type( "Components::SessionContext_ptr");
       sessioncmp_class.add_method( get_session_method );
       string get_session_implem = string("return (Components::SessionContext_ptr) component_context_;") + string("\n");
       sessioncmp_class.add_implem( "get_context",
				   new Invariable_string_in_place_of( get_session_implem ) );
      }       
       
      //
      //////////////// Dump classes to files.
      ////////////////
  
      cerr << "Problem 1" << endl;

      string base_name_file_to_generate = "microccm_" + name_of_component + "_executor";
      
      string header_file_to_generate = base_name_file_to_generate + ".h";
      string implem_file_to_generate = base_name_file_to_generate + ".cpp";

      fstream outfile_h( header_file_to_generate.c_str(), ios::out );
      fstream outfile_cpp( implem_file_to_generate.c_str(), ios::out );

      outfile_h << "#ifndef " << base_name_file_to_generate << "_h" << endl
		<< "#define " << base_name_file_to_generate << "_h" << endl;

      outfile_h << "#include <EnterpriseComponent.h>" << endl;

      outfile_h << "#include <microccm_" << name_of_component << "S.h>" << endl;

      outfile_h << context_generation.generate_code().first << endl;

      outfile_cpp << "#include <" << header_file_to_generate << ">" << endl;

      outfile_cpp << context_generation.generate_code().second << endl;

      outfile_h << endl
		<< "typedef " << context_generation.get_name_of_class() << "* " 
		<< context_generation.get_name_of_class() + "_ptr;"
		<< endl;

      outfile_h << endl;

      for( list< Cpp_class_gene* >::iterator iter = ccm_xxx_to_generate.begin(); 
	   iter != ccm_xxx_to_generate.end(); iter++ )
	{
	  cerr << "IDL3_to_cpp_executors.cpp : generating for " << ( *iter )->get_name_of_class() << endl;

	  outfile_h << ( *iter )->generate_code().first << endl;
	  outfile_h << endl;
	  outfile_h << "typedef " << ( *iter )->get_name_of_class() 
		    << "* " << ( *iter )->get_name_of_class() + "_ptr;" << endl
		    << endl;

	  outfile_cpp << ( *iter )->generate_code().second << endl;
	}

      cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;

      outfile_h << the_class_gene.generate_code().first << endl;
      outfile_h << "typedef " << the_class_gene.get_name_of_class() << "*" 
		<< the_class_gene.get_name_of_class() << "_ptr;" << endl;
      outfile_cpp << the_class_gene.generate_code().second << endl;
      cerr << "the_class_gene OK" << endl;
      
      outfile_h << sessioncmp_class.generate_code().first <<endl;
      outfile_h << "typedef " << sessioncmp_class.get_name_of_class() << "*" 
		<< sessioncmp_class.get_name_of_class() << "_ptr;" << endl;
      outfile_cpp << sessioncmp_class.generate_code().second <<endl;
            cerr << "sessioncmp_class OK" << endl;
      
      
      /********************************************************
       *
       *            Home generation
       *
       *********************************************************/

      string name_of_home_searched( argv[ 2 ] );

      CORBA::Contained_ptr ref_home_as_contained
	= the_repository->lookup( name_of_home_searched.c_str() );

      if( CORBA::is_nil( ref_home_as_contained ) )
	{
	  cerr << "Error : " << name_of_home_searched 
	       << " is not present in Interface Repository" << endl;
	  exit( ERROR_NO_IDL_ITEM_OK );
	}
  
      CORBA::ComponentIR::HomeDef_ptr ref_home
	= CORBA::ComponentIR::HomeDef::_narrow( ref_home_as_contained );
  
      CORBA::Contained::Description* contained_desc;
  
      contained_desc = ref_home->describe();

      CORBA::ComponentIR::HomeDescription* the_home_desc = 0;

      contained_desc->value >>= the_home_desc;
      const char* name_of_home = the_home_desc->name; string name_of_home_string( name_of_home );
      string filename_base = string( "" ) + "microccm_" + name_of_home_string + "_executor";


      // Class home_Explicit
      Cpp_class_gene homeExpl_exec_class( "CCM_" + name_of_home_string + "Explicit" );
      homeExpl_exec_class.add_inherited_class( "Components::HomeExecutorBase", "public" );

      // Class home_Implicit
      Cpp_class_gene homeImpl_exec_class( "CCM_" + name_of_home_string + "Implicit" );
      // Methods of the class      
      
      // ------------ insertion of create() pure virtual method --------------
      {
	Cpp_method homeimpl_create_method; 
	
	{
	  homeimpl_create_method.set_name_of_method( "create" );
	  homeimpl_create_method.set_return_type( "Components::EnterpriseComponent_ptr" );
	  homeimpl_create_method.add_exception_thrown( "Components::CCMException" );
	  homeimpl_create_method.set_virtual_decl( is_pure_virtual );
	}
	homeImpl_exec_class.add_method(homeimpl_create_method);
      }


      // Class CCM_xxx_home
      Cpp_class_gene home_exec_class( "CCM_" + name_of_home_string );
      home_exec_class.add_inherited_class( "CCM_" + name_of_home_string + "Explicit",
					   "public" );
      home_exec_class.add_inherited_class( string( "CCM_" ) + name_of_home_string + "Implicit",
					   "public" );

      // should go to IDL3_to_CORBA.cpp
      //       home_exec_class.add_inherited_class( string( "Components::HomeConfiguration"),
      // 					   "public" );

      // ---------------- _narrow method -------------------------

      {
	Cpp_method narrow_method;
	narrow_method.set_name_of_method( "_narrow" );
	narrow_method.set_return_type( string( "CCM_" ) + name_of_home_string + "_ptr" );
	narrow_method.add_parameter( "microCCM::Object_ptr", "obj" );
	narrow_method.is_static();

	home_exec_class.add_method( narrow_method );

	string narrow_method_impl = string( "" ) +
	  " return dynamic_cast< CCM_" + name_of_home_string + "*>( obj );\n";

	home_exec_class.add_implem( narrow_method, 
				    new Invariable_string_in_place_of( narrow_method_impl ) );
      }

      outfile_h << homeExpl_exec_class.generate_code().first << endl;
      outfile_h << homeImpl_exec_class.generate_code().first << endl;

      outfile_h << "class CCM_" << name_of_home << ";" << endl;
      outfile_h << "typedef CCM_" << name_of_home << "* CCM_" << name_of_home << "_ptr;" << endl;

      outfile_h << home_exec_class.generate_code().first << endl;
      outfile_cpp << home_exec_class.generate_code().second << endl;
      cerr << "home generation OK" << endl;

      
      outfile_h << "#endif // " << base_name_file_to_generate << "_h" << endl;
      outfile_h.close();
      outfile_cpp.close();
    }

  return 0;
}
