#include <create_equivalent_idl2_interface.h>

#include <iostream>
#include <string>
using namespace std;

#include <typecode_utils.h>
#include <repid_utils.h>

CORBA::InterfaceDef_ptr 
create_equivalent_idl2_interface( CORBA::ComponentIR::Repository_ptr the_repo_ref,
				  CORBA::ComponentIR::ComponentDescription* the_comp_desc )
{
  CORBA::InterfaceDefSeq base_interfaces;
  base_interfaces.length( 1 );

  CORBA::Contained_ptr ccm_object_intf
    = the_repo_ref->lookup_id( "IDL:omg.org/Components/CCMObject:1.0" );

  if( CORBA::is_nil( ccm_object_intf ) )
    {
      cerr << __PRETTY_FUNCTION__ << ": " << __LINE__ << "probleme" << endl;
      exit( 1 );
    }

  base_interfaces[ 0 ] 
    = CORBA::InterfaceDef::_narrow( ccm_object_intf );

  // ---- 

  string name_of_equivalent_intf 
    = string( "_microccm_" ) + string( the_comp_desc->name );

  string repid_of_equivalent_interface 
    = string( "IDL:" ) + name_of_equivalent_intf + string( ":1.0" );

  CORBA::InterfaceDef_ptr the_created_interface
    = the_repo_ref->create_interface( repid_of_equivalent_interface.c_str(),
				      name_of_equivalent_intf.c_str(),
				      "1.0",
				      base_interfaces
				      );

  the_created_interface->base_interfaces( base_interfaces );

  CORBA::ExtAttrDescriptionSeq& the_attrib_seq = the_comp_desc->attributes;
  int nb_attribs = the_attrib_seq.length();

  for( int ct_attrib = 0; ct_attrib < nb_attribs; ct_attrib++ )
    {
      cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << endl;

      CORBA::ExtAttributeDescription& the_description = the_attrib_seq[ ct_attrib ];

      CORBA::TypeCode_ptr the_typecode = the_description.type.in();

      CORBA::IDLType_ptr as_idltype = typecode_to_idltype( the_typecode, the_repo_ref );

      Repid current_repid( string( the_description.id.in() ) );

      current_repid.add_prefix_to_beginning( "_microccm_" );
      string new_id = current_repid.get();

      the_created_interface->create_attribute( new_id.c_str(),
					       the_description.name,
					       the_description.version,
					       as_idltype,
					       the_description.mode );
    }

  return the_created_interface;
}
