#ifndef dump_intf_from_ir_h
#define dump_intf_from_ir_h

#include <Stubs_IR3.h>

#include <iostream>
#include <string>
using namespace std;

/** 
 * This class allows to dump IDL items to a given output stream.
 * This class allows to dump the following idl item: interface, struct, exception. It looks 
 * for data in the Interface Repository and dump idl item to an output stream.
 */
class Dump_idl_item_as_idl_language
{
 public:
  
  /** This method permits to dump an interface item to an output stream. */ 
  static void dump_idl_interface_as_idl_language( ostream& os,
						  CORBA::InterfaceDef_ptr the_intf_def );

  /** This method permits to dump a component's home to an output stream. */ 
  static void dump_idl_home_as_idl_language( ostream& os,
					     CORBA::ComponentIR::HomeDef_ptr the_home_def );

  /** This method permits to dump a struct item to an output stream. */ 
  static void dump_idl_struct_as_idl_language( ostream& os,
					       CORBA::StructDef_ptr the_struct_def );
  
  /** This method permits to dump an exception item to an output stream. */ 
  static void dump_idl_exception_as_idl_language( ostream& os,
						  CORBA::ExceptionDef_ptr the_exception_def );
  
  /** This method permits to dump an item with its dependencies to an output stream. */ 
  static void dump_with_dependencies( ostream& os,
				      CORBA::Contained_ptr the_contained,
				      CORBA::ComponentIR::Repository_ptr );
  
  /** This method permits to dump all event sinks item to an output stream. */ 
  static void dump_idl_sinks_as_idl_language( ostream& os,  CORBA::ComponentIR::ComponentDescription* the_comp_desc,  CORBA::ComponentIR::Repository_ptr the_repo_ref);

  /** This method permits to dump all event sources item to an output stream. */ 
  static void dump_idl_sources_as_idl_language( ostream& os, CORBA::ComponentIR::ComponentDescription* the_comp_desc,  CORBA::ComponentIR::Repository_ptr the_repo_ref);

  /** This method permits to dump an event type item to an output stream. */
  static void dump_idl_eventtype_as_idl_language(ostream& os, CORBA::ComponentIR::EventDef_ptr the_event_def, CORBA::ComponentIR::Repository_ptr the_repo_ref );

  /** This method permits to dump a value type to an output stream. */
  static void dump_idl_valuetype_as_idl_language(ostream& os, CORBA::ExtValueDef_ptr the_value_def,  CORBA::ComponentIR::Repository_ptr the_repo_ref);

  /** This method permits to dump an attribute to an output stream. */
  static void dump_idl_attribute_as_idl_language(ostream& os, CORBA::ExtAttributeDescription& attribute_desc );

  /** This method permits to dump an operation to an output stream. */
  static void dump_idl_operation_as_idl_language(ostream& os, CORBA::OperationDescription& operation_desc );

  /** This method permits to dump a list of exceptions to an output stream. */
  static void dump_idl_exceptions_as_idl_language(ostream& os, CORBA::ExcDescriptionSeq& exceptions_desc );
  
};

#endif // dump_intf_from_ir_h
