#ifndef threading_utils_h
#define threading_utils_h

#include <pthread.h>

namespace threading
{
  template< typename T > 
  class protected_resource
  {
  public:

    protected_resource( )
    {
      pthread_mutex_init( &the_mutex_, NULL );
    }
    
    ~protected_resource()
    {
      pthread_mutex_destroy( &the_mutex_ );
    }

    void set( const T& t )
    {
      pthread_mutex_lock( &the_mutex_ );
      instance_ = t ;
      pthread_mutex_unlock( &the_mutex_ );
    }

    T get() /* const */ 
    {
      pthread_mutex_lock( &the_mutex_ );
      T to_return = instance_;
      pthread_mutex_unlock( &the_mutex_ );
      return to_return;
    }

    void operator=( const T& t )
      {
	instance_ = t;
      }

    operator T()
      {
	return instance_;
      }

  private:

    pthread_mutex_t the_mutex_;
    T instance_;
  };

}

#endif // threading_utils_h
