/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Christophe Demarey.
Contributor(s): _______________________________.

====================================================================*/

package org.objectweb.ccm.runtime.cif.api;

import org.omg.Components.ExecutorSegmentBase;

/**
 * Base interface for all component segment classes generated from CIDL.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *         <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</A>
 *
 * @version 0.1
 */

public interface ComponentSegment
         extends ExecutorSegmentBase,
                 org.omg.Components.ExecutorLocator
{
    /**
     * Sets the number of executor segments.
     *
     * This method is called by the constructor of
     * component segment classes generated from CIDL.
     *
     * @param nb_segments The number of executor segments
     *                    for this CIDL component executor.
     */
    public void
    set_nb_segments(int nb_segments);

    /**
     * Sets the associated segment home.
     *
     * @param sh The associated segment home.
     */
    public void
    set_segment_home(SegmentHome sh);

    /**
     * Gets an executor segment.
     *
     * If the requested executor segment does not exist
     * then it is created by the segment home.
     *
     * @param segid The executor segment id.
     *
     * @return The executor segment.
     */
    public ExecutorSegmentBase
    get_executor_segment(int segid);

    /**
     * Obtains the segmentation table.
     *
     * This method is implemented by component segment classes generated
     * from CIDL according to segmentation described in CIDL compositions.
     *
     * @return A HashMap containing <facet_name, segid> associations.
     */
    public java.util.HashMap
    get_segmentation_table();
};
