/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle
                      Mathieu Vadet
                      Tran Huynh (tran.huynh@fr.thalesgroup.com)
Contributor(s): .

====================================================================*/

package org.objectweb.ccm.scripts;

/**
 * This class is called by the ir3_xmi shell script.
 */
public class IR3toXMI
    extends org.objectweb.openccm.corba.Application {    

    /**
     * Default constructor.
     */
    public IR3toXMI() {
    }

    /**
     * The main bootstrap method.
     *
     * @param args The command line arguments.
     */
    public static void 
    main(java.lang.String[] args) {
        IR3toXMI ir3 = new IR3toXMI();
        ir3.start(args);
    }

    /**
     * Overridden org.objectweb.openccm.corba.Application methods.
     */

    /**
     * This method runs the application.
     *
     * @param args The command line arguments.
     *
     * @return The exit code.
     */
    public int 
    run(java.lang.String[] args) {
        // Obtain the Interface Repository.
        org.objectweb.openccm.ir3.api.ComponentRepository repositoryRef =
            org.objectweb.openccm.ir3.api.ComponentRepositoryHelper.narrow(
                org.objectweb.openccm.corba.TheInterfaceRepository.getRepository());

        // Create an OpenCCM XMI Compiler
        XMICompiler compiler = new XMICompiler(
            new IR3XMIOptionsManager(org.objectweb.ccm.scripts.Version.label, 
                                     "ir3_xmi"),
                                     org.objectweb.ccm.scripts.Version.label);

        // Run the compiler.
        boolean ok = compiler.run(args);
        if (!ok) {
            return -1;
        }

        // Set the default filename and the default XMI DTD
        String filename = "stdout";
        String xmidtd = "xmi.dtd";

        // Create an options manager.
        IR3XMIOptionsManager manager = compiler.getManager();

        // Deals with the options.
        if (manager.isSet("-o")) {
            filename = manager.get("-o")[0];
        }

        if (manager.isSet("-dtd")) {
            xmidtd = manager.get("-dtd")[0];
        }

        // Start an IDL3 Repository
        org.objectweb.ccm.IDL3.Repository rep =
            new org.objectweb.ccm.IDL3.Repository(
                repositoryRef.as_IDL3_repository());

        try {
            org.objectweb.ccm.visitorIDL3.xmi.IDL3_XMI mi = 
                new org.objectweb.ccm.visitorIDL3.xmi.IDL3_XMI(rep);

            // Generate XMI
            mi.generate(manager.getObjectName(), filename, xmidtd);
        } catch(fr.lifl.cim.jidlscript.lang.JISError ex) {
            System.err.println(ex.exception.toString());
            return 1;
        }

        return 0;
    }
}
