/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.corba.generator.cif.lib;

// Package dependencies.
import org.objectweb.openccm.generator.java.ast.api.*;
import org.objectweb.openccm.generator.java.ast.lib.*;

/**
 * This class generates CIF implementation templates files for a value type.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */

public class ValueTypeImplMapping
  implements org.objectweb.corba.generator.cif.api.ValueTypeImplMapping
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** Utility class to convert types in Java*/
    static public org.objectweb.openccm.generator.translator.idl2java.api.IDL_JavaTranslator translator_;

    /** The Value Type to map. */
    private org.objectweb.openccm.ast.api.ValueDecl value_decl_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     *
     * @param value_decl - The value type declaration to map.
     **/
    public ValueTypeImplMapping(org.objectweb.openccm.ast.api.ValueDecl value_decl)
    {
        // Inits internal state
        value_decl_ = value_decl;
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Inits the static field.
     **/
    static
    {
        translator_ = new org.objectweb.openccm.generator.translator.idl2java.lib.IDL_JavaTranslator();
    }

    /**
     * Inits value type members.
     *
     * @param ct - The constructor to complete.
     **/
    private void
    init_value_members(ConstructorObject ct)
    {
        org.objectweb.openccm.ast.api.Declaration[] decls = null;

        decls = value_decl_.getContents(false, org.objectweb.openccm.ast.api.DeclarationKind.dk_value_member);
        ct.getImpl().setMacro("VALUE_TYPE_IMPL_CT");
        ct.getImpl().addContextValue("members", decls);
        ct.getImpl().addContextValue("translator", translator_);
    }

    /**
     * Map value type local operations.
     *
     * @param clazz - Add operation mapping to the Value Type class.
     **/
    private void
    local_operations(ClassObject clazz)
    {
        org.objectweb.openccm.ast.api.Declaration[] decls = null;
        MethodObject method = null;

        decls = value_decl_.getContents(false, org.objectweb.openccm.ast.api.DeclarationKind.dk_operation+
                                               org.objectweb.openccm.ast.api.DeclarationKind.dk_attribute);
        for (int i=0; i<decls.length; i++)
        {
            if (decls[i].getDeclKind() == org.objectweb.openccm.ast.api.DeclarationKind.dk_attribute)
            {
                method = translator_.map_attribute_accessor( (org.objectweb.openccm.ast.api.AttributeDecl)decls[i] );
                method.getImpl().setMacro("BUSINESS_OP");
                method.getImpl().addContextValue("translator", translator_);
                method.getImpl().addContextValue("obj", decls[i]);
                clazz.addMethod(method);

                method = translator_.map_attribute_mutator( (org.objectweb.openccm.ast.api.AttributeDecl)decls[i] );
                if (method != null)
                {
                    method.getImpl().setMacro("TODO");
                    clazz.addMethod(method);
                }
            }
            else
            {
                method = translator_.map_operation( (org.objectweb.openccm.ast.api.OperationDecl)decls[i] );
                method.getImpl().setMacro("BUSINESS_OP");
                method.getImpl().addContextValue("translator", translator_);
                method.getImpl().addContextValue("obj", decls[i]);
                clazz.addMethod(method);
            }
        }
    }

    /**
     * Get the name of the base factory.
     *
     * @return The base factory name.
     **/
    private String
    baseFactory()
    {
        org.objectweb.openccm.ast.api.Initializer[] inits = null;

        inits = value_decl_.getInitializerList().getInitializers();

        if (inits.length == 0)
            return "org.omg.CORBA.portable.ValueFactory";
        else
            return translator_.checkKeywords(value_decl_.getName())+"ValueFactory";
    }

    /**
     * Map value type factory default operations.
     *
     * @param clazz - Add methods to the Value Type class.
     * @param value_name - The value type name managed by the factory.
     **/
    private void
    map_factory_default_op(ClassObject clazz,
                           String value_name )
    {
        MethodObject method = null;
        ParameterObject param = null;

        // Map "read_value" operation
        method = new MethodObjectImpl();
        method.addComment("Method for the org.omg.CORBA.portable.ValueFactory interface.");
        method.addComment(" ");
        method.addComment("To read " + value_name + " on a CORBA stream.");
        method.setName("read_value");
        method.setReturnType("java.io.Serializable");
        method.getImpl().setMacro("VT_FACTORY_READ_VALUE");
        method.getImpl().addContextValue("value_name", value_name);

        param = new ParameterObjectImpl();
        param.setName("in");
        param.setType("org.omg.CORBA_2_3.portable.InputStream");
        method.addParameter(param);
        clazz.addMethod(method);

        // Map "register" method
        method = new MethodObjectImpl();
        method.addComment("Register the valuetype factory to the ORB.");
        method.setName("register");
        method.setStatic(true);
        method.setReturnType("void");
        method.getImpl().setMacro("VT_FACTORY_REGISTER");
        method.getImpl().addContextValue("value_name", value_name);
        clazz.addMethod(method);
    }

    /**
     * Map value type factory initializers.
     *
     * @param clazz - Add methods to the Value Type class.
     **/
    private void
    map_factory_initializers(ClassObject clazz)
    {
        org.objectweb.openccm.ast.api.Initializer[] inits = null;

        inits = value_decl_.getInitializerList().getInitializers();

        for (int i=0; i<inits.length; i++)
        {
            MethodObject method = null;

            // Map "read_value" operation
            method = new MethodObjectImpl();
            method.addComment("Implementation of the " +
                              translator_.checkKeywords(inits[i].getName()) +
                              " initializer");
            method.addComment("in "+value_decl_.getAbsoluteName()+" valuetype.");
            method.setName( translator_.checkKeywords(inits[i].getName()) );
            method.setReturnType(value_decl_.getName());
            method.getImpl().setMacro("VT_FACTORY_INITIALIZER");
            method.getImpl().addContextValue("factory_impl_name", value_decl_.getName()+"Impl");

            translator_.map_parameters( method,
                                        inits[i].getParameterList() );
            translator_.map_exceptions( method,
                                        inits[i].getExceptionList() );
            clazz.addMethod(method);
        }
    }

    // ==================================================================
    //
    //  Public methods for org.objectweb.openccm.generator.cif.api.ValueTypeImplMapping.
    //
    // ==================================================================

    /**
     * Generate Value Type template class.
     *
     * @param repository - The java repository.
     **/
    public void
    toJavaValueTemplate(Repository repository)
    {
        ClassObject clazz = null;
        ConstructorObject ct = null;

        clazz = new ClassObjectImpl(value_decl_.getName()+"Impl");
        clazz.addComment(" Implementation skeleton class for the "
                         + value_decl_.getId()
                         + " declaration.");
        clazz.addComment("");
        clazz.addComment(" @author OpenCCM CIF_Jimpl Compiler.");
        clazz.setModifier(ModifierKindImpl.mk_public);
        clazz.setPackage( translator_.getPackage(value_decl_) );
        clazz.addInheritedObject(value_decl_.getName());

        // Add the default constructor
        ct = new ConstructorObjectImpl();
        clazz.addConstructor(ct);

        init_value_members(ct);
        local_operations(clazz);

        // Add object to the java repository
        repository.addObject(clazz);
    }

    /**
     * Generate Value Type Factory template class.
     *
     * @param repository - The java repository.
     **/
    public void
    toJavaValueFactoryTemplate(Repository repository)
    {
        ClassObject clazz = null;
        ConstructorObject ct = null;
        MethodObject method = null;

        clazz = new ClassObjectImpl(value_decl_.getName()+"FactoryImpl");
        clazz.addComment(" Implementation skeleton class for the "
                         + value_decl_.getId()
                         + " declaration factory.");
        clazz.addComment("");
        clazz.addComment(" @author OpenCCM CIF_Jimpl Compiler.");
        clazz.setModifier(ModifierKindImpl.mk_public);
        clazz.setPackage( translator_.getPackage(value_decl_) );
        clazz.addImplementedObject(baseFactory());

        // Add the default constructor
        ct = new ConstructorObjectImpl();
        clazz.addConstructor(ct);

        map_factory_default_op(clazz, value_decl_.getName());
        map_factory_initializers(clazz);

        // Add object to the java repository
        repository.addObject(clazz);
    }

    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================

}
