/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.corba.generator.cif_idl.lib;

// Package dependencies.
import org.objectweb.openccm.ast.api.Declaration;
import org.objectweb.openccm.ast.api.Scope;
import org.objectweb.openccm.ast.api.CompositionDecl;
import org.objectweb.openccm.ast.api.ModuleDecl;
import org.objectweb.openccm.ast.api.DeclarationKind;
import org.objectweb.corba.generator.cif_idl.api.CompositionMapping;
import org.objectweb.openccm.generator.common.lib.GenerationException;
import java.util.List;
import java.util.ArrayList;
import java.util.Iterator;

/**
 * This class generates CIF interfaces in the Interface Repository.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</A>
 */

public class CIF_IDLGenerator
     extends org.objectweb.openccm.generator.common.lib.GeneratorBase
  implements org.objectweb.corba.generator.cif_idl.api.CIF_IDLGenerator
{

    // ===========================================================
    //
    // Internal methods.
    //
    // ===========================================================

    /** Declarations created for CIF. **/
    private List cif_decls_;

    /** CIF Declarations to remove from IR. **/
    private List decls_to_remove_;

    /** The OpenCCM Interface Repository reference. **/
    private org.objectweb.openccm.ir3.api.ComponentRepository rep_;

    // ===========================================================
    //
    // Constructors.
    //
    // ===========================================================

    /**
     * The default constructor.
     *
     * @param ast - The Abstract Syntax Tree.
     * @param rep - The OpenCCM Interface Repository reference.
     *              Used to remove CIF mapping from IR.
     **/

    public CIF_IDLGenerator( org.objectweb.openccm.ast.api.AST ast,
                             org.objectweb.openccm.ir3.api.ComponentRepository rep)
    {
        // Call the GeneratorBase constructor
        super(ast);

        // Init internal states
        rep_ = rep;
        cif_decls_ = null;
        decls_to_remove_ = null;
    }

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /**
     * Generate CIF interfaces from AST.
     * IR must be initialized first with method "initRepository()".
     *
     * @param scope - The scope to map.
     *
     * @return The list of mapped modules.
     **/
    public List
    declare_cif(Scope scope)
    throws GenerationException
    {
        List list = null;
        Declaration[] decls = null;
        org.objectweb.openccm.ast.api.NativeDecl nativ = null;

        cif_decls_ = new ArrayList();
        decls_to_remove_ = new ArrayList();

        /** Get all psdl abstract storage home and map to native **/
        list = getAllDeclarations(scope, DeclarationKind.dk_abstract_storage_home);
        decls = (Declaration[]) list.toArray(new Declaration[0]);
        for (int i=0; i<decls.length; i++)
        {
            // System.out.println("decl : "+decls[i].getName());
            nativ = ((org.objectweb.openccm.ast.api.AbstractStorageHomeDecl)decls[i]).getMapping();
            cif_decls_.add(nativ);
            decls_to_remove_.add(nativ);
        }

        /** Get all psdl abstract storage type and map to native **/
        list = getAllDeclarations(scope, DeclarationKind.dk_abstract_storage_type);
        decls = (Declaration[]) list.toArray(new Declaration[0]);
        for (int i=0; i<decls.length; i++)
        {
            nativ = ((org.objectweb.openccm.ast.api.AbstractStorageTypeDecl)decls[i]).getMapping();
            cif_decls_.add(nativ);
            decls_to_remove_.add(nativ);
        }

        /** Get all compositions contained in the file scope **/
        list = getAllDeclarations(scope, DeclarationKind.dk_composition);
        decls = (Declaration[]) list.toArray(new Declaration[0]);

        // For each composition, call declare_cif()
        for (int i=0; i<decls.length; i++)
        {
            CompositionMapping comp = null;
            ModuleDecl module = null;

            comp = new org.objectweb.corba.generator.cif_idl.lib.CompositionMapping(
                            (CompositionDecl) decls[i]);
            module = comp.declareCIF();
            cif_decls_.add(module);
            decls_to_remove_.add(module);
        }

        // return new created declarations
        return cif_decls_;
    }


    /**
     * Remove CIF declarations from I.R.
     **/
    public void
    remove_decls()
    {
        Declaration decl = null;
        Iterator it = null;

        for(it=decls_to_remove_.iterator(); it.hasNext(); )
        {
            decl = (Declaration) it.next();
            if (decl.getDeclKind() == DeclarationKind.dk_module)
            {
                org.omg.CORBA.Contained contained = null;

                // Remove Compositions Mapping (CIF module)
                contained = rep_.lookup_id( decl.getId() );
                contained.destroy();
            }
            else
            {
                // Remove remaining declarations (i.e. Natives)
                decl.destroy();
            }
        }
    }
}
