/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.corba.generator.cif_idl.lib;

// Package dependencies.
import org.objectweb.openccm.ast.api.Declaration;
import org.objectweb.openccm.ast.api.HomeExecutorDecl;
import org.objectweb.openccm.ast.api.ModuleDecl;
import org.objectweb.openccm.ast.api.InterfaceDecl;
import org.objectweb.openccm.ast.api.InterfaceList;
import org.objectweb.openccm.ast.api.NativeDecl;
import org.objectweb.openccm.ast.api.OperationDecl;
import org.objectweb.openccm.ast.utils.api.CompositionInfo;
import org.objectweb.corba.generator.cif_idl.api.ExecutorMapping;


/**
 * This class generates CIF IDL for an OMG CIDL Home Executor.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */

public class HomeExecutorMapping
  implements org.objectweb.corba.generator.cif_idl.api.HomeExecutorMapping
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The home executor to map. */
    private HomeExecutorDecl home_exec_;

    /** The Home Executor CIF interface mapping. */
    private InterfaceDecl cif_mapping_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     *
     * @param home_exec - The home executor to map.
     */
    public HomeExecutorMapping(HomeExecutorDecl home_exec)
    {
        // Init internal states
        home_exec_ = home_exec;
        cif_mapping_ = null;
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.openccm.generator.cif_idl.api.HomeExecutorMapping
    //
    // ==================================================================

    /**
     * Declare CIF interfaces into Interface Repository.
     *
     * @param module - The module to declare CIF mapping in.
     * @param comp - An abstract view of the binding composition.
     */
    public void
    declareCIF(ModuleDecl module,
               CompositionInfo comp)
    {
        InterfaceDecl itf = null;
        Declaration[] decls = null;
        InterfaceList list = null;
        NativeDecl ast = null,
                   ash = null;
        ExecutorMapping exec_mapping = null;

        /** Create the home executor interface **/
        itf = module.declareLocalInterface( "CIF_" + home_exec_.getName() );
        // Feed inherited interface list
        list = itf.getInheritedInterfaceList();
          // the CIF_SegmentBase interface
        list.add( home_exec_.getHomeType().getLocalMapping() );
        itf.create();
        cif_mapping_ = itf;

        /** Create operations for component persistence if needed **/
        if (home_exec_.getAbstractStorageHomeBinding() != null)
        {
            OperationDecl op = null;

            ash = home_exec_.getAbstractStorageHomeBinding().getMapping();
            ast = home_exec_.getAbstractStorageHomeBinding().getAbstractStorageType().getMapping();

            op = itf.startOperation("get_state");
            op.setType(ash);
            op.create();
        }

        /** Create operations for home persistence if needed **/
        if (home_exec_.getHomePersistence() != null)
        {
            NativeDecl home_ast = null,
                       home_ash = null;
            OperationDecl op = null;

            home_ash = home_exec_.getHomePersistence().getMapping();
            home_ast = home_exec_.getHomePersistence().getAbstractStorageType().getMapping();

            op = itf.startOperation("get_home_executor_state");
            op.setType(home_ast);
            op.create();
            // Create an operation to get home_ast ?
        }

        // Generate operations if needed

        // Call mapping for component executor
        exec_mapping = new org.objectweb.corba.generator.cif_idl.lib.ExecutorMapping( comp.getComponentExecutor() );
        exec_mapping.declareCIF(comp, module, ast);
    }

    /**
     * Declare CIF interfaces into Interface Repository.
     */
    public InterfaceDecl
    getCIFMapping()
    {
        return cif_mapping_;
    }

    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================

}
