/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.corba.generator.cif_idl.lib;

// Package dependencies.
import org.objectweb.openccm.ast.api.ProxyHomeDecl;
import org.objectweb.openccm.ast.api.ModuleDecl;
import org.objectweb.openccm.ast.api.InterfaceDecl;
import org.objectweb.openccm.ast.utils.api.CompositionInfo;

/**
 * This class generates CIF IDL for an OMG CIDL Proxy Home.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */

public class ProxyHomeMapping
  implements org.objectweb.corba.generator.cif_idl.api.ProxyHomeMapping
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The proxy home to map. */
    private ProxyHomeDecl proxy_home_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     *
     * @param proxy_home - The proxy home to map.
     */
    public ProxyHomeMapping(ProxyHomeDecl proxy_home)
    {
        // Init internal states
        proxy_home_ = proxy_home;
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.openccm.generator.cif_idl.api.ProxyHomeMapping
    //
    // ==================================================================

    /**
     * Declare CIF interfaces into Interface Repository.
     *
     * @param module - The module to declare CIF mapping in.
     * @param comp - An abstract view of the binding composition.
     * @param he_mapping - The home executor CIF mapping interface.
     */
    public void
    declareCIF( ModuleDecl module,
                CompositionInfo comp,
                InterfaceDecl he_mapping)
    {
        org.objectweb.openccm.ast.api.InterfaceList list = null;
        org.objectweb.openccm.ast.api.OperationDecl op = null;
        org.objectweb.openccm.ast.api.InterfaceDecl itf = null;

        /** Create the CIF proxy home interface **/
        itf = module.declareLocalInterface("CIF_" + proxy_home_.getName());
          // Feed inherited interface list
        list = itf.getInheritedInterfaceList();
        list.add(he_mapping);
        itf.create();

        /** Add the get_home operation **/
        op = itf.startOperation("get_home");
        op.setType(he_mapping);
        op.create();
   }

    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================

}
