/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.corba.generator.dependencies.api;

// Package dependencies.
import org.objectweb.openccm.ast.api.Declaration;
import org.objectweb.openccm.ast.api.CompositionDecl;
import org.objectweb.openccm.ast.api.ExecutorDecl;
import org.objectweb.openccm.ast.api.SegmentDecl;
import org.objectweb.openccm.ast.api.HomeExecutorDecl;
import java.util.Set;


/**
 * This interface allows you to get classes dependencies for a CIDL declaration.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */

public interface CIDLDeclarationDependencies
         extends IDL3DeclarationDependencies
{
    /**
     * Get dependencies for a CIDL declaration.
     *
     * @param decl - Get dependencies for this declaration.
     *
     * @return The list of dependencies as a set of Files.
     */
    public Set
    getDeclarationDependencies(Declaration decl);

   /**
     * Get Composition File dependencies.
     *
     * @param composition - The composition declaration.
     *
     * @return The list of dependencies as a set of Files.
     */
    public Set
    getCompositionDependencies(CompositionDecl composition);

    /**
     * Get Component Executor File dependencies.
     *
     * @param exec - The Component executor declaration.
     *
     * @return The list of dependencies as a set of Files.
     */
    public Set
    getExecutorDependencies(ExecutorDecl exec);

     /**
     * Get Segment File dependencies.
     *
     * @param seg - The Segment declaration.
     *
     * @return The list of dependencies as a set of Files.
     */
    public Set
    getSegmentDependencies(SegmentDecl seg);

   /**
     * Get Home Executor File dependencies.
     *
     * @param home_exec - The home executor declaration.
     *
     * @return The list of dependencies as a set of Files.
     */
    public Set
    getHomeExecutorDependencies(HomeExecutorDecl home_exec);
}
