/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Contreras
Contributor(s):

====================================================================*/

package org.objectweb.openccm.descriptor.componentassembly.gui;

import org.objectweb.openccm.descriptor.componentassembly.beans.*;
import org.objectweb.openccm.descriptor.componentassembly.*;
import org.objectweb.openccm.descriptor.softpkg.beans.SoftpkgBean;
import org.objectweb.openccm.descriptor.softpkg.beans.SoftpkgBeanImpl;
import org.objectweb.openccm.descriptor.softpkg.gui.SoftpkgZipper;

/**
 * This is an extension to the Apollon generated framework around componentassembly DTD
 *  it looks for subelements that could contain files to archive
 *  and calls their own zipper extensions to do the same job
 *  any found file name is sent to a zip factory
 *
 */
public class ComponentfileZipper
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /**
     *  The zip method called from parents
     *
     */
    public void
    zipCall(
        ComponentfileBean componentfile
        , org.objectweb.openccm.packaging.ZipFactory zip_factory
        )
    {
        FileinarchiveBean fileinarchive
         = (FileinarchiveBean)
            componentfile.getFileinarchive();

        // goes through sub element and call its zip method
        if (fileinarchive != null)
        {
            FileinarchiveZipper sub_zipper
             = (FileinarchiveZipper) fileinarchive
                .getExtensionManager()
                .getExtensionByName("gui.Zipper")
                .getInstance();

            sub_zipper.zipCall(fileinarchive, zip_factory);


            // identifies the component file (CAR or CSD)
            java.io.File component_file
                = new java.io.File(fileinarchive.getName());

            // a flat AAR with CSD inside
            if (component_file.exists()
                && fileinarchive.getName().toLowerCase().endsWith("csd")
                && fileinarchive.getLink() == null
                )
            {
                try
                {
                    SoftpkgBean csd_instance
                        = SoftpkgBeanImpl.unmarshalBean(component_file);

                    SoftpkgZipper csd_zipper
                        = (SoftpkgZipper)
                            csd_instance
                                .getExtensionManager()
                                .getExtensionByName("gui.Zipper")
                                .getInstance();

                    csd_zipper.zipCall(csd_instance, zip_factory);

                } catch (java.io.IOException exc) {
                    System.err.println(
                        "Could not open "
                        +fileinarchive.getName()
                        +" for archive dependencies");
                }
            }
        }
    }
}
