/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Contreras
Contributor(s): ___________________________________________________.

====================================================================*/

package org.objectweb.openccm.packaging;

/**
 * This is the split panel for CCM Packaging and Assembly tools
 *
 * @author <a href="mailto:Christophe.Contreras@lifl.fr">Christophe Contreras</a>
 *
 */
public class CCMSplitPane
     extends org.objectweb.apollon.gui.ApollonSplitPane
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     *  The default constructor.
     */
    public
    CCMSplitPane()
    {
        super();

        // Register a CCM entity resolver for CAD, CCD, CSD and CPF beans
        org.objectweb.openccm.descriptor.EntityResolver.setCCMResolver();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * scans an instance for known and identified elements
     *   (componentfiles and instantiations in CAD
     *   , implementations in CSD)
     *
     * @param Bean instance the instance to scan
     */
    private void
    store_ccm_elements(org.objectweb.apollon.framework.Bean instance, String filename)
    {
        // gets the type of instance
        if (filename.endsWith(".cad")
            || filename.endsWith(".CAD"))
        {
            // the instance is an assembly
            org.objectweb.openccm.descriptor.componentassembly.beans.ComponentassemblyBean
             assembly_instance
             = (org.objectweb.openccm.descriptor.componentassembly.beans.ComponentassemblyBean)
                instance;

                // adds its id to this list
                CCMIdRefsSingleton.getInstance().addAssembly(assembly_instance);
        }

        if (filename.endsWith(".csd")
            || filename.endsWith(".CSD"))
        {
            // this instance is a software package descriptor
            org.objectweb.openccm.descriptor.softpkg.beans.SoftpkgBean
             software_instance
             = (org.objectweb.openccm.descriptor.softpkg.beans.SoftpkgBean)
                instance;

                // adds its id to this list
                CCMIdRefsSingleton.getInstance().addPackage(software_instance);
        }
    }

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /**
     * calls super add_to_tree method
     *   and scans the instance for identified elements
     *
     */
    public void
    add_instance_to_tree(org.objectweb.apollon.framework.Bean instance, java.io.File file)
    {
        super.add_instance_to_tree(instance, file);

        this.store_ccm_elements(instance,file.getName());

/*
        if (file.getName().endsWith(".cad")
            || file.getName().endsWith(".CAD"))
        {
            // the instance is an assembly
            org.objectweb.openccm.descriptor.componentassembly.beans.ComponentassemblyBean
             assembly_instance
             = (org.objectweb.openccm.descriptor.componentassembly.beans.ComponentassemblyBean)
                instance;

            if (assembly_instance.getComponentfiles() != null)
            {
                java.util.List csd_list
                 = assembly_instance.getComponentfiles().getComponentfileList();

                for (java.util.Iterator i = csd_list.iterator() ; i.hasNext() ; )
                {
                    org.objectweb.openccm.descriptor.componentassembly.Componentfile csd
                     = (org.objectweb.openccm.descriptor.componentassembly.Componentfile)
                        i.next();

                    if (csd.getFileinarchive() != null
                        && csd.getFileinarchive().getLink() == null)
                    {
                        //gets the frame
                        org.objectweb.apollon.gui.ApollonFrame calling_frame
                            = (org.objectweb.apollon.gui.ApollonFrame)
                                this.getRootPane().getParent();

                        calling_frame.open_file(
                            new java.io.File(
                                csd.getFileinarchive().getName()
                                )
                            );

                    }
                }
            }
        }
*/
    }

    /**
     * calls super save method for an entry
     *   and scans the instances for identified elements
     *
     */
    public void
    save_tree_entry(org.objectweb.util.browser.api.Entry tree_entry)
    {
        super.save_tree_entry(tree_entry);

        this.store_ccm_elements(
            (org.objectweb.apollon.framework.Bean)
                ((org.objectweb.apollon.framework.Context)
                    tree_entry.getValue()
                        ).getSource()
            ,(String) tree_entry.getName()
            );
    }
}
