/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Contreras
Contributor(s): ___________________________________________________.

====================================================================*/

package org.objectweb.openccm.packaging.cmdline;

// Package dependencies.
import org.objectweb.util.cmdline.lib.DefaultOptionBase;


/**
 * Base abstract implementation for Tools Option objects.
 *
 * Subclasses must implement the consume method.
 *
 * @author <a href="mailto:christophe.contreras@lifl.fr">Christophe Contreras</a>
 *
 */

public abstract class OptionBase
              extends DefaultOptionBase
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The application. */
    private PATApplication application_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /** The default constructor. */
    public
    OptionBase()
    {
        // Calls the DefaultOptionBase constructor.
        super();

        setArguments(new String[0]);
        setMandatory(false);

        // Inits internal state.
        application_ = null;
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for interface org.objectweb.util.cmdline.api.Option
    //
    // ==================================================================

    /**
     * Checks the current command line argument.
     *
     * @param current The current command line argument.
     *
     * @return true if the option accepts this argument.
     */
    public boolean
    check(String current)
    {
      String baseOptionLabel = getBaseOptionLabel();

        if (!current.startsWith(baseOptionLabel))
        {
            return false;
        }

        consumeOption(current.substring(baseOptionLabel.length()));
        return true;
    }

    /**
     * Consumes command line arguments from an iterator.
     *
     * @param iterator The command line argument iterator.
     */
    public void
    consume(org.objectweb.util.cmdline.api.Iterator iterator)
    {
        // Nothing to do.
    }

    /**
     * Obtains the associated application.
     *
     * @return The associated application.
     */
    public PATApplication
    getApplication()
    {
        return application_;
    }

    /**
     * Sets the associated application.
     *
     * @param preprocessor The associated application.
     */
    public void
    setApplication(PATApplication application)
    {
        application_ = application;
    }

    /**
     * Gets the base option label.
     *
     * @return The base option label.
     */
    abstract public String
    getBaseOptionLabel();

    /**
     * Consumes the option.
     *
     * @param current The option value.
     */
    abstract public void
    consumeOption(String current);

}