/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Contreras
Contributor(s): ___________________________________________________.

====================================================================*/

package org.objectweb.openccm.packaging.cmdline;

// Package dependencies
import org.objectweb.openccm.packaging.AssemblyPackager;
import org.objectweb.openccm.packaging.CCMMenuBar;
import org.objectweb.openccm.packaging.CCMSplitPane;
import org.objectweb.openccm.packaging.ComponentPackager;
import org.objectweb.openccm.packaging.FileOperations;

import org.objectweb.util.cmdline.api.CommandLine;
import org.objectweb.util.cmdline.lib.ApplicationBase;
import org.objectweb.util.cmdline.lib.DefaultCommandLine;

import org.objectweb.apollon.gui.ApollonFrame;

/**
 * This is the Application class for OpenCCM's Packaging/Assembling Tools
 *
 * @author <a href="mailto:Christophe.Contreras@lifl.fr">Christophe Contreras</a>
 *
 */
public class PATApplication
     extends ApplicationBase
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The GUi display setting. */
    private boolean displayGUI_;
    
    /** The CAR archive maker setting. */
    private boolean CARMaker_;
    
    /** The AAR archive maker setting. */
    private boolean AARMaker_;
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     *  The default constructor.
     */
    public
    PATApplication()
    {
        // default Application constructor
        super(
            new DefaultCommandLine(
                new String [] { "ccm_assembling", "car_maker" , "aar_maker" }
                ,new String[0]
                ,true
                ,new String[] {
                    "Packaging/Assembling Tool providing a GUI and console-based engines (default is GUI)."
                    ,"car_maker is a shortcut for 'ccm_assembling -CAR'"
                    ,"aar_maker is a shortcut for 'ccm_assembling -AAR'"
                    ,"[additional] arguments should be descriptor files to be opened or used for CAR/AAR creation."
                    }
                ,true
                )
            );
        
        // inits the commandLine options
        getCommandLine().addOption(new OptionCAR(this));
        getCommandLine().addOption(new OptionAAR(this));
        
        // inits default to GUI displayed
        this.displayGUI_ = true;
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.util.api.Identifiable
    //
    // ==================================================================

    /**
     * Obtains its identity.
     *
     * @return Its identity.
     */
    public String
    getIdentity()
    {
        return "OpenCCM's Packaging/Assembling Tools";
    }

    /**
     * Executes the main function, i.e.
     * 1 - arguments = getCommandLine().parse(args);
     * 2 - status = starts(arguments);
     *
     * @param args The command line arguments.
     */
    public void
    runMain(String[] args)
    {
        try {
            // Parses the command line arguments.
            String[] arguments = getCommandLine().parse(args);
            
            // Starts the application.
            int status = start(arguments);

        // If any exception thrown then reports it.
        //
        } catch(org.objectweb.util.misc.api.ExceptionWrapper exc) {
            report_exception(exc.getException());
        } catch(Exception exc) {
            report_exception(exc);
        }
    }

    /**
     * Starts the application.
     *
     * @param args The command line arguments.
     *
     * @return The status.
     */
    public int
    start(String[] args)
    {
        boolean result = process(args);
        return 0;

//        return result?0:1;
    }

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================
    /**
     * Enables/Disables the GUI display
     *
     * @param displayGUI The boolean indicating GUI display setting
     */
    public void
    displayGUI(boolean displayGUI)
    {
        this.displayGUI_ = displayGUI;
    }

    /**
     * Enables the CAR archive maker
     *
     * @param CAR indicates to use the CAR maker
     */
    public void
    setCARMaker(boolean CAR)
    {
        this.CARMaker_ = CAR;
    }

    /**
     * Enables the AAR archive maker
     *
     * @param AAR indicates to use the CAR maker
     */
    public void
    setAARMaker(boolean AAR)
    {
        this.AARMaker_ = AAR;
    }

    /**
     * Global processing method.
     *
     * @param filenames The XML DTD to generate Java from.
     *
     * @return True if OK.
     */
    public boolean
    process (String[] filenames)
    {
        if (this.displayGUI_)
        {
            // inits the graphical frame
            ApollonFrame frame
             = new ApollonFrame();

            // inits the split panel of the frame
            frame.set_split_panel(new CCMSplitPane());

            // Adds the CCM part of the Menubar to existing
            CCMMenuBar ccm_menubar
             = new CCMMenuBar(frame);

            frame.setVisible(true);

            // opens files given as arguments
            for (int i=0 ; i<filenames.length ; i++)
            {
                java.io.File file
                 = new java.io.File(filenames[i]);

                FileOperations.open_file(file, frame);
            }
            synchronized (this)
            {
                try
                {
                    this.wait();
                } catch (InterruptedException e) {}
            }
        }
        for (int i=0 ; i<filenames.length ; i++)
        {
            String file_used = filenames[i];
System.err.println(file_used);

            // direct operations on the files passed as arguments
            java.io.File file
             = new java.io.File (file_used);

            org.objectweb.apollon.framework.Bean zeus_instance
             = null;

            if (CARMaker_)
            {
                // Parses the descriptor
                try
                {
                    zeus_instance
                     = org.objectweb.openccm.descriptor.
                        softpkg.beans.
                        SoftpkgBeanImpl
                            .unmarshalBean(file);
                    // instantiate and call a Packager
                    ComponentPackager maker = new ComponentPackager();
                    maker.make_zip(zeus_instance,file_used);

                } catch (Exception e) {
                    getConsole().getErrorStream().println(
                        "CAR builder ignored "+file);
                }
            }
            if (AARMaker_)
            {
                // Parses the descriptor
                try
                {
                    zeus_instance
                     = org.objectweb.openccm.descriptor.
                        componentassembly.beans.
                        ComponentassemblyBeanImpl
                            .unmarshalBean(file);
                    // instantiate and call a Packager
                    AssemblyPackager maker = new AssemblyPackager();
                    maker.make_zip(zeus_instance,file_used);

                } catch (Exception e) {
                    getConsole().getErrorStream().println(
                        "AAR builder ignored "+file);
                }
            }
        }
        return true;
    }

    // ==================================================================
    //
    // Static public methods.
    //
    // ==================================================================

    /**
     * The main bootstrap method.
     *
     * @param args The command line arguments.
     */
    public static void
    main(String[] args)
    {
        PATApplication application = new PATApplication();
        application.runMain(args);
    }
}
