/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ________________________________________.

====================================================================*/

package org.objectweb.openccm.generator.java.ast.api;

import java.util.ArrayList;

/**
 * This is the representation for java Classes.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</A>
 */

public interface ClassObject
         extends InterfaceObject
{
    /**
     * Add an implemented object.
     *
     * @param object - The object to add.
     */
    public void
    addImplementedObject(String object);

    /**
     * Obtain all implemented objects.
     *
     * @return A list of implemented objects.
     */
    public ArrayList
    getImplementedObjects();

    /**
     * Add a constructor.
     *
     * @param constr - The constructor to add.
     */
    public void
    addConstructor(ConstructorObject constr);

    /**
     * Obtain all constructors.
     *
     * @return A list of constructors.
     */
    public ArrayList
    getConstructors();

    /**
     * Add an attribute.
     *
     * @param object - The attribute to add.
     */
    public void
    addAttribute(AttributeObject att);

    /**
     * Obtain all attributes.
     *
     * @return A list of attributes.
     */
    public ArrayList
    getAttributes();
}
