/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ________________________________________.

====================================================================*/

package org.objectweb.openccm.generator.java.ast.lib;

import org.objectweb.openccm.generator.java.ast.api.ClassObject;
import org.objectweb.openccm.generator.java.ast.api.ConstructorObject;
import org.objectweb.openccm.generator.java.ast.api.AttributeObject;
import java.util.ArrayList;

/**
 * This is the representation for java Classes.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</A>
 */

public class ClassObjectImpl
     extends InterfaceObjectImpl
  implements ClassObject
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** Implemented objects */
    private ArrayList implemented_objects_;

    /** Class constructors */
    private ArrayList constructors_;

    /** Class constructors */
    private ArrayList attributes_;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public
    ClassObjectImpl()
    {
        // Init internal states
        super();
        implemented_objects_ = new ArrayList();
        constructors_ = new ArrayList();
        attributes_ = new ArrayList();
    }

    /**
     * The constructor with the name.
     *
     * @param name - The name to set.
     */
    public
    ClassObjectImpl(String name)
    {
        // Init internal states
        super();
        implemented_objects_ = new ArrayList();
        constructors_ = new ArrayList();
        attributes_ = new ArrayList();

        setName(name);
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for org.objectweb.openccm.generator.java.ast.api.ClassObject
    //
    // ==================================================================

    /**
     * Add an implemented object.
     *
     * @param object - The object to add.
     */
    public void
    addImplementedObject(String object)
    {
        implemented_objects_.add(object);
    }

    /**
     * Obtain all implemented objects.
     *
     * @return A list of implemented objects.
     */
    public ArrayList
    getImplementedObjects()
    {
        return implemented_objects_;
    }

    /**
     * Add a constructor.
     *
     * @param constr - The constructor to add.
     */
    public void
    addConstructor(ConstructorObject constr)
    {
        constructors_.add(constr);
    }

    /**
     * Obtain all constructors.
     *
     * @return A list of constructors.
     */
    public ArrayList
    getConstructors()
    {
        return constructors_;
    }

    /**
     * Add an attribute.
     *
     * @param object - The attribute to add.
     */
    public void
    addAttribute(AttributeObject att)
    {
        attributes_.add(att);
    }

    /**
     * Obtain all attributes.
     *
     * @return A list of attributes.
     */
    public ArrayList
    getAttributes()
    {
        return attributes_;
    }
}
