/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Mathieu Vadet, Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.openccm.generator.translator.idl2java.lib;

// Package dependencies.
import org.objectweb.openccm.ast.api.Declaration;
import org.objectweb.openccm.ast.api.DeclarationKind;
import org.objectweb.openccm.ast.api.TypeKind;

/**
 * This class offers some IDL translations such as IDL names to Java names, etc.
 *
 * @author <a href="mailto:Mathieu.Vadet@lifl.fr">Mathieu Vadet</a>
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */

public class CommonTranslator
  implements org.objectweb.openccm.generator.translator.idl2java.api.CommonTranslator
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /**
     * Table with declaration absolute names translated into java
     */
    protected java.util.Map abs_names_;

    /**
     * Java keywords table.
     */
    protected java.util.Set keywords_;


    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /**
     *  The default constructor.
     */
    public
    CommonTranslator()
    {
        abs_names_ = new java.util.HashMap();
        keywords_ = new java.util.HashSet();
        keywords_.add("public");
        keywords_.add("protected");
        keywords_.add("private");
        keywords_.add("class");
        keywords_.add("interface");
        keywords_.add("abstract");
        keywords_.add("boolean");
        keywords_.add("break");
        keywords_.add("byte");
        keywords_.add("case");
        keywords_.add("catch");
        keywords_.add("char");
        keywords_.add("const");
        keywords_.add("continue");
        keywords_.add("default");
        keywords_.add("do");
        keywords_.add("double");
        keywords_.add("else");
        keywords_.add("extends");
        keywords_.add("final");
        keywords_.add("finally");
        keywords_.add("float");
        keywords_.add("for");
        keywords_.add("goto");
        keywords_.add("if");
        keywords_.add("implements");
        keywords_.add("import");
        keywords_.add("instanceof");
        keywords_.add("int");
        keywords_.add("long");
        keywords_.add("native");
        keywords_.add("new");
        keywords_.add("package");
        keywords_.add("return");
        keywords_.add("short");
        keywords_.add("static");
        keywords_.add("super");
        keywords_.add("switch");
        keywords_.add("synchronized");
        keywords_.add("this");
        keywords_.add("throw");
        keywords_.add("throws");
        keywords_.add("transient");
        keywords_.add("try");
        keywords_.add("void");
        keywords_.add("volatile");
        keywords_.add("while");
        keywords_.add("true");
        keywords_.add("false");
        keywords_.add("null");
        keywords_.add("clone");
        keywords_.add("equals");
        keywords_.add("finalize");
        keywords_.add("getClass");
        keywords_.add("hashCode");
        keywords_.add("notify");
        keywords_.add("notifyAll");
        keywords_.add("toString");
        keywords_.add("wait");
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for org.objectweb.openccm.generator.translator.idl2java.api.CommonTranslator.
    //
    // ==================================================================

    /**
     * Translate a TypeRef into its java mapping.
     *
     * @param typeref - The TypeRef to translate.
     *
     * @return The resulting mapping.
     **/
    public java.lang.String
    toJava(org.objectweb.openccm.ast.api.TypeRef typeref)
    {
        TypeKind tk = typeref.getTypeKind();

        if (tk == TypeKind.tk_null)
            return "null";
        else if (tk == TypeKind.tk_void)
            return "void";
        else if (tk == TypeKind.tk_short)
            return "short";
        else if (tk == TypeKind.tk_ushort)
            return "short";
        else if (tk == TypeKind.tk_long)
            return "int";
        else if (tk == TypeKind.tk_ulong)
            return "int";
        else if (tk == TypeKind.tk_longlong)
            return "long";
        else if (tk == TypeKind.tk_ulonglong)
            return "long";
        else if (tk == TypeKind.tk_float)
            return "float";
        else if (tk == TypeKind.tk_double)
            return "double";
        else if (tk == TypeKind.tk_longdouble)
            return "double";
        else if (tk == TypeKind.tk_boolean)
            return "boolean";
        else if (tk == TypeKind.tk_char)
            return "char";
        else if (tk == TypeKind.tk_wchar)
            return "char";
        else if (tk == TypeKind.tk_octet)
            return "byte";
        else if (tk == TypeKind.tk_any)
            return "org.omg.CORBA.Any";
        else if (tk == TypeKind.tk_Principal)
            return "org.omg.CORBA.Principal";
        else if (tk == TypeKind.tk_TypeCode)
            return "org.omg.CORBA.TypeCode";
        else if (tk == TypeKind.tk_objref)
            return "org.omg.CORBA.Object";
        else if (tk == TypeKind.tk_string)
            return "String";
        else if (tk == TypeKind.tk_wstring)
            return "String";
        else if (tk == TypeKind.tk_fixed)
            return "java.Math.BigDecimal";

        else if ( tk == TypeKind.tk_struct ||
                  tk == TypeKind.tk_union ||
                  tk == TypeKind.tk_enum ||
                  tk == TypeKind.tk_exception ||
                  tk == TypeKind.tk_value_box ||
                  tk == TypeKind.tk_value ||
                  tk == TypeKind.tk_native ||
                  tk == TypeKind.tk_abstract_interface ||
                  tk == TypeKind.tk_local_interface ||
                  tk == TypeKind.tk_interface ||
                  tk == TypeKind.tk_component ||
                  tk == TypeKind.tk_home ||
                  tk == TypeKind.tk_event )
            {
                org.objectweb.openccm.ast.api.Declaration decl;
                decl = (org.objectweb.openccm.ast.api.Declaration)typeref;
                return getAbsoluteName(decl);
            }

        else if (tk == TypeKind.tk_alias)
        {
            org.objectweb.openccm.ast.api.AliasDecl alias;
            alias  = (org.objectweb.openccm.ast.api.AliasDecl)typeref;
            return toJava(alias.getType());
        }

        else if ( tk == TypeKind.tk_sequence ||
                  tk == TypeKind.tk_array )
        {
            org.objectweb.openccm.ast.api.TypeRefWithContent content;
            content = (org.objectweb.openccm.ast.api.TypeRefWithContent)typeref;
            java.lang.String str = toJava(content.getContentType());
            return str+"[]";
        }
        else
            return "";
    }

    /**
     * Translate a parameter into its java mapping.
     *
     * @param typeref - The TypeRef to translate.
     * @param mode - The parameter mode (in, out or inout).
     *
     * @return The resulting mapping.
     **/
    public java.lang.String
    toJava(org.objectweb.openccm.ast.api.TypeRef type,
           int mode)
    {
        if (mode==org.omg.CORBA.ParameterMode._PARAM_IN)
            return toJava(type);

        // mode is 'out' or 'inout'
        TypeKind tk = type.getTypeKind();
        if ( tk == TypeKind.tk_null ||
             tk == TypeKind.tk_void )
                throw new Error("IDL null and void types could not be used for out or inout parameters!!!");

        else if (tk == TypeKind.tk_short )
            return "org.omg.CORBA.ShortHolder";
        else if (tk == TypeKind.tk_ushort )
            return "org.omg.CORBA.ShortHolder";
        else if (tk == TypeKind.tk_long )
            return "org.omg.CORBA.IntHolder";
        else if (tk == TypeKind.tk_ulong )
            return "org.omg.CORBA.IntHolder";
        else if (tk == TypeKind.tk_longlong )
            return "org.omg.CORBA.LongHolder";
        else if (tk == TypeKind.tk_ulonglong )
            return "org.omg.CORBA.LongHolder";
        else if (tk == TypeKind.tk_float )
            return "org.omg.CORBA.FloatHolder";
        else if (tk == TypeKind.tk_double )
            return "org.omg.CORBA.DoubleHolder";
        else if (tk == TypeKind.tk_longdouble )
            throw new Error("Java mapping for IDL longdouble is unspecified!!!");
        else if (tk == TypeKind.tk_boolean )
            return "org.omg.CORBA.BooleanHolder";
        else if (tk == TypeKind.tk_char )
            return "org.omg.CORBA.CharHolder";
        else if (tk == TypeKind.tk_wchar )
            return "org.omg.CORBA.CharHolder";
        else if (tk == TypeKind.tk_octet )
            return "org.omg.CORBA.ByteHolder";
        else if (tk == TypeKind.tk_any )
            return "org.omg.CORBA.AnyHolder";
        else if (tk == TypeKind.tk_Principal )
            return "org.omg.CORBA.PrincipalHolder";
        else if (tk == TypeKind.tk_TypeCode )
            return "org.omg.CORBA.TypeCodeHolder";
        else if (tk == TypeKind.tk_objref )
            return "org.omg.CORBA.ObjectHolder";
        else if (tk == TypeKind.tk_string )
            return "org.omg.CORBA.StringHolder";
        else if (tk == TypeKind.tk_wstring )
            return "org.omg.CORBA.StringHolder";
        else if (tk == TypeKind.tk_fixed )
            return "org.omg.CORBA.FixedHolder";
        else if (tk == TypeKind.tk_alias )
            {
                org.objectweb.openccm.ast.api.TypeRef ct;
                ct = ((org.objectweb.openccm.ast.api.AliasDecl)type).getType();
                if ((ct.getTypeKind()==TypeKind.tk_array) ||
                    (ct.getTypeKind()==TypeKind.tk_sequence))
                    return getAbsoluteName((org.objectweb.openccm.ast.api.AliasDecl)type) + "Holder";
                else
                    return toJava(ct, mode);
            }
        else if ( tk == TypeKind.tk_sequence ||
                  tk == TypeKind.tk_array )
            throw new Error("Not implemented!!!");
        else if ( tk == TypeKind.tk_struct ||
                  tk == TypeKind.tk_union ||
                  tk == TypeKind.tk_enum ||
                  tk == TypeKind.tk_exception ||
                  tk == TypeKind.tk_value_box ||
                  tk == TypeKind.tk_value ||
                  tk == TypeKind.tk_native ||
                  tk == TypeKind.tk_abstract_interface ||
                  tk == TypeKind.tk_local_interface ||
                  tk == TypeKind.tk_interface ||
                  tk == TypeKind.tk_component ||
                  tk == TypeKind.tk_home ||
                  tk == TypeKind.tk_event )
            return getAbsoluteName((org.objectweb.openccm.ast.api.Declaration)type) + "Holder";
        else
            throw new Error("Other cases are not supported!!!");
    }

    /**
     * Check if id is a java keyword.
     *
     * @param id - The string to check
     *
     * @return A valid string.
     **/
    public java.lang.String
    checkKeywords(java.lang.String id)
    {
        if (keywords_.contains(id))
           return "_"+id;

        return id;
    }

    /**
     * Get the java absolute name of a declaration
     * ( i.e. package.decl_name ).
     *
     * @param decl - The declaration to translate
     *
     * @return The java absolute name.
     **/
    public java.lang.String
    getAbsoluteName(Declaration decl)
    {
        if (decl==null)
            return "";

        // check if the absolute name has already been generated.
        java.lang.String res = null;
        res = (java.lang.String)abs_names_.get(decl.getId());
        if (res!=null)
            return res;

        // translate the IDL prefix into a java prefix.
        res = "";
        java.lang.String prefix = decl.getPrefix();
        int idx, idx2;
        if (!prefix.equals(""))
        {
            idx = prefix.indexOf('.');
            idx2 = 0;
            while (idx!=-1)
            {
                res = prefix.substring(idx2, idx+1) + res;
                idx2 = idx+1;
                idx = prefix.indexOf('.', idx2);
            }
            res = prefix.substring(idx2) + '.' + res;
        }

        // translate the IDL scoped name into a Java absolute name
        java.lang.String abs_name = decl.getAbsoluteName();
        idx = abs_name.indexOf(':', 2);
        idx2 = 2;
        while (idx!=-1)
        {
            res = res + abs_name.substring(idx2, idx) + '.';
            idx2 = idx+2;
            idx = abs_name.indexOf(':', idx2);
        }
        res = res + abs_name.substring(idx2);

        // check special cases ie nested types within interfaces
        org.objectweb.openccm.ast.api.Scope parent = decl.getParent();
        long parent_kind = parent.getDeclKind();
        long decl_kind = decl.getDeclKind();
        if (decl_kind==DeclarationKind.dk_constant)
        {
            if ((parent_kind!=DeclarationKind.dk_interface) &&
                (parent_kind!=DeclarationKind.dk_abstract_interface) &&
                (parent_kind!=DeclarationKind.dk_local_interface))
                res = res + ".value";
        }
        else if ((decl_kind==DeclarationKind.dk_exception) ||
                 (decl_kind==DeclarationKind.dk_alias) ||
                 (decl_kind==DeclarationKind.dk_struct) ||
                 (decl_kind==DeclarationKind.dk_union) ||
                 (decl_kind==DeclarationKind.dk_enum) ||
                 (decl_kind==DeclarationKind.dk_native))
        {
            if ((parent_kind==DeclarationKind.dk_interface) ||
                (parent_kind==DeclarationKind.dk_abstract_interface) ||
                (parent_kind==DeclarationKind.dk_local_interface) ||
                (parent_kind==DeclarationKind.dk_home) ||
                (parent_kind==DeclarationKind.dk_value) ||
                (parent_kind==DeclarationKind.dk_event) ||
                (parent_kind==DeclarationKind.dk_component))
            {
                idx = res.lastIndexOf('.');
                res = res.substring(0, idx) + "Package" + res.substring(idx);
            }
        }

        // store the computed absolute name
        abs_names_.put(decl.getId(), res);
        return res;
    }

    /**
     * Get the package of a declaration.
     *
     * @param decl - The declaration to translate
     *
     * @return The java package name.
     **/
    public java.lang.String
    getPackage(Declaration decl)
    {
        java.lang.String abs_name = getAbsoluteName(decl);
        int idx = abs_name.lastIndexOf('.');
        if (idx==-1)
            return "";

        return abs_name.substring(0, idx);
    }

    /**
     * Get the java path of a declaration.
     * This don't include the declaration's java name.
     * The package name is translated to a path.
     *
     * @param decl - The declaration to translate
     *
     * @return The java package name.
     **/
    public String
    getAsDirectory(String package_name)
    {
        if (package_name == null)
            return "./";

        return package_name.replace('.', java.io.File.separatorChar);
    }

    /**
     * Get the java path of a declaration.
     * This don't include the declaration's java name.
     * The package name is translated to a path.
     *
     * @param decl - The declaration to translate
     *
     * @return The java package name.
     **/
    public java.lang.String
    getAsDirectory(Declaration decl)
    {
        java.lang.String abs_name = getAbsoluteName(decl);
        int idx = abs_name.indexOf('.');
        if (idx==-1)
            return "./";

        java.lang.String dir = "";
        int idx2 = 0;
        while (idx!=-1)
        {
            dir = dir + abs_name.substring(idx2, idx) + '/';
            idx2 = idx+1;
            idx = abs_name.indexOf('.', idx2);
        }

        return dir;
    }

    /**
     * Get the null value for an IDL3 TypeRef
     *
     * @param typeref - The TypeRef to translate.
     *
     * @return The null value for this typeref.
     **/
    public java.lang.String
    nullValue(org.objectweb.openccm.ast.api.TypeRef typeref)
    {
        TypeKind tk = typeref.getTypeKind();

        if ( (tk == TypeKind.tk_null) ||
             (tk == TypeKind.tk_void) )
            return "NO_VALUE";
        else if ( (tk == TypeKind.tk_short) ||
                  (tk == TypeKind.tk_ushort) )
            return "0";
        else if ( (tk == TypeKind.tk_long) ||
                  (tk == TypeKind.tk_ulong) )
            return "0";
        else if ( (tk == TypeKind.tk_longlong) ||
                  (tk == TypeKind.tk_ulonglong) )
            return "0";
        else if ( (tk == TypeKind.tk_char) ||
                  (tk == TypeKind.tk_wchar) )
            return "\'\0\'";
        else if ( (tk == TypeKind.tk_string) ||
                  (tk == TypeKind.tk_wstring) )
            return "\"\"";
        else if (tk == TypeKind.tk_float)
            return "0f";
        else if (tk == TypeKind.tk_double)
            return "0.0";
        else if (tk == TypeKind.tk_boolean)
            return "true";
        else if (tk == TypeKind.tk_octet)
            return "(byte)0";
        // objects case
        else
            return "null";
    }

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

}
