#!/bin/sh -f
# ====================================================================
#
# OpenCCM: The Open CORBA Component Model Platform
# Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
# Contact: openccm@objectweb.org
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
# USA
#
# Initial developer(s): Philippe Merle.
# Contributor(s): ______________________________________.
#
# ====================================================================

# Goes to the root of the OpenCCM distribution.
cd ../..

# Shell function to stop the Interface Repository and exit.
stop_and_exit()
{
  ir3_stop
  echo Please report this problem to the openccm@objectweb.org mailing list!
  exit -1
}

# Shell function to exit if error occurs on the last command.
exit_if_status_is_not_OK()
{
  if [ $? != 0 ]
  then
    stop_and_exit
  fi
}

# Shell function to exit if no error occurs on the last command.
exit_if_status_is_OK()
{
  if [ $? == 0 ]
  then
    echo ERROR: The previous ir3_destroy should fail!!!
    stop_and_exit
  fi
}

# Starts the OpenCCM Interface Repository.
ir3_start

# Feeds test/sample.idl3 into the Interface Repository.
ir3_feed test/sample.idl3

# Destroys the sample module from the Interface Repository.
ir3_destroy sample
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.id into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M module from the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.id into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M::M1 module from the Interface Repository.
ir3_destroy M::M1
exit_if_status_is_not_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.id into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M::M1::I interface from the Interface Repository.
ir3_destroy M::M1::I
exit_if_status_is_not_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.idl into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M::M1::I::getI operation from the Interface Repository.
ir3_destroy M::M1::I::getI
exit_if_status_is_not_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.idl into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M::M2 module from the Interface Repository.
ir3_destroy M::M2
exit_if_status_is_not_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.idl into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M::M2::J interface from the Interface Repository.
ir3_destroy M::M2::J
exit_if_status_is_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.idl into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M::M2::I and M::M2::J interfaces from the Interface Repository.
ir3_destroy M::M2::I
exit_if_status_is_not_OK
ir3_destroy M::M2::J
exit_if_status_is_not_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.idl into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys M::M2::I::getJ and M::M2::J interface from the Interface Repository.
ir3_destroy M::M2::I::getJ
exit_if_status_is_not_OK
ir3_destroy M::M2::J
exit_if_status_is_not_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.idl into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M::M3 module from the Interface Repository.
ir3_destroy M::M3
exit_if_status_is_not_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.idl into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M::M3::MI::I interface from the Interface Repository.
ir3_destroy M::M3::MI::I
exit_if_status_is_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.idl into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M::M3::MJ and M::M3::MI::I interfaces from the Interface Repository.
ir3_destroy M::M3::MJ
exit_if_status_is_not_OK
ir3_destroy M::M3::MI::I
exit_if_status_is_not_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.idl into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M::M3::MI::I interface from the Interface Repository.
ir3_destroy M::M3::MJ::J
exit_if_status_is_not_OK
ir3_destroy M::M3::MI::I
exit_if_status_is_not_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.id into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys M::M3::MJ::J::getI and M::M3::MI::I interface from the Interface Repository.
ir3_destroy M::M3::MJ::J::getI
exit_if_status_is_not_OK
ir3_destroy M::M3::MI::I
exit_if_status_is_not_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.idl into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M::M4 module from the Interface Repository.
ir3_destroy M::M4
exit_if_status_is_not_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.idl into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M::M4::I interface from the Interface Repository.
ir3_destroy M::M4::I
exit_if_status_is_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Feeds test/ir3/check_ir3_destroy.idl into the Interface Repository.
ir3_feed test/ir3/check_ir3_destroy.idl

# Destroys the M::MI interface from the Interface Repository.
ir3_destroy M::M4::J
exit_if_status_is_not_OK
ir3_destroy M::M4::Iseq
exit_if_status_is_not_OK
ir3_destroy M::M4::I
exit_if_status_is_not_OK

# Cleans up the Interface Repository.
ir3_destroy M
exit_if_status_is_not_OK

# Stops the OpenCCM Interface Repository.
ir3_stop

# Tests run successfully.
echo All ir3_destroy tests run successfully.
exit 0
