/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.openccm.pss.demo1;

/**
 * This is the client application to access Form.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */
public class Client
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    // Reference to the remote object
    private static Form form = null;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /**
     * The application entry point.
     * 
     * @param args - Application arguments.
     */
    public static void
    main( String args[] )
    {
        String ns_name = null;

        // Init the ORB.
        args = org.objectweb.openccm.corba.TheORB.initialize(args);

        // Obtain the ORB.
        org.omg.CORBA.ORB orb = org.objectweb.openccm.corba.TheORB.getORB();

        // Obtain the Name Service.
        System.out.println("Obtaining the Name Service...");
        org.omg.CORBA.Object obj = null;
        try {
            obj = orb.resolve_initial_references("NameService");
        } catch(org.omg.CORBA.ORBPackage.InvalidName ex) {
            ex.printStackTrace();
        }
        org.omg.CosNaming.NamingContext nc = org.omg.CosNaming.NamingContextHelper.narrow(obj);


        // Resolving the pss::demo1::form instance
        ns_name = "My_PSS_demo1_form";
        System.out.println("Obtaining the " + ns_name + " Form instance...");
        org.omg.CosNaming.NameComponent[] ncomp = new org.omg.CosNaming.NameComponent[1];
        ncomp[0] = new org.omg.CosNaming.NameComponent(ns_name, "");
        try {
            obj = nc.resolve(ncomp);
        } catch(org.omg.CosNaming.NamingContextPackage.NotFound ex1) {
            ex1.printStackTrace();
        } catch(org.omg.CosNaming.NamingContextPackage.CannotProceed ex2) {
            ex2.printStackTrace();
        } catch(org.omg.CosNaming.NamingContextPackage.InvalidName ex3){
            ex3.printStackTrace();
        }

        // Narrow the object reference
        form = FormHelper.narrow( obj );

        int option = 0;

        boolean stop = false;

        while ( !stop )
        {
            option = menu();

            switch ( option )
            {

            case 0 :
                stop = true;
                System.exit(0);
                break;

            case 1 :
                createPerson();
                break;

            case 2 :
                removePerson();
                break;

            case 3 :
                displayPerson();
                break;
            }
        }

    }

    /**
     * Create a new person
     */
    public static void
    createPerson()
    {
        try
        {
            System.out.println( "[ Create a new person ]" );
            System.out.print( "First Name : " );
            String first_name = input();

            System.out.print( "Last Name : " );
            String last_name = input();

            System.out.print( "Age : " );
            int age = new Integer( input() ).intValue();

            System.out.print( "Address Line1 : " );
            String address_line1 = input();

            System.out.print( "Address Line2 : " );
            String address_line2 = input();

            System.out.print( "Address City : " );
            String address_city = input();

            System.out.print( "Address Zip : " );
            String address_zip = input();

            System.out.println( "" );

            form.createPerson( first_name, last_name, age,
                               address_line1, address_line2, address_city, address_zip );
        }
        catch ( org.omg.CORBA.SystemException ex )
        {
            System.out.println( "A CORBA System exception has been intercepted" );
            ex.printStackTrace();
        }
    }

    /**
     * This operation is used to remove a person.
     */
    public static void
    removePerson()
    {
        try
        {
            System.out.println( "[ Remove a person ]" );
            System.out.print( "First Name : " );
            String first_name = input();

            System.out.print( "Last Name : " );
            String last_name = input();

            System.out.println( "" );

            form.removePerson( first_name, last_name );
        }
        catch ( org.omg.CORBA.SystemException ex )
        {
            System.out.println( "A CORBA System exception has been intercepted" );
            ex.printStackTrace();
        }
    }

    /**
     * This operation is used to display person's data.
     */
    public static void
    displayPerson()
    {
        try
        {
            System.out.println( "[ Display a person ]" );
            System.out.print( "First Name : " );
            String first_name = input();

            System.out.print( "Last Name : " );
            String last_name = input();

            System.out.println( "" );

            System.out.print( form.showPerson(first_name, last_name) );
        }
        catch ( org.omg.CORBA.SystemException ex )
        {
            System.out.println( "A CORBA System exception has been intercepted" );
            ex.printStackTrace();
        }
    }

    /**
     * Read input from the keyboard.
     * 
     * @return The string read.
     */
    public static String
    input()
    {
        try
        {
            java.io.BufferedReader reader = new java.io.BufferedReader( new java.io.InputStreamReader( System.in ) );

            return reader.readLine();
        }
        catch ( java.lang.Exception ex )
        {
            ex.printStackTrace();
        }

        return null;
    }

    /**
     * Display the menu
     * 
     * @return The menu identifier.
     */
    public static int menu()
    {
        System.out.println( "Select a choice : " );
        System.out.println( "\t0. Quit" );
        System.out.println( "\t1. Create a new person" );
        System.out.println( "\t2. Remove a person" );
        System.out.println( "\t3. Display all person's data" );

        String choice = input();

        return new Integer( choice ).intValue();
    }
}
