/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ________________________________________.

====================================================================*/

package org.objectweb.openccm.pss.generator.common.lib;

// Package dependencies
/** To access AST. */
import org.objectweb.openccm.ast.api.AbstractStorageTypeDecl;
import org.objectweb.openccm.ast.api.StorageTypeStateMemberDecl;
import org.objectweb.openccm.ast.api.PsdlOperationDecl;
import org.objectweb.openccm.ast.api.DeclarationKind;
/** To access Java AST. */
import org.objectweb.openccm.generator.java.ast.api.*;
import org.objectweb.openccm.generator.java.ast.lib.*;
/** Others. */
import org.objectweb.openccm.generator.common.lib.GenerationException;
import org.objectweb.openccm.pss.generator.common.api.PSDL2JavaGenerator;

import java.util.List;


/**
 * This class generates Abstract Storage Type Mapping.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 * 
 * @version 0.1
 */

public class AbstractStorageTypeMapping
  implements org.objectweb.openccm.pss.generator.common.api.AbstractStorageTypeMapping
{

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The Abstract StorageType declaration. */
    private AbstractStorageTypeDecl ast_;

    // ===========================================================
    //
    // Constructors.
    //
    // ===========================================================

    /**
     * The default constructor.
     */
    public AbstractStorageTypeMapping()
    {
        // Init internal state
        ast_ = null;
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /** 
     * Set the PSDL Abstract StorageType Declaration to map. 
     *
     * @param ast - The Abstract Storage Type to map.
     */
     public void
     setAbstractStorageType(AbstractStorageTypeDecl ast)
     {
         ast_ = ast;
     }

    /**
     * Map an Abstract Storage Type definition into a java Interface.
     *
     * @param generator - The PSDL to Java generator.
     */
    public void
    toJava(PSDL2JavaGenerator generator)
    throws GenerationException
    {
        InterfaceObject itf = null;
        MethodObject method = null;
        AbstractStorageTypeDecl[] inherited = null;
        List vect = null;
        StorageTypeStateMemberDecl[] state_members = null;
        PsdlOperationDecl[] operations = null;

        itf = new InterfaceObjectImpl(ast_.getName());
        itf.addComment(" Abstract Storage Type "+ast_.getName());
        itf.addComment("");
        itf.addComment(" @author OpenCCM PSDL Compiler");
        itf.setModifier(ModifierKindImpl.mk_public);
        itf.setPackage(generator.getTranslator().getPackage(ast_));

        // Add Inherited Abstract Storage Type by ast
        inherited = ast_.getAbstractStorageTypeList().getAbstractStorageTypes();
        for (int i=0; i<inherited.length; i++)
            itf.addInheritedObject(generator.getTranslator().getAbsoluteName(inherited[i]));

        // inherits implicitly org.omg.CosPersistentState.StorageObject
        if (inherited.length < 1)
            itf.addInheritedObject("org.objectweb.openccm.pss.runtime.common.api.StorageObject");

        generator.getJavaRepository().addObject(itf);
        HolderMapping hm = new HolderMapping(ast_.getName(), generator.getTranslator().getPackage(ast_));
        hm.toJava(generator.getJavaRepository());

        // Map State Members
        vect = generator.getDeclarations(ast_, DeclarationKind.dk_storage_type_state_member);
        state_members = (StorageTypeStateMemberDecl[])vect.toArray(new StorageTypeStateMemberDecl[0]);
        for (int i=0; i<state_members.length; i++)
        {
            org.objectweb.openccm.pss.generator.common.api.StateMemberMapping state = null;
            
            state = (org.objectweb.openccm.pss.generator.common.api.StateMemberMapping)
                         MappingObjectFactory.getClass("StateMemberMapping");
            state.setStateMember(state_members[i]);
            state.toJavaAccessors(generator.getTranslator(), itf, false);
        }

        // Map Psdl Operations
        vect = generator.getDeclarations(ast_, DeclarationKind.dk_psdl_operation);
        operations = (PsdlOperationDecl[])vect.toArray(new PsdlOperationDecl[0]);
        for (int i=0; i<operations.length; i++)
        {
            org.objectweb.openccm.pss.generator.common.api.PSDLOperationMapping op = null;
            
            op = (org.objectweb.openccm.pss.generator.common.api.PSDLOperationMapping)
                        MappingObjectFactory.getClass("PSDLOperationMapping");
            op.setOperation(operations[i]);
            op.toJava(generator.getTranslator(), itf);
        }
    }
}
