/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Alex Andrushchak.
Contributor(s): Christophe Demarey.

====================================================================*/

package org.objectweb.openccm.pss.generator.hibernate.api;

// Package dependencies
import java.util.List;
import org.objectweb.openccm.generator.common.lib.GenerationException;

/**
 * This interface allows you to generate hibernate mapping xml files.
 *
 * @author <a href="mailto:pretend@ukr.net">Alex Andrushchak</a>
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 */

public interface HibernateXmlGenerator
    extends org.objectweb.openccm.generator.common.api.Generator
{
    /**
     * Initialize the generator.
     *
     * @param app_name - The application's name.
     **/
    public void
    initialize(String app_name);

    /**
     * Map a storage type to a hibernate persistent classe in the xml file.
     *
     * @param st - The storage type to map.
     **/
    public void
    mapStorageType(org.objectweb.openccm.ast.api.StorageTypeDecl st);

    /**
     * Generate Hibernate mapping xml files.
     *
     * @param base_dir - The base directory where files will be generated.
     * @param storage_types - Storage Types to include in Hibernate mapping xml files.
     **/
    public void
    to_hibernate_xml(String base_dir,
                     List storage_types,
                     String user_properties_file)
    throws GenerationException;
}