/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Alex Andrushchak.
Contributor(s): Christophe Demarey.

====================================================================*/

package org.objectweb.openccm.pss.generator.hibernate.lib;

// Package dependencies
/** To access AST. */
import org.objectweb.openccm.ast.api.StorageTypeStateMemberDecl;
/** To access Java AST. */
import org.objectweb.openccm.generator.java.ast.api.*;
import org.objectweb.openccm.generator.java.ast.lib.*;
/** Others. */
import org.objectweb.openccm.generator.translator.idl2java.api.PSDL_JavaTranslator;
import org.objectweb.openccm.pss.generator.common.api.PSDL2JavaGenerator;


/**
 * This class generates Storage Type Hibernate Mapping.
 *
 * @author <a href="mailto:pretend@ukr.net">Alex Andrushchak</a>
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 * 
 * @version 0.1
 */

public class StorageTypeMapping
     extends org.objectweb.openccm.pss.generator.common.lib.StorageTypeMapping
{

    // ==================================================================
    //
    // Internal states.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     */
    public StorageTypeMapping()
    {
        super();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Add methods of net.sf.hibernate.Lifecycle interface to this storage type.
     *
     * @param generator - The PSDL to Java generator.
     * @param clazz - The abstract storage type mapping class.
     **/
    protected void
    addInstanceCallbacks( PSDL2JavaGenerator generator,
                          ClassObject clazz )
    {
        java.util.List to_codec = null,
                       to_ior = null,
                       to_class = null;
        java.util.Iterator it = null;
        StorageTypeStateMemberDecl state = null;
        String mapping_type = null;
        MethodObject method = null;
        ParameterObject param = null;
        PSDL_JavaTranslator translator = null;

        translator = generator.getTranslator();

        clazz.addImplementedObject("net.sf.hibernate.Lifecycle");

        // Compute marshalled states
        to_codec = getStatesToCodec(generator);
        to_ior = getStatesToIOR(generator);
        to_class = getStatesToClass(generator);

        // Add the onLoad method
        method = new MethodObjectImpl();
        method.addComment("net.sf.hibernate.Lifecycle onLoad method.");
        method.setName("onLoad");
        method.setReturnType("void");
        method.getImpl().setMacro("ST_HIBERNATE_POST_LOAD_METHOD");
        method.getImpl().addContextValue("to_codec", to_codec);
        method.getImpl().addContextValue("to_ior", to_ior);
        method.getImpl().addContextValue("to_class", to_class);
        method.getImpl().addContextValue("translator", translator);
        param = new ParameterObjectImpl();
        param.setName("session");
        param.setType("net.sf.hibernate.Session");
        method.addParameter(param);
        param = new ParameterObjectImpl();
        param.setName("id");
        param.setType("java.io.Serializable");
        method.addParameter(param);
        clazz.addMethod(method);

        // Add the onSave method
        method = new MethodObjectImpl();
        method.addComment("net.sf.hibernate.Lifecycle onSave method.");
        method.setName("onSave");
        method.setReturnType("boolean");
        method.getImpl().setMacro("ST_HIBERNATE_PRE_STORE_METHOD");
        method.getImpl().addContextValue("to_codec", to_codec);
        method.getImpl().addContextValue("to_ior", to_ior);
        method.getImpl().addContextValue("to_class", to_class);
        method.getImpl().addContextValue("translator", translator);
        param = new ParameterObjectImpl();
        param.setName("session");
        param.setType("net.sf.hibernate.Session");
        method.addParameter(param);
        method.addException("net.sf.hibernate.CallbackException");
        clazz.addMethod(method);

        // Add the onUpdate method
        method = new MethodObjectImpl();
        method.addComment("net.sf.hibernate.Lifecycle onUpdate method.");
        method.setName("onUpdate");
        method.setReturnType("boolean");
        method.getImpl().setMacro("ST_HIBERNATE_PRE_UPDATE_METHOD");
        method.getImpl().addContextValue("to_codec", to_codec);
        method.getImpl().addContextValue("to_ior", to_ior);
        method.getImpl().addContextValue("to_class", to_class);
        method.getImpl().addContextValue("translator", translator);
        param = new ParameterObjectImpl();
        param.setName("session");
        param.setType("net.sf.hibernate.Session");
        method.addParameter(param);
        method.addException("net.sf.hibernate.CallbackException");
        clazz.addMethod(method);

        // Add the onDelete method
        method = new MethodObjectImpl();
        method.addComment("net.sf.hibernate.Lifecycle onDelete method.");
        method.setName("onDelete");
        method.setReturnType("boolean");
        method.getImpl().setMacro("ST_HIBERNATE_PRE_DELETE_METHOD");
        method.getImpl().addContextValue("to_codec", to_codec);
        method.getImpl().addContextValue("to_ior", to_ior);
        method.getImpl().addContextValue("to_class", to_class);
        method.getImpl().addContextValue("translator", translator);
        param = new ParameterObjectImpl();
        param.setName("session");
        param.setType("net.sf.hibernate.Session");
        method.addParameter(param);
        method.addException("net.sf.hibernate.CallbackException");
        clazz.addMethod(method);

    }
    
    /**
     * Get The base class for JDO Storage Type Mapping.
     * 
     * @return The base class name.
     */
    protected String
    getStorageTypeBaseClass()
    {
        return "org.objectweb.openccm.pss.runtime.hibernate.lib.StorageObjectBase";
    }

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

}
