/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ________________________________________.

====================================================================*/

package org.objectweb.openccm.pss.generator.jdo.lib;

// Package dependencies
/** To access AST. */
import org.objectweb.openccm.ast.api.StorageTypeStateMemberDecl;
/** To access Java AST. */
import org.objectweb.openccm.generator.java.ast.api.*;
import org.objectweb.openccm.generator.java.ast.lib.*;
/** Others. */
import org.objectweb.openccm.generator.translator.idl2java.api.PSDL_JavaTranslator;
import org.objectweb.openccm.pss.generator.common.api.PSDL2JavaGenerator;



/**
 * This class generates Storage Type JDO Mapping.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 * 
 * @version 0.1
 */

public class StorageTypeMapping
     extends org.objectweb.openccm.pss.generator.common.lib.StorageTypeMapping
{

    // ==================================================================
    //
    // Internal states.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     */

    public StorageTypeMapping()
    {
        super();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Add methods of javax.jdo.InstanceCallbacks interface to this storage type.
     *
     * @param generator - The PSDL to Java generator.
     * @param clazz - The abstract storage type mapping class.
     **/
    protected void
    addInstanceCallbacks( PSDL2JavaGenerator generator,
                          ClassObject clazz )
    {
        java.util.List to_codec = null,
                       to_ior = null,
                       to_class = null;
        java.util.Iterator it = null;
        StorageTypeStateMemberDecl state = null;
        String mapping_type = null;
        MethodObject method = null;
        PSDL_JavaTranslator translator = null;

        translator = generator.getTranslator();

        clazz.addImplementedObject("javax.jdo.InstanceCallbacks");

        // Compute marshalled states
        to_codec = getStatesToCodec(generator);
        to_ior = getStatesToIOR(generator);
        to_class = getStatesToClass(generator);

        // Add the jdoPostLoad method
        method = new MethodObjectImpl();
        method.addComment("javax.jdo.InstanceCallbacks jdoPostLoad method.");
        method.setName("jdoPostLoad");
        method.setReturnType("void");
        method.getImpl().setMacro("ST_JDO_POST_LOAD_METHOD");
        method.getImpl().addContextValue("to_codec", to_codec);
        method.getImpl().addContextValue("to_ior", to_ior);
        method.getImpl().addContextValue("to_class", to_class);
        method.getImpl().addContextValue("translator", translator);
        clazz.addMethod(method);

        // Add the jdoPreStore method
        method = new MethodObjectImpl();
        method.addComment("javax.jdo.InstanceCallbacks jdoPreStore method.");
        method.setName("jdoPreStore");
        method.setReturnType("void");
        method.getImpl().setMacro("ST_JDO_PRE_STORE_METHOD");
        method.getImpl().addContextValue("to_codec", to_codec);
        method.getImpl().addContextValue("to_ior", to_ior);
        method.getImpl().addContextValue("to_class", to_class);
        method.getImpl().addContextValue("translator", translator);
        clazz.addMethod(method);

        // Add the jdoPreClear method
        method = new MethodObjectImpl();
        method.addComment("javax.jdo.InstanceCallbacks jdoPreClear method.");
        method.setName("jdoPreClear");
        method.setReturnType("void");
        clazz.addMethod(method);

        // Add the jdoPreDelete method
        method = new MethodObjectImpl();
        method.addComment("javax.jdo.InstanceCallbacks jdoPreDelete method.");
        method.setName("jdoPreDelete");
        method.getImpl().setMacro("ST_JDO_PRE_DELETE_METHOD");
        method.getImpl().addContextValue("to_class", to_class);
        method.getImpl().addContextValue("translator", translator);
        method.setReturnType("void");
        clazz.addMethod(method);
    }

    /**
     * Get The base class for JDO Storage Type Mapping.
     * 
     * @return The base class name.
     */
    protected String
    getStorageTypeBaseClass()
    {
        return "org.objectweb.openccm.pss.runtime.jdo.lib.StorageObjectBase";
    }

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

}
