/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.openccm.pss.runtime.common.lib;

//Package dependencies.
import org.objectweb.openccm.pss.runtime.common.api.ConnectorInstanciationException;


/**
 * PSS Connector Factory.
 * This factory gives either a jdo connector or an hibernate connector.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */
public class ConnectorFactory
{
    /**
     * Get a new PSS connector instance.
     * 
     * @return a new PSS connector instance.
     */
    public static org.objectweb.openccm.pss.runtime.common.api.Connector
    create()
    {
        String pf = System.getProperty("pss.pf");
        
        if (pf != null)
        {
            if (pf.compareTo("kodo") == 0)
                return new org.objectweb.openccm.pss.runtime.jdo.kodo.Connector();
            if (pf.compareTo("hibernate") == 0)
                return new org.objectweb.openccm.pss.runtime.hibernate.lib.Connector();
        }
        
        throw new ConnectorInstanciationException();
    }
}
