/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Alex Andrushchak.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.openccm.pss.runtime.hibernate.lib;


/**
 * CatalogBase is a base class for Hibernate Catalog.
 * It implements the org.objectweb.openccm.services.pss.api.Catalog interface.
 *
 * @author <a href="mailto:pretend@ukr.net">Alex Andrushchak</a>
 *
 * @version 0.1
 */

public abstract class CatalogBase
              extends org.objectweb.openccm.pss.runtime.common.lib.CatalogBase
           implements org.objectweb.openccm.pss.runtime.hibernate.api.CatalogBase
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /**
     * Hibernate session reference.
     */
    private net.sf.hibernate.Session _hibernate_session;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /**
     * The default constructor.
     *
     * @param id - The catalog id.
     * @param pm - The associted Hibernate Session.
     */
    public CatalogBase(int id, net.sf.hibernate.Session session)
    {
        super(id);
        _hibernate_session = session;
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for org.omg.CosPersistentState.Catalog
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for org.objectweb.openccm.pss.runtime.common.api.CatalogBase
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for org.objectweb.openccm.pss.runtime.hibernate.api.CatalogBase
    //
    // ==================================================================

    /**
     * Get the Hibernate Persistence Manager.
     *
     * @return The associated persistence manager.
     */
    public net.sf.hibernate.Session
    get_hibernate_session()
    {
        return _hibernate_session;
    }

    /**
     * Begin a transaction in the Hibernate session.
     */
    public void
    begin_tx()
    {
        try {
            get_hibernate_session().beginTransaction();
        } catch (net.sf.hibernate.HibernateException ex) {
            throw new RuntimeException(ex);
        }
    }

    /**
     * Commit a transaction in the Hibernate session.
     */
    public void
    commit_tx()
    {
        try {
            net.sf.hibernate.Transaction t = get_hibernate_session().beginTransaction();
            t.commit();
        } catch (net.sf.hibernate.HibernateException ex) {
            throw new RuntimeException(ex);
        }
    }

    /**
     * Rollback a transaction in the Hibernate session
     */
    public void
    rollback_tx()
    {
        try {
            net.sf.hibernate.Transaction t = get_hibernate_session().beginTransaction();
            t.rollback();
        } catch (net.sf.hibernate.HibernateException ex) {
            throw new RuntimeException(ex);
        }
    }
}
