/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.openccm.pss.runtime.jdo.kodo;


/**
 * JDO Connector for Kodo.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */

public class Connector
     extends org.objectweb.openccm.pss.runtime.jdo.lib.Connector
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** Configuration properties. */
    java.util.Properties props_ = null;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /**
     * The default constructor.
     */
    public Connector()
    {
        super();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Load Kodo configuration file.
     * 
     * @param file - The configuration file to load.
     */
    private void
    load_kodo_properties(String file)
    {
        props_ = new java.util.Properties();

        try {
            java.io.InputStream propStream = null;
    
            propStream = Thread.currentThread().getContextClassLoader().getResourceAsStream(file);
            props_.load(propStream);
        }catch (Exception e) {
            throw new RuntimeException(e);
        }

        System.getProperties().putAll(props_);
    }

    /**
     * Get JDO generic Connector session parameters.
     * 
     * @return JDO generic Connector session parameters.
     */
    private org.omg.CosPersistentState.Parameter[]
    get_session_parameters()
    {
        org.omg.CosPersistentState.Parameter[] parameters = null;
        org.omg.CosPersistentState.Parameter param = null;
        org.omg.CORBA.Any a = null;
        String value = null;

        // Init parameters
        parameters = new org.omg.CosPersistentState.Parameter[5];

        a = org.objectweb.openccm.corba.TheORB.getORB().create_any();
        value = System.getProperty("javax.jdo.option.ConnectionURL");
        a.insert_string(value);
        param = new org.omg.CosPersistentState.Parameter("DB_URL", a);
        parameters[0] = param;
        
        a = org.objectweb.openccm.corba.TheORB.getORB().create_any();
        value = System.getProperty("javax.jdo.option.ConnectionDriverName");
        a.insert_string(value);
        param = new org.omg.CosPersistentState.Parameter("DB_DRIVER", a);
        parameters[1] = param;
        
        a = org.objectweb.openccm.corba.TheORB.getORB().create_any();
        value = System.getProperty("javax.jdo.PersistenceManagerFactoryClass");
        a.insert_string(value);
        param = new org.omg.CosPersistentState.Parameter("PM_FACTORY", a);
        parameters[2] = param;
        
        a = org.objectweb.openccm.corba.TheORB.getORB().create_any();
        value = System.getProperty("javax.jdo.option.ConnectionUserName");
        a.insert_string(value);
        param = new org.omg.CosPersistentState.Parameter("USER_NAME", a);
        parameters[3] = param;
        
        a = org.objectweb.openccm.corba.TheORB.getORB().create_any();
        value = System.getProperty("javax.jdo.option.ConnectionPassword");
        a.insert_string(value);
        param = new org.omg.CosPersistentState.Parameter("PASSWORD", a);
        parameters[4] = param;

        return parameters;
    }
    
    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for org.omg.CosPersistentState.Connector
    //
    // ==================================================================

    /**
     * Create a basic session.
     */
    public org.omg.CosPersistentState.Session
    create_basic_session(short access_mode,
                         org.omg.CosPersistentState.Parameter[] additional_parameters)
    {
        if (additional_parameters.length == 1)
        {
            org.omg.CosPersistentState.Parameter param = additional_parameters[0];

            if (param.name.compareTo(Connector.CONF_FILE_KEY) == 0)
            {
                load_kodo_properties( param.val.extract_string() );
            }
            else
                throw new RuntimeException("CONF_FILE parameter is missing!");
        }
        else
            throw new RuntimeException("CONF_FILE parameter is missing!");

        return super.create_basic_session(access_mode, get_session_parameters());
    }

    /**
     * Create a transactional session.
     */
    public org.omg.CosPersistentState.TransactionalSession
    create_transactional_session(short access_mode,
                                 short default_isolation_level,
                                 org.omg.CosPersistentState.EndOfAssociationCallback callback,
                                 org.omg.CosPersistentState.Parameter[] additional_parameters)
    {
        // TO DO
        return null;
    }

    /**
     * Create a session pool.
     */
    public org.omg.CosPersistentState.SessionPool
    create_session_pool(short access_mode,
                        short tx_policy,
                        org.omg.CosPersistentState.Parameter[] additional_parameters)
    {
        // TO DO
        return null;
    }

    // ==================================================================
    //
    // Methods for org.objectweb.openccm.pss.runtime.api.Connector
    //
    // ==================================================================

}

