/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Pierre Carpentier.
Contributor(s): Philippe Merle.

---------------------------------------------------------------------
$Id: ModelData.java,v 1.1 2004/05/26 11:25:34 carpentier Exp $
====================================================================*/

package org.objectweb.openccm.uml.lib;

import java.io.File;


/**
 * Class representation of a Model.
 *
 * @author <a href="mailto:Pierre.Carpentier@lifl.fr">Pierre Carpentier</a>
 *
 * @version 1.0
 */

public class ModelData
{

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
 
	/** The file of the model. */
    private File modelFile = null;
    
    /** The URI of the model, i.e. the name which represents the model in the rules file. */
    private String modelUri = null;
    
    /** The URL of the metamodel file. */
    private String metamodelURL = null;
    
    /** The outermost package of the repository (corresponding to the metamodel). */
    private String metamodelJmiClass = null;
    
    /** The class to import or export the model in/from the repository
     *  (it depends if the model is the source or the destination model). */
    private String modelIOClass = null;
	
    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /**
     * The default constructor.
     * 
     * @param modelFilename The filename of the model.
     * @param modelUri The URI of the model.
     * @param metamodelURL The URL of the metamodel file.
     * @param metamodelJmiClass The outermost package of the repository.
     * @param modelIOClass The class to import or export the model in/from the repository.
     */
    public
	ModelData(File modelFile, String modelUri, String metamodelURL, String metamodelJmiClass, String modelIOClass) {
    	this.modelFile = modelFile;
    	this.modelUri = modelUri;
    	this.metamodelURL = metamodelURL;
        this.metamodelJmiClass = metamodelJmiClass;
        this.modelIOClass = modelIOClass;
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public accessor methods.
    //
    // ==================================================================
	
	/**
	 * Gets the filename of the model.
	 * @return Returns the filename of the model.
	 */
	public File getModelFile() {
		return modelFile;
	}
	
	/**
	 * Gets the URI of the model.
	 * @return Returns the URI of the model.
	 */
	public String getModelUri() {
		return modelUri;
	}
	
	/**
	 * Gets the URL of the metamodel file.
	 * @return Returns the URL of the metamodel file.
	 */
	public String getMetamodelURL() {
		return metamodelURL;
	}

	/**
	 * Gets the outermost package of the repository.
	 * @return Returns the outermost package of the repository.
	 */
	public String getMetamodelJmiClasses() {
		return metamodelJmiClass;
	}
	
	/**
	 * Gets the class to import or export the model in/from the repository.
	 * @return Returns the class to import or export the model in/from the repository.
	 */
	public String getModelIOClass() {
		return modelIOClass;
	}
	
}
