/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Pierre Carpentier.
Contributor(s): Philippe Merle.

---------------------------------------------------------------------
$Id: DestroyCidlModule.java,v 1.3 2005/04/01 20:04:08 contrera Exp $
====================================================================*/

package org.objectweb.openccm.uml.transformation.ast;

import ispuml.mdaTransformation.RuleContext;
import ispuml.mdaTransformation.TransformationException;
import ispuml.mdaTransformation.ActionBase;
import ispuml.mdaTransformation.rules.xml.CompositeXmlAction;


/**
 * This action destroys the CIDL Module from the OpenCCM Interface Repository.
 */
public class DestroyCidlModule extends CompositeXmlAction {

    /**
     * Constructor.
     */
    public DestroyCidlModule() {
        // The src property is not required. If it is not set, use the bean provided
        // as parameter.
        isSrcPropertyRequired = false;
        isDstPropertyRequired = false;
        action = new TransformAction();
    }
    

    /**
     * Inner class
     */
    class TransformAction extends ActionBase {
        /**
         * Transform the bean and return the result.
         * @param object
         * @return Object
         */
        public Object execute(Object bean, RuleContext request) throws TransformationException {
            CCMASTModelContext context;
            context = (CCMASTModelContext) request.engineContext.getModel("ccm-ast");
            Object obj = request.getAttribute("declaration");
            org.objectweb.openccm.ast.api.CidlModuleDecl cidlModule;
            cidlModule = (org.objectweb.openccm.ast.api.CidlModuleDecl) obj;
            String cidlModuleName = cidlModule.getName();
            
            // Destroy the CIDL Module
            org.objectweb.openccm.ir3.api.ComponentRepository interfaceRepository;
            interfaceRepository = org.objectweb.openccm.ir3.api.ComponentRepositoryHelper.narrow(
                org.objectweb.openccm.corba.TheInterfaceRepository.getRepository());
            interfaceRepository.lookup(cidlModule.getName()).destroy();
            
            return cidlModule;
        }

    } // end class
}
