/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Pierre Carpentier.
Contributor(s): Philippe Merle.

---------------------------------------------------------------------
$Id: Scopes.java,v 1.1 2004/05/26 11:25:35 carpentier Exp $
====================================================================*/

package org.objectweb.openccm.uml.transformation.ast;

import java.util.Stack;
import org.objectweb.openccm.ast.api.Scope;

/**
 * Singleton class for retrieving the current Scope.
 * The scopes are stocked thanks to a stack.
 * 
 * @author Pierre Carpentier
 */
public class Scopes {

    /** The scopes. */
    private static Stack scopes = new java.util.Stack();
    
    /**
     * Gets the current scope.
     * @return The current scope.
     */
    public static Scope getScope() {
        return (Scope)scopes.peek();
    }
    
    /**
     * Adds a scope to the stack.
     * @param scope The scope to add.
     */
    public static void pushScope(Scope scope) {
        scopes.push(scope);
    }
    
    /**
     * Remove the current scope from the stack.
     * @return The removed scope.
     */
    public static Scope popScope() {
        return (Scope)scopes.pop();
    }


}
