/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Pierre Carpentier.
Contributor(s): Philippe Merle.

---------------------------------------------------------------------
$Id: TransformAssociations.java,v 1.1 2004/05/26 11:25:35 carpentier Exp $
====================================================================*/

package org.objectweb.openccm.uml.transformation.ast;

import ispuml.mdaTransformation.RuleContext;
import ispuml.mdaTransformation.TransformationException;
import ispuml.mdaTransformation.ActionBase;
import ispuml.mdaTransformation.rules.xml.CompositeXmlAction;

import javax.jmi.reflect.RefPackage;

import org.objectweb.openccm.uml.transformation.modfact.JmiModFactModelCreateUtils;

import java.util.Collection;
import java.util.Iterator;

/**
 * An action which gets all the classes associated to a specified class.
 */
public class TransformAssociations extends CompositeXmlAction {

    /**
     * Constructor.
     */
    public TransformAssociations() {
        // The src property is not required. If it is not set, use the bean provided
        // as parameter.
        isSrcPropertyRequired = false;
        isDstPropertyRequired = false;
        action = new TransformAction();
    }

    /**
     * Inner class
     */
    class TransformAction extends ActionBase {

        /**
         * Get the list of the associated classes of a class.
         * @param roots The roots of the repository.
         * @param clazz The class which is associated to the class.
         * @return The list of the associated classes.
         */
        private Collection getAssociatedClass(Collection roots, Object clazz) {
            Collection list = new java.util.ArrayList();
            Iterator it = roots.iterator();
            while (it.hasNext()) {
                Object obj = it.next();
                if (obj instanceof org.omg.uml.core.Association) {
                    org.omg.uml.core.Association asso = (org.omg.uml.core.Association) obj;
                    java.util.List connections = asso.getConnection();
                    if (connections.size() == 2) {
                        if (((org.omg.uml.core.AssociationEnd) connections.get(0)).getParticipant().equals(clazz)) {
                            list.add(connections.get(1));
                        }
                        if (((org.omg.uml.core.AssociationEnd) connections.get(1)).getParticipant().equals(clazz)) {
                            list.add(connections.get(0));
                        }
                    }
                }
            }
            return list;
        }

        /**
         * Transform the bean and return the result.
         * @param object
         * @return Object
         * @roseuid 3F1C5EBF016D
         */
        public Object execute(Object bean, RuleContext request) throws TransformationException {
            Collection roots = JmiModFactModelCreateUtils.getRoots((RefPackage) bean);
            Iterator iter = getAssociatedClass(roots, bean).iterator();
            while (iter.hasNext()) {
                Object cur = iter.next();
                request.engineContext.engine.transform(cur, request);
            }
            return null;
        }
    } // end class
    
}
