/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Pierre Carpentier.
Contributor(s): Philippe Merle.

---------------------------------------------------------------------
$Id: UMLType2CORBAType.java,v 1.1 2004/05/26 11:25:35 carpentier Exp $
====================================================================*/

package org.objectweb.openccm.uml.transformation.ast;

import org.objectweb.openccm.ast.api.TypeRef;
import org.objectweb.openccm.uml.transformation.modfact.JmiModfactUML14ModelContext;

import ispuml.mdaTransformation.RuleContext;
import ispuml.mdaTransformation.TransformationException;
import ispuml.mdaTransformation.ActionBase;
import ispuml.mdaTransformation.rules.xml.CompositeXmlAction;


/**
 * This action transforms a UML Classifier to a CORBA Type.
 */
public class UMLType2CORBAType extends CompositeXmlAction {

	/**
	 * Constructor.
	 */
	public UMLType2CORBAType() {
		// The src property is not required. If it is not set, use the bean provided
		// as parameter.
		isSrcPropertyRequired = false;
		isDstPropertyRequired = false;
		action = new TransformAction();
	}

	/**
	 * Inner class
	 */
	class TransformAction extends ActionBase {
		/**
		 * Transform the bean and return the result.
		 * @param object
		 * @return Object
		 */
		public Object execute(Object bean, RuleContext request) throws TransformationException {
            org.omg.uml.core.UmlAttribute umlAttribute = (org.omg.uml.core.UmlAttribute) bean;
            CCMASTModelContext context;
            context = (CCMASTModelContext) request.engineContext.getModel("ccm-ast");
            JmiModfactUML14ModelContext umlContext;
            umlContext = (JmiModfactUML14ModelContext) request.engineContext.getModel("uml");
            org.objectweb.openccm.ast.api.WithTypeRef attr = (org.objectweb.openccm.ast.api.WithTypeRef) request.getAttribute("declaration");
            
            TypeRef type = null;
            String typeName = umlAttribute.getType().getName().toLowerCase();
            if (typeName.equals("short"))
                type = CCMASTModelCreateUtils.getAst().getShortType();
            else if (typeName.equals("long"))
                type = CCMASTModelCreateUtils.getAst().getLongType();
            else if (typeName.equals("long long"))
                type = CCMASTModelCreateUtils.getAst().getLongLongType();
            else if (typeName.equals("double"))
                type = CCMASTModelCreateUtils.getAst().getDoubleType();
            else if (typeName.equals("long double"))
                type = CCMASTModelCreateUtils.getAst().getLongDoubleType();
            else if (typeName.equals("unsigned short"))
                type = CCMASTModelCreateUtils.getAst().getUShortType();
            else if (typeName.equals("unsigned long"))
                type = CCMASTModelCreateUtils.getAst().getULongType();
            else if (typeName.equals("unsigned long long"))
                type = CCMASTModelCreateUtils.getAst().getULongLongType();
            else if (typeName.equals("any"))
                type = CCMASTModelCreateUtils.getAst().getAnyType();
            else if (typeName.equals("boolean"))
                type = CCMASTModelCreateUtils.getAst().getBooleanType();
            else if (typeName.equals("string"))
                type = CCMASTModelCreateUtils.getAst().getStringType();
            else if (typeName.equals("octet"))
                type = CCMASTModelCreateUtils.getAst().getOctetType();
            else if (typeName.equals("void"))
                type = CCMASTModelCreateUtils.getAst().getVoidType();
            else if (typeName.equals("char"))
                type = CCMASTModelCreateUtils.getAst().getCharType();
            else if (typeName.equals("wchar"))
                type = CCMASTModelCreateUtils.getAst().getWCharType();
            else if (typeName.equals("float"))
                type = CCMASTModelCreateUtils.getAst().getFloatType();
            else if (typeName.equals("wstring"))
                type = CCMASTModelCreateUtils.getAst().getWStringType();
            else if (typeName.equals("typecode"))
                type = CCMASTModelCreateUtils.getAst().getTypeCodeType();
            else if (typeName.equals("principal"))
                type = CCMASTModelCreateUtils.getAst().getPrincipalType();
            else if (typeName.equals("object"))
                type = CCMASTModelCreateUtils.getAst().getObjectType();
            else if (typeName.equals("valuebase"))
                type = CCMASTModelCreateUtils.getAst().getValueBaseType();
            else if (typeName.equals("native")) {
                type = CCMASTModelCreateUtils.getAst().startNative(umlAttribute.getName());
                ((org.objectweb.openccm.ast.api.NativeDecl)type).create();
            } else if (typeName.indexOf("fixed") == 0) {
                java.util.StringTokenizer token = new java.util.StringTokenizer(typeName, "fixed<>, ");
                if (token.countTokens() == 2) {
                    short digits = Short.parseShort(token.nextToken());
                    short scale = Short.parseShort(token.nextToken());
                    type = CCMASTModelCreateUtils.getAst().createFixedType(digits, scale);
                } else {
                    throw new TransformationException("Attribute " + umlAttribute.getName() + " with bad 'fixed' type.");
                }
            } else {
                //System.out.println("Type " + umlAttribute.getType().getName() + " unrecognized !");
                type = (TypeRef) request.engineContext.engine.transform(umlAttribute.getType(), request);
                if (type == null) {
                	type = (TypeRef) request.engineContext.engine.transform(umlAttribute.getType(), request, "LeafProcessing");
                }
            }
            
            if (type != null) {
                if (umlContext.isStereotyped(umlAttribute, "CORBAAnonymousSequence")) {
                    attr.setType(CCMASTModelCreateUtils.getAst().createSequenceType(0, type));
                } else {
                    attr.setType(type);
                }
            }
            
            return null;
		}
        
        

	} // end class
}
