/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Pierre Carpentier.
Contributor(s): Philippe Merle.

---------------------------------------------------------------------
$Id: JmiModFactUML14ModelUtil.java,v 1.2 2004/06/07 09:09:37 carpentier Exp $
====================================================================*/

package org.objectweb.openccm.uml.transformation.modfact;

import ispuml.mdaTransformation.TransformationException;
import ispuml.mdaTransformation.NotFoundException;
import ispuml.mdaTransformation.model.PropertyUtil;
import ispuml.mdaTransformation.model.jmi.JmiModelUtil;

import java.util.List;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.Vector;

import javax.jmi.reflect.RefPackage;
import javax.jmi.reflect.RefObject;
import javax.jmi.reflect.JmiException;

/**
 * UML 14 Model utilities. This class implementats UML methods dedicated to UML 14.
 */
public class JmiModFactUML14ModelUtil extends JmiModelUtil {

    /**
     * Default constructor.
     * Create an empty outermostRefPackage.
     */
    public JmiModFactUML14ModelUtil() {
        throw new UnsupportedOperationException("Not yet implemented.");
    }

    /**
     * Default constructor.
     * Create an empty outermostRefPackage.
     */
    protected JmiModFactUML14ModelUtil(RefPackage outermostRefPackage) {
        super(outermostRefPackage);
    }

    /**
     * Default constructor.
     * Create an empty outermostRefPackage.
     */
    public JmiModFactUML14ModelUtil(PropertyUtil propUtil, RefPackage outermostRefPackage) {
        super(propUtil, outermostRefPackage);
    }

    /**
     * Create an instance of specified model element.
     * @param instanceName Name of the instance to create.
     * @return The new instance.
     * @throws InstantiationException If the model element can't be created.
     */
    public Object createInstance(String conceptName) throws InstantiationException {
        RefPackage extent = getOutermostRefPackage();
        String[] names = conceptName.split("\\.");
        try {
            // refCreateInstance(null) for ModFact
            return getRefClassByConceptName(conceptName).refCreateInstance(null);
        } catch (JmiException ex) {
            ex.printStackTrace();
            throw new InstantiationException(ex.getMessage());
        }
    }

    /**
     * Get the associated stereotype model element.
     * @param object The object to parse.
     * @param stereotype The stereotype to search.
     * @return The stereotyped-object or null if not found.
     */
    protected RefObject getStereotype(Object object, String stereotype) {
        RefObject modelElement = (RefObject) object;
        Collection stereotypes = (Collection) modelElement.refGetValue("stereotype");
        Iterator iter = stereotypes.iterator();
        while (iter.hasNext()) {
            RefObject stereotypeElement = (RefObject) iter.next();
            if (stereotypeElement.refGetValue("name").equals(stereotype)) {
                return stereotypeElement;
            }
        } // end loop

        return null;
    }

    /**
     * Test if the object in parameter have the stereotype.
     * @param object The object to test.
     * @param stereotype The stereotype to search.
     * @return boolean TRUE if the object is stereotyped with the stereotype.
     */
    public boolean isStereotyped(Object object, String stereotype) {
        RefObject modelElement = (RefObject) object;

        Collection stereotypes = (Collection) modelElement.refGetValue("stereotype");
        Iterator iter = stereotypes.iterator();
        while (iter.hasNext()) {
            RefObject stereotypeElement = (RefObject) iter.next();
            if (stereotype.equals(stereotypeElement.refGetValue("name")))
                return true;
        } // end loop
        if (stereotypes.size() == 0 && stereotype.trim().length() == 0)
            return true;
        return false;
    }

    /**
     * Get all the stereotype of an object.
     * @param object The stereotyped-object.
     * @return List The list of the stereotypes.
     */
    public List getStereotypes(Object object) {
        RefObject modelElement = (RefObject) object;

        Collection stereotypes = (Collection) modelElement.refGetValue("stereotype");
        List res = new ArrayList(stereotypes);
        return res;
    }

    /**
     * Add a stereotype to an object.
     * @param object The object to stereotype.
     * @param stereotype The stereotype to add to the object.
     */
    public void addStereotype(Object object, String stereotype) {
        throw new UnsupportedOperationException("Not yet implemented.");
    }

    /**
     * Get the value of the tagged value associated to the stereotype.
     * @param object The object
     * @param stereotype Name of the stereotype to which the value belong
     * @param attributeName The name of the stereotype attribute (tagged value)
     * @return The value of the stereotype attribute (tagged value).
     * @throws TransformationException
     */
    public Object getStereotypeTaggedValue(Object object, String stereotype, String attributeName) throws TransformationException {
        RefObject modelElement = (RefObject) object;
        Collection tagValues = (Collection) modelElement.refGetValue("taggedValue");
        Iterator iter = tagValues.iterator();
        while (iter.hasNext()) {
            RefObject tag = (RefObject) iter.next();
            if (tag != null) {
                RefObject tagDef = (RefObject) tag.refGetValue("type");
                if (tagDef != null) {
                    String tagName = (String) tagDef.refGetValue("name");
                    RefObject owner = (RefObject)tagDef.refGetValue("owner");
                    if (tagName != null && attributeName.equals(tagName)
                        && ((owner != null && owner.refGetValue("name").equals(stereotype))
                        || (owner == null && stereotype.trim().length() == 0)))
                        return ((Vector) tag.refGetValue("dataValue")).get(0);
                }
            }
        } // end loop
        throw new NotFoundException("Can't find tagValue '" + attributeName + "', '" + stereotype + "'.");
    }

    /**
     *
     * Set the value of the tagged value associated to the stereotype.
     * @param object The object
     * @param stereotype Name of the stereotype to which the value belong
     * @param attributeName The name of the stereotype attribute (tagged value)
     * @param value The value to be set
     * @throws TransformationException
     */
    public void setStereotypeTaggedValue(Object object, String stereotype, String attributeName, Object value)
        throws TransformationException {
        throw new UnsupportedOperationException("Not yet implemented.");
    }

}
