/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Pierre Carpentier.
Contributor(s): Philippe Merle.

---------------------------------------------------------------------
$Id: CallMethod.java,v 1.1 2004/05/26 11:25:35 carpentier Exp $
====================================================================*/

package org.objectweb.openccm.uml.transformation.rules.xml;

import ispuml.mdaTransformation.RuleContext;
import ispuml.mdaTransformation.TransformationException;
import ispuml.mdaTransformation.ActionBase;
import ispuml.mdaTransformation.rules.xml.CompositeXmlAction;


/**
 * This action calls a method to the bean.
 */
public class CallMethod extends CompositeXmlAction {
    
    /** The name of the method to call. */
    private String methodName;

    /**
     * Constructor.
     */
    public CallMethod() {
        // The src property is not required. If it is not set, use the bean provided
        // as parameter.
        isSrcPropertyRequired = false;
        isDstPropertyRequired = false;
        action = new TransformAction();
    }
    
    /**
     * Sets the name of the method to call.
     * @param methodName The method name.
     */
    public void setMethodName (String methodName) {
        this.methodName = methodName;
    }

    /**
     * Inner class
     */
    class TransformAction extends ActionBase {
        /**
         * Calls the method to the bean.
         * @param bean The bean which contains the method to invoke.
         * @param request The context.
         * @return Object The result of the method invocation.
         */
        public Object execute(Object bean, RuleContext request) throws TransformationException {
            try {
                Class param [] = new Class[0];
                java.lang.reflect.Method method = bean.getClass().getMethod(methodName, param);
                return method.invoke(bean, null);
            } catch (Exception exc) {
                throw new TransformationException("The method " + methodName + "() does not exist on this bean.");
            }
        }

    } // end class
}
