/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Pierre Carpentier.
Contributor(s): Philippe Merle.

---------------------------------------------------------------------
$Id: FormatString.java,v 1.2 2004/06/07 09:09:37 carpentier Exp $
====================================================================*/

package org.objectweb.openccm.uml.transformation.rules.xml;


import ispuml.mdaTransformation.RuleContext;
import ispuml.mdaTransformation.TransformationException;
import ispuml.mdaTransformation.ActionBase;
import ispuml.mdaTransformation.rules.xml.CompositeXmlAction;


/**
 * This action formats a String.
 */
public class FormatString extends CompositeXmlAction {
    
    /** The format pattern. */
    private String formatPattern;

    /**
     * Constructor.
     */
    public FormatString() {
        // The src property is not required. If it is not set, use the bean provided
        // as parameter.
        isSrcPropertyRequired = false;
        isDstPropertyRequired = false;
        action = new TransformAction();
    }
    
    /**
     * Sets the format pattern.
     * @param formatPattern The format pattern.
     */
    public void setFormatPattern (String formatPattern) {
        this.formatPattern = formatPattern;
    }

    /**
     * Inner class
     */
    class TransformAction extends ActionBase {
        /**
         * Transform the bean and return the result.
         * @param object
         * @return Object
         */
        public Object execute(Object bean, RuleContext request) throws TransformationException {
            String toFormat = bean.toString();
            if (toFormat.length() > 1)
                return toFormat.substring(0,1).toUpperCase() + toFormat.substring(1).toLowerCase();
            else
                return toFormat.toUpperCase();
        }

    } // end class
}
