/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Pierre Carpentier.
Contributor(s): Philippe Merle.

---------------------------------------------------------------------
$Id: MethodNotPresentCondition.java,v 1.1 2004/05/26 11:25:35 carpentier Exp $
====================================================================*/

package org.objectweb.openccm.uml.transformation.rules.xml;

import ispuml.mdaTransformation.RuleContext;
import ispuml.mdaTransformation.TransformationException;
import ispuml.mdaTransformation.rules.xml.Condition;

/**
 * Condition to test if a method is not present inside the bean.
 * 
 * @author Pierre Carpentier
 */
public class MethodNotPresentCondition extends Condition {

    /** The method name to search. */
    private String methodName;

    /**
     * Sets the boolean value to test.
     * @param value The boolean value.
     */ 
    public void setMethodName(String methodName) {
        this.methodName = methodName;
    }
    
    /* (non-Javadoc)
     * @see ispuml.mdaTransformation.Guard#isAllowed(java.lang.Object, ispuml.mdaTransformation.RuleContext)
     */
    public boolean isAllowed(Object object, RuleContext context) throws TransformationException {
        org.omg.uml.core.Classifier classifier = (org.omg.uml.core.Classifier)object;
        java.util.List features = classifier.getFeature();
        java.util.Iterator it = features.iterator();
        while (it.hasNext()) {
            Object feature = it.next();
            if (feature instanceof org.omg.uml.core.Method
                && ((org.omg.uml.core.Method)feature).getSpecification().getName().equals(this.methodName))
                return false;
        }
        return true;
    }

}
