/*====================================================================

ObjectWeb Util CommandLine Package.
Copyright (C) 2003 INRIA & USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Romain Rouvoy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.cmdline.lib;


import jregex.Pattern;

import org.objectweb.util.cmdline.api.RegExOptionArgument ;


/**
 * This is a default implementation of the
 * org.objectweb.util.cmdline.api.OptionArgument interface.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *
 * @version 0.1
 */

public class DefaultRegExOptionArgument
     extends DefaultOptionArgument
  implements RegExOptionArgument
{
    /** The checking pattern */
    protected Pattern pattern;

    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     *
     * It inits the Labels, Arguments, and Description usage properties
     * with an empty string.
     */
    public
    DefaultRegExOptionArgument()
    {
        this("", "", (String[])null, null,".*");
    }

    /**
     * The constructor with the initial values for the Labels,
     * Arguments, and Description usage properties.
     *
     * @param label The usage label.
     * @param arguments The usage arguments.
     * @param description The usage description.
     * @param flag The initial flag value.
     */
    public
    DefaultRegExOptionArgument(String label,
                               String arguments,
                               String description,
                               String argument,
                               String pattern)
    {
        this(new String[] { label }, arguments,
             new String[] { description }, argument, pattern);
    }

    /**
     * The constructor with the initial values for the Labels,
     * Arguments, and Description usage properties.
     *
     * @param labels The usage labels.
     * @param arguments The usage arguments.
     * @param description The usage description.
     * @param flag The initial flag value.
     */
    public
    DefaultRegExOptionArgument(String[] labels,
                               String arguments,
                               String description,
                               String argument,
                               String pattern)
    {
        this(labels, arguments, new String[]{description}, argument, pattern);
    }

    /**
     * The constructor with the initial values for the Labels,
     * Arguments, and Description usage properties.
     *
     * @param label The usage label.
     * @param arguments The usage arguments.
     * @param description The usage description.
     * @param flag The initial flag value.
     */
    public
    DefaultRegExOptionArgument(String label,
                               String arguments,
                               String[] description,
                               String argument,
                               String pattern)
    {
        this(new String[]{label}, arguments, description, argument, pattern);
    }

    /**
     * The constructor with the initial values for the Labels,
     * Arguments, and Description usage properties.
     *
     * @param labels The usage labels.
     * @param arguments The usage arguments.
     * @param description The usage description.
     * @param flag The initial flag value.
     */
    public
    DefaultRegExOptionArgument(String[] labels,
                               String arguments,
                               String[] description,
                               String argument,
                               String pattern)
    {
        super(labels, arguments, description,argument);    
        setPattern(new Pattern(pattern));
    }




    // ==================================================================
    //
    // Public methods for interface org.objectweb.util.cmdline.api.Option
    //
    // ==================================================================

    /**
     * Consumes command line arguments from an iterator.
     *
     * @param iterator The command line argument iterator.
     */
    public void
    consume(org.objectweb.util.cmdline.api.Iterator iterator)
    {
        checkAlreadySet(iterator);
        String arg = consumeArgument(iterator);
        if (getPattern().matches(arg))
            setArgument(arg);
    }

    // ==================================================================
    //
    // Public methods for interface org.objectweb.util.cmdline.api.OptionRegExArgument
    //
    // ==================================================================

    /**
     * Gets the checking pattern
     *
     * @return The pattern used to check the CommandLine Argument
     */
    public Pattern
    getPattern() { return pattern; }

    /**
     * Sets the checking pattern
     *
     * @param pattern - the pattern used to check the CommandLine Argument.
     */
    public void
    setPattern(Pattern pattern) { this.pattern = pattern; }
}
