/*====================================================================

ObjectWeb Util Preprocessor Package.
Copyright (C) 2004 INRIA & USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s): Christophe Demarey.

--------------------------------------------------------------------
$Id: OptionP.java,v 1.1 2004/02/05 20:29:57 rouvoy Exp $
====================================================================*/

package org.objectweb.util.cpp.lib;

import org.objectweb.util.cpp.api.Preprocessor;

/**
 * This is an implementation for -P preprocessor option.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *         <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 * @version 0.1
 */

public class OptionP
     extends PreprocessorOptionBase
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /**
     * The constructor.
     *
     * @param preprocessor The associated preprocessor.
     */
    public OptionP(Preprocessor preprocessor) {
        setLabels(new String[] { "-P" });
        setDescription(new String[] { "Inhibit generation of #-lines with line-number information"});
        setPreprocessor(preprocessor);
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for interface org.objectweb.util.cmdline.api.Option
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.util.cpp.api.PreprocessorHolder
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.util.cpp.api.PreprocessorOption
    //
    // ==================================================================

    /**
     * Gets the base option label.
     *
     * @return The base option label.
     */
    public String getBaseOptionLabel() {
        return "-P";
    }  

    /**
     * Consumes the option value.
     *
     * @param current The option value.
     */
    public void consumeOption(String current) {
        getPreprocessor().setGenerateLineInformation(true);
    }

    // ==================================================================
    //
    // Other public methods.
    //
    // ==================================================================
}
