/*====================================================================

Objectweb Explorer Framework
Copyright (C) 2005 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s): ______________________________________.

====================================================================
$Id: BeanShellCode.java,v 1.1 2005/05/30 10:47:22 merle Exp $
====================================================================*/

package org.objectweb.util.explorer.core.code.lib;

import org.objectweb.util.explorer.ExplorerUtils;
import org.objectweb.util.explorer.core.code.api.Code;
import org.objectweb.util.explorer.core.code.api.CodeConfiguration;
import org.objectweb.util.explorer.core.common.lib.ClassResolver;
import org.objectweb.util.trace.TraceSystem;

import bsh.Interpreter;
import bsh.EvalError;

/**
 * 
 *
 * @author <a href="mailto:Philippe.Merle@inria.fr">Philippe Merle</a>.  
 * 
 * @version 0.1
 */
public class BeanShellCode
  implements CodeConfiguration, Code 
{

    //==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The code to instanciate. */
    protected String theCode_ = null;

    protected Class theClass_ = null;
   
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // No internal method.
    //
    // ==================================================================
    
    protected boolean equals(BeanShellCode code){
        if(code!=null){
            String theCode = code.theCode_;
            if(theCode_!=null && theCode!=null){
                return theCode_.equals(theCode);
            }
        }
        return false;
    }
    
    // ==================================================================
    //
    // Public methods for CodeConfiguration interface.
    //
    // ==================================================================

    public void setCode(String code) {
        theCode_ = code;
    }

    // ==================================================================
    //
    // Public methods for Code interface.
    //
    // ==================================================================

    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.code.api.Code#isAssignableFrom(java.lang.Class)
     */
    public boolean isInstanceOf(Class c) {
        theClass_ = c;
        return true;
    }
    
    /* (non-Javadoc)
     * @see org.objectweb.util.explorer.core.code.api.Code#createInstance()
     */
    public Object createInstance() {
        Interpreter interpreter = new Interpreter();

        String code = theCode_
                    + "\nreturn ("
                    + theClass_.getName()
                    + ")this;";
        try
        {
            return interpreter.eval(code);
        }
        catch(EvalError exc)
        {
            TraceSystem.get("explorer").info(exc.getMessage());
        }
	return null;
    }

    // ==================================================================
    //
    // Public methods surcharging Object class.
    //
    // ==================================================================    
    
    /**
     * Surcharging the Object.equals method.
     * @see Object#equals(java.lang.Object)
     */
    public boolean equals(Object o){
        if(o!=null && o instanceof BeanShellCode){
            return equals((BeanShellCode)o);
        }
        return false;
    }
   
    /**
     * Return a String representation of a BasicImageIcon 
     * @see Object#toString() 
     */    
    public String toString(){
        return "BeanShellCode[class=" + 
            ExplorerUtils.toString(theClass_) + "]";
    }    
        
}
