/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Hameau Fabien.
Contributor(s): ______________________________________.

====================================================================*/



package org.objectweb.openccm.Containers.MetaInformation;

/**
 * Manage the storage and acces to a given list of
 * attribute instance objectsd
 *
 * @author <a href="hameau@lifl.fr">Hameau Fabien</a>
 *
 * @version 0.1
 */

import org.objectweb.ccm.util.Table;
import org.omg.CORBA.LocalObject;
import org.omg.Components.InvalidName;

/**
 * @author hameau
 *

 */
public class AttributeInstanceListImpl
extends LocalObject
implements AttributeInstanceList
{  
  // ==================================================================
  //
  // Internal states.
  //
  // ==================================================================

  /** Internal representation of attribute instance MI */
  private Table _attributes; 
  
   public AttributeInstanceListImpl()
   {
     _attributes = new Table();
   }

  // ==================================================================
  //
  // Internal methods.
  //
  // ==================================================================
  
  // NONE
  
  //

  // ==================================================================
  //
  //  Public methods for ccm.Containers.MetaInformation::AttributeInstanceList.
  //
  // ==================================================================
  
   public AttributeInstance 
   get_attribute_instance(String name) 
   throws InvalidName
   {
     AttributeInstance result = (AttributeInstance) _attributes.get(name);
     if(result == null)
       throw new InvalidName();
     return result;
   }

   /* (non-Javadoc)
    * @see org.objectweb.openccm.Containers.MetaInformation.AttributeInstanceListOperations#get_named_attribute_instances(java.lang.String[])
    */
   public AttributeInstance[] 
   get_named_attribute_instances(String[] names) 
   throws InvalidName
   {
     AttributeInstance[] result = new AttributeInstance[names.length];

    // Iterate on all the connections.
  
    int i = 0;
    for(i=0;i<names.length;i++)
    {
      result[i] = (AttributeInstance)_attributes.get(names[i]);
     
      if(result[i] == null)
      {
        throw new InvalidName();
      }
     }
   
    return result;
   }

   /* (non-Javadoc)
    * @see org.objectweb.openccm.Containers.MetaInformation.AttributeInstanceListOperations#get_all_attribute_instances()
    */
   public AttributeInstance[] 
   get_all_attribute_instances()
   {
     AttributeInstance[] result = new AttributeInstance[_attributes.size()];
  
      // Iterate on all the connections.
      int idx = 0;
      for(java.util.Enumeration elements = _attributes.elements(); elements.hasMoreElements(); )
      {
        AttributeInstance info = (AttributeInstance)elements.nextElement();
          result[idx++] = info;
      }
      return result;
   }

   /* (non-Javadoc)
    * @see org.objectweb.openccm.Containers.MetaInformation.AttributeInstanceListOperations#add_attribute_instance(org.objectweb.openccm.Containers.MetaInformation.AttributeInstance)
    */
   public void add_attribute_instance(AttributeInstance cpi)
   {
     String key = cpi.type_reference().name() + cpi.toString().substring(cpi.toString().lastIndexOf("@"));
     
     _attributes.put(key,cpi);
    
   }

   /* (non-Javadoc)
    * @see org.objectweb.openccm.Containers.MetaInformation.AttributeInstanceListOperations#remove_attribute_instance(java.lang.String)
    */
   public void remove_attribute_instance(String name) 
   throws InvalidName
   {
     Object result = _attributes.remove(name);
    
     if (result == null) throw new InvalidName();
   }
}
